@@ -1,3 +1,4 @@
+#
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -13,18 +14,19 @@
 import uuid
 
 import mock
+import six
 
 from heat.common import exception
 from heat.common import template_format
 from heat.engine import resource
 from heat.engine import scheduler
-from heat.tests.common import HeatTestCase
+from heat.tests import common
 from heat.tests import utils
 
 from ..resources import cloudnetworks  # noqa
 
 try:
-    from pyrax.exceptions import NotFound
+    from pyrax.exceptions import NotFound  # noqa
 except ImportError:
     from ..resources.cloudnetworks import NotFound  # noqa
 
@@ -73,7 +75,7 @@ class FakeClient(object):
 
 
 @mock.patch.object(cloudnetworks.CloudNetwork, "cloud_networks")
-class CloudNetworkTest(HeatTestCase):
+class CloudNetworkTest(common.HeatTestCase):
 
     _template = template_format.parse("""
     heat_template_version: 2013-05-23
@@ -88,7 +90,6 @@ class CloudNetworkTest(HeatTestCase):
 
     def setUp(self):
         super(CloudNetworkTest, self).setUp()
-        utils.setup_dummy_db()
         resource._register_class("Rackspace::Cloud::Network",
                                  cloudnetworks.CloudNetwork)
 
@@ -106,7 +107,6 @@ class CloudNetworkTest(HeatTestCase):
         res = self.stack['cnw']
         self.assertEqual((res.CREATE, res.COMPLETE), res.state)
 
-    @utils.stack_delete_after
     def test_attributes(self, mock_client):
         self._setup_stack(mock_client)
         res = self.stack['cnw']
@@ -116,15 +116,25 @@ class CloudNetworkTest(HeatTestCase):
         self.assertEqual(expect_label, res.FnGetAtt('label'))
         self.assertEqual(expect_cidr, res.FnGetAtt('cidr'))
 
-    @utils.stack_delete_after
     def test_create_bad_cider(self, mock_client):
         self._template['resources']['cnw']['properties']['cidr'] = "bad cidr"
         self._parse_stack()
         exc = self.assertRaises(exception.StackValidationFailed,
                                 self.stack.validate)
-        self.assertIn("Invalid cidr", str(exc))
+        self.assertIn("Invalid cidr", six.text_type(exc))
+
+    def test_check(self, mock_client):
+        self._setup_stack(mock_client)
+        res = self.stack['cnw']
+        scheduler.TaskRunner(res.check)()
+        self.assertEqual((res.CHECK, res.COMPLETE), res.state)
+
+        self.fake_cnw.networks = []
+        exc = self.assertRaises(exception.ResourceFailure,
+                                scheduler.TaskRunner(res.check))
+        self.assertEqual((res.CHECK, res.FAILED), res.state)
+        self.assertIn('No network', str(exc))
 
-    @utils.stack_delete_after
     def test_delete(self, mock_client):
         self._setup_stack(mock_client)
         res = self.stack['cnw']
@@ -132,15 +142,28 @@ class CloudNetworkTest(HeatTestCase):
         scheduler.TaskRunner(res.delete)()
         self.assertEqual((res.DELETE, res.COMPLETE), res.state)
         exc = self.assertRaises(NotFound, self.fake_cnw.get, res_id)
-        self.assertIn(res_id, str(exc))
+        self.assertIn(res_id, six.text_type(exc))
+
+    def test_delete_in_use(self, mock_client):
+        self._setup_stack(mock_client)
+        res = self.stack['cnw']
+        fake_network = res.network()
+        fake_network.delete = mock.Mock()
+        fake_network.delete.side_effect = [cloudnetworks.NetworkInUse(), True]
+        fake_network.get = mock.Mock(side_effect=cloudnetworks.NotFound())
+
+        scheduler.TaskRunner(res.delete)()
+        self.assertEqual((res.DELETE, res.COMPLETE), res.state)
 
-    @utils.stack_delete_after
     def test_delete_not_complete(self, mock_client):
         self._setup_stack(mock_client)
         res = self.stack['cnw']
-        self.assertFalse(res.check_delete_complete(res.network()))
+        fake_network = res.network()
+        fake_network.get = mock.Mock()
+
+        task = res.handle_delete()
+        self.assertFalse(res.check_delete_complete(task))
 
-    @utils.stack_delete_after
     def test_delete_not_found(self, mock_client):
         self._setup_stack(mock_client)
         self.fake_cnw.networks = []
