@@ -92,9 +92,9 @@ class CloudServersTest(common.HeatTestCase):
         templ = template.Template(
             t, env=environment.Environment({'key_name': 'test'}))
 
-        stack = parser.Stack(self.ctx, stack_name, templ,
-                             stack_id=uuidutils.generate_uuid())
-        return (templ, stack)
+        self.stack = parser.Stack(self.ctx, stack_name, templ,
+                                  stack_id=uuidutils.generate_uuid())
+        return (templ, self.stack)
 
     def _setup_test_server(self, return_server, name, image_id=None,
                            override_name=False, stub_create=True, exit_code=0):
@@ -179,7 +179,8 @@ class CloudServersTest(common.HeatTestCase):
         self.m.ReplayAll()
         create = scheduler.TaskRunner(server.create)
         exc = self.assertRaises(exception.ResourceFailure, create)
-        self.assertEqual('Error: RackConnect automation FAILED',
+        self.assertEqual('Error: resources.test_rackconnect_failed: '
+                         'RackConnect automation FAILED',
                          six.text_type(exc))
 
     def test_rackconnect_unprocessable(self):
@@ -210,7 +211,8 @@ class CloudServersTest(common.HeatTestCase):
         self.m.ReplayAll()
         create = scheduler.TaskRunner(server.create)
         exc = self.assertRaises(exception.ResourceFailure, create)
-        self.assertEqual('Error: Unknown RackConnect automation status: FOO',
+        self.assertEqual('Error: resources.test_rackconnect_unknown: '
+                         'Unknown RackConnect automation status: FOO',
                          six.text_type(exc))
 
     def test_rackconnect_deploying(self):
@@ -309,7 +311,8 @@ class CloudServersTest(common.HeatTestCase):
         self.m.ReplayAll()
         create = scheduler.TaskRunner(server.create)
         exc = self.assertRaises(exception.ResourceFailure, create)
-        self.assertEqual('Error: Managed Cloud automation failed',
+        self.assertEqual('Error: resources.test_managed_cloud_build_error: '
+                         'Managed Cloud automation failed',
                          six.text_type(exc))
 
     def test_managed_cloud_unknown(self):
@@ -323,7 +326,8 @@ class CloudServersTest(common.HeatTestCase):
         self.m.ReplayAll()
         create = scheduler.TaskRunner(server.create)
         exc = self.assertRaises(exception.ResourceFailure, create)
-        self.assertEqual('Error: Unknown Managed Cloud automation status: FOO',
+        self.assertEqual('Error: resources.test_managed_cloud_unknown: '
+                         'Unknown Managed Cloud automation status: FOO',
                          six.text_type(exc))
 
     def _test_server_config_drive(self, user_data, config_drive, result):
