@@ -17,7 +17,7 @@ import itertools
 from docutils import core
 from docutils import nodes
 import pydoc
-from sphinx.util.compat import Directive
+from sphinx.util import compat
 
 from heat.common.i18n import _
 from heat.engine import attributes
@@ -27,6 +27,9 @@ from heat.engine import properties
 from heat.engine import resources
 from heat.engine import support
 
+_CODE_NAMES = {'2014.1': 'Icehouse',
+               '2014.2': 'Juno',
+               '2015.1': 'Kilo'}
 
 global_env = environment.Environment({}, user_env=False)
 
@@ -35,7 +38,7 @@ class resourcepages(nodes.General, nodes.Element):
     pass
 
 
-class ResourcePages(Directive):
+class ResourcePages(compat.Directive):
     has_content = False
     required_arguments = 0
     optional_arguments = 1
@@ -55,14 +58,7 @@ class ResourcePages(Directive):
             self.attrs_schemata = attributes.schemata(
                 self.resource_class.attributes_schema)
 
-            if resource_class.support_status.status == support.DEPRECATED:
-                sstatus = resource_class.support_status.to_dict()
-                msg = _('%(status)s')
-                if sstatus['message'] is not None:
-                    msg = _('%(status)s - %(message)s')
-                para = nodes.inline('', msg % sstatus)
-                warning = nodes.note('', para)
-                section.append(warning)
+            self._status_str(resource_class.support_status, section)
 
             cls_doc = pydoc.getdoc(resource_class)
             if cls_doc:
@@ -79,6 +75,30 @@ class ResourcePages(Directive):
 
         return content
 
+    def _version_str(self, version):
+        if version in _CODE_NAMES:
+            return _("%(version)s (%(code)s)") % {'version': version,
+                                                  'code': _CODE_NAMES[version]}
+        else:
+            return version
+
+    def _status_str(self, support_status, section):
+        sstatus = support_status.to_dict()
+        if sstatus['status'] is support.SUPPORTED:
+            msg = _('Available')
+        else:
+            msg = sstatus['status']
+        if sstatus['version'] is not None:
+            msg = _('%s since %s') % (msg,
+                                      self._version_str(sstatus['version']))
+        if sstatus['message'] is not None:
+            msg = _('%s - %s') % (msg, sstatus['message'])
+        if not (sstatus['status'] is support.SUPPORTED and
+                sstatus['version'] is None):
+            para = nodes.paragraph(_(''), msg)
+            note = nodes.note(_(''), para)
+            section.append(note)
+
     def _section(self, parent, title, id_pattern):
         id = id_pattern % self.resource_type
         section = nodes.section(ids=[id])
@@ -208,19 +228,12 @@ Resources:
         definition = nodes.definition()
         prop_item.append(definition)
 
-        if prop.support_status.status != support.SUPPORTED:
-            sstatus = prop.support_status.to_dict()
-            msg = _('%(status)s')
-            if sstatus['message'] is not None:
-                msg = _('%(status)s - %(message)s')
-            para = nodes.inline('', msg % sstatus)
-            warning = nodes.note('', para)
-            definition.append(warning)
+        self._status_str(prop.support_status, definition)
 
         if not prop.implemented:
-            para = nodes.inline('', _('Not implemented.'))
-            warning = nodes.note('', para)
-            definition.append(warning)
+            para = nodes.paragraph('', _('Not implemented.'))
+            note = nodes.note('', para)
+            definition.append(note)
             return
 
         if prop.description:
@@ -303,14 +316,7 @@ Resources:
             definition = nodes.definition()
             prop_item.append(definition)
 
-            if prop.support_status.status != support.SUPPORTED:
-                sstatus = prop.support_status.to_dict()
-                msg = _('%(status)s')
-                if sstatus['message'] is not None:
-                    msg = _('%(status)s - %(message)s')
-                para = nodes.inline('', msg % sstatus)
-                warning = nodes.note('', para)
-                definition.append(warning)
+            self._status_str(prop.support_status, definition)
 
             if description:
                 def_para = nodes.paragraph('', description)
