@@ -13,19 +13,18 @@
 
 import hashlib
 
-from oslo.config import cfg
-from oslo.utils import importutils
+from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_serialization import jsonutils as json
+from oslo_utils import importutils
 import requests
 import webob
 
 from heat.api.aws import exception
-from heat.api.aws.exception import HeatAPIException
 from heat.common.i18n import _
 from heat.common.i18n import _LE
 from heat.common.i18n import _LI
 from heat.common import wsgi
-from heat.openstack.common import jsonutils as json
-from heat.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
@@ -40,7 +39,21 @@ opts = [
                 default=[],
                 help=_('Allowed keystone endpoints for auth_uri when '
                        'multi_cloud is enabled. At least one endpoint needs '
-                       'to be specified.'))
+                       'to be specified.')),
+    cfg.StrOpt('cert_file',
+               default=None,
+               help=_('Optional PEM-formatted certificate chain file.')),
+    cfg.StrOpt('key_file',
+               default=None,
+               help=_('Optional PEM-formatted file that contains the '
+                      'private key.')),
+    cfg.StrOpt('ca_file',
+               default=None,
+               help=_('Optional CA cert file to use in SSL connections.')),
+    cfg.BoolOpt('insecure',
+                default=False,
+                help=_('If set, then the server\'s certificate will not '
+                       'be verified.')),
 ]
 cfg.CONF.register_opts(opts, group='ec2authtoken')
 
@@ -51,6 +64,7 @@ class EC2Token(wsgi.Middleware):
     def __init__(self, app, conf):
         self.conf = conf
         self.application = app
+        self._ssl_options = None
 
     def _conf_get(self, name):
         # try config from paste-deploy first
@@ -62,12 +76,14 @@ class EC2Token(wsgi.Middleware):
     def _conf_get_auth_uri(self):
         auth_uri = self._conf_get('auth_uri')
         if auth_uri:
-            return auth_uri
+            return auth_uri.replace('v2.0', 'v3')
         else:
             # Import auth_token to have keystone_authtoken settings setup.
             # We can use the auth_uri from the keystone_authtoken section
             importutils.import_module('keystonemiddleware.auth_token')
-            return cfg.CONF.keystone_authtoken['auth_uri']
+            auth_uri = cfg.CONF.keystone_authtoken['auth_uri']
+            if auth_uri:
+                return auth_uri.replace('v2.0', 'v3')
 
     @staticmethod
     def _conf_get_keystone_ec2_uri(auth_uri):
@@ -127,11 +143,24 @@ class EC2Token(wsgi.Middleware):
                 try:
                     LOG.debug("Attempt authorize on %s" % auth_uri)
                     return self._authorize(req, auth_uri)
-                except HeatAPIException as e:
+                except exception.HeatAPIException as e:
                     LOG.debug("Authorize failed: %s" % e.__class__)
                     last_failure = e
             raise last_failure or exception.HeatAccessDeniedError()
 
+    @property
+    def ssl_options(self):
+        if not self._ssl_options:
+            cacert = self._conf_get('ca_file')
+            insecure = self._conf_get('insecure')
+            cert = self._conf_get('cert_file')
+            key = self._conf_get('key_file')
+            self._ssl_options = {
+                'verify': cacert if cacert else not insecure,
+                'cert': (cert, key) if cert else None
+            }
+        return self._ssl_options
+
     def _authorize(self, req, auth_uri):
         # Read request signature and access id.
         # If we find X-Auth-User in the headers we ignore a key error
@@ -186,13 +215,16 @@ class EC2Token(wsgi.Middleware):
         keystone_ec2_uri = self._conf_get_keystone_ec2_uri(auth_uri)
         LOG.info(_LI('Authenticating with %s'), keystone_ec2_uri)
         response = requests.post(keystone_ec2_uri, data=creds_json,
-                                 headers=headers)
+                                 headers=headers,
+                                 verify=self.ssl_options['verify'],
+                                 cert=self.ssl_options['cert'])
         result = response.json()
         try:
-            token_id = result['access']['token']['id']
-            tenant = result['access']['token']['tenant']['name']
-            tenant_id = result['access']['token']['tenant']['id']
-            LOG.info(_LI("AWS authentication successful."))
+            token_id = response.headers['X-Subject-Token']
+            tenant = result['token']['project']['name']
+            tenant_id = result['token']['project']['id']
+            roles = [role['name']
+                     for role in result['token'].get('roles', [])]
         except (AttributeError, KeyError):
             LOG.info(_LI("AWS authentication failure."))
             # Try to extract the reason for failure so we can return the
@@ -208,6 +240,8 @@ class EC2Token(wsgi.Middleware):
                 raise exception.HeatSignatureError()
             else:
                 raise exception.HeatAccessDeniedError()
+        else:
+            LOG.info(_LI("AWS authentication successful."))
 
         # Authenticated!
         ec2_creds = {'ec2Credentials': {'access': access,
@@ -218,8 +252,6 @@ class EC2Token(wsgi.Middleware):
         req.headers['X-Tenant-Id'] = tenant_id
         req.headers['X-Auth-URL'] = auth_uri
 
-        metadata = result['access'].get('metadata', {})
-        roles = metadata.get('roles', [])
         req.headers['X-Roles'] = ','.join(roles)
 
         return self.application
@@ -236,3 +268,7 @@ def EC2Token_filter_factory(global_conf, **local_conf):
         return EC2Token(app, conf)
 
     return filter
+
+
+def list_opts():
+    yield 'ec2authtoken', opts
