@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -13,21 +11,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-"""
-Controller that returns information on the heat API versions
-"""
+"""Controller that returns information on the heat API versions."""
 
 import httplib
-import json
 
+from oslo_serialization import jsonutils
 import webob.dec
 
 
 class Controller(object):
 
-    """
-    A controller that produces information on the heat API versions.
-    """
+    """A controller that produces information on the heat API versions."""
 
     def __init__(self, conf):
         self.conf = conf
@@ -46,7 +40,7 @@ class Controller(object):
                     }]
             }]
 
-        body = json.dumps(dict(versions=version_objs))
+        body = jsonutils.dumps(dict(versions=version_objs))
 
         response = webob.Response(request=req,
                                   status=httplib.MULTIPLE_CHOICES,
