@@ -15,6 +15,7 @@
 Stack endpoint for Heat v1 ReST API.
 """
 
+from oslo_log import log as logging
 import six
 from six.moves.urllib import parse
 from webob import exc
@@ -22,6 +23,7 @@ from webob import exc
 from heat.api.openstack.v1 import util
 from heat.api.openstack.v1.views import stacks_view
 from heat.common import environment_format
+from heat.common.i18n import _
 from heat.common.i18n import _LW
 from heat.common import identifier
 from heat.common import param_utils
@@ -29,8 +31,7 @@ from heat.common import serializers
 from heat.common import template_format
 from heat.common import urlfetch
 from heat.common import wsgi
-from heat.openstack.common import log as logging
-from heat.rpc import api as engine_api
+from heat.rpc import api as rpc_api
 from heat.rpc import client as rpc_client
 
 LOG = logging.getLogger(__name__)
@@ -65,7 +66,7 @@ class InstantiationData(object):
         """
         self.data = data
         if patch:
-            self.data[engine_api.PARAM_EXISTING] = True
+            self.data[rpc_api.PARAM_EXISTING] = True
 
     @staticmethod
     def format_parse(data, data_type):
@@ -97,19 +98,13 @@ class InstantiationData(object):
         Get template file contents, either inline, from stack adopt data or
         from a URL, in JSON or YAML format.
         """
-        if engine_api.PARAM_ADOPT_STACK_DATA in self.data:
-            adopt_data = self.data[engine_api.PARAM_ADOPT_STACK_DATA]
+        if rpc_api.PARAM_ADOPT_STACK_DATA in self.data:
+            adopt_data = self.data[rpc_api.PARAM_ADOPT_STACK_DATA]
             try:
                 adopt_data = template_format.simple_parse(adopt_data)
-
-                if not isinstance(adopt_data, dict):
-                    raise exc.HTTPBadRequest(
-                        _('Adopt data %s invalid. Adopt data must be a dict.')
-                        % adopt_data)
-
                 return adopt_data['template']
             except (ValueError, KeyError) as ex:
-                err_reason = _('Invalid data: %s') % ex
+                err_reason = _('Invalid adopt data: %s') % ex
                 raise exc.HTTPBadRequest(err_reason)
         elif self.PARAM_TEMPLATE in self.data:
             template_data = self.data[self.PARAM_TEMPLATE]
@@ -195,15 +190,20 @@ class StackController(object):
         filter_params = util.get_allowed_params(req.params, filter_whitelist)
 
         show_deleted = False
-        if engine_api.PARAM_SHOW_DELETED in params:
-            params[engine_api.PARAM_SHOW_DELETED] = param_utils.extract_bool(
-                params[engine_api.PARAM_SHOW_DELETED])
-            show_deleted = params[engine_api.PARAM_SHOW_DELETED]
+        if rpc_api.PARAM_SHOW_DELETED in params:
+            params[rpc_api.PARAM_SHOW_DELETED] = param_utils.extract_bool(
+                params[rpc_api.PARAM_SHOW_DELETED])
+            show_deleted = params[rpc_api.PARAM_SHOW_DELETED]
         show_nested = False
-        if engine_api.PARAM_SHOW_NESTED in params:
-            params[engine_api.PARAM_SHOW_NESTED] = param_utils.extract_bool(
-                params[engine_api.PARAM_SHOW_NESTED])
-            show_nested = params[engine_api.PARAM_SHOW_NESTED]
+        if rpc_api.PARAM_SHOW_NESTED in params:
+            params[rpc_api.PARAM_SHOW_NESTED] = param_utils.extract_bool(
+                params[rpc_api.PARAM_SHOW_NESTED])
+            show_nested = params[rpc_api.PARAM_SHOW_NESTED]
+
+        key = rpc_api.PARAM_LIMIT
+        if key in params:
+            params[key] = param_utils.extract_int(key, params[key])
+
         # get the with_count value, if invalid, raise ValueError
         with_count = False
         if req.params.get('with_count'):
@@ -243,7 +243,11 @@ class StackController(object):
         """
         Lists summary information for all stacks
         """
-        global_tenant = bool(req.params.get('global_tenant', False))
+        global_tenant = False
+        if rpc_api.PARAM_GLOBAL_TENANT in req.params:
+            global_tenant = param_utils.extract_bool(
+                req.params.get(rpc_api.PARAM_GLOBAL_TENANT))
+
         if global_tenant:
             return self.global_index(req, req.context.tenant_id)
 
@@ -283,16 +287,21 @@ class StackController(object):
         """
         data = InstantiationData(body)
 
+        args = data.args()
+        key = rpc_api.PARAM_TIMEOUT
+        if key in args:
+            args[key] = param_utils.extract_int(key, args[key])
+
         result = self.rpc_client.create_stack(req.context,
                                               data.stack_name(),
                                               data.template(),
                                               data.environment(),
                                               data.files(),
-                                              data.args())
+                                              args)
 
         formatted_stack = stacks_view.format_stack(
             req,
-            {engine_api.STACK_ID: result}
+            {rpc_api.STACK_ID: result}
         )
         return {'stack': formatted_stack}
 
@@ -355,12 +364,17 @@ class StackController(object):
         """
         data = InstantiationData(body)
 
+        args = data.args()
+        key = rpc_api.PARAM_TIMEOUT
+        if key in args:
+            args[key] = param_utils.extract_int(key, args[key])
+
         self.rpc_client.update_stack(req.context,
                                      identity,
                                      data.template(),
                                      data.environment(),
                                      data.files(),
-                                     data.args())
+                                     args)
 
         raise exc.HTTPAccepted()
 
@@ -371,12 +385,18 @@ class StackController(object):
         Add the flag patch to the args so the engine code can distinguish
         """
         data = InstantiationData(body, patch=True)
+
+        args = data.args()
+        key = rpc_api.PARAM_TIMEOUT
+        if key in args:
+            args[key] = param_utils.extract_int(key, args[key])
+
         self.rpc_client.update_stack(req.context,
                                      identity,
                                      data.template(),
                                      data.environment(),
                                      data.files(),
-                                     data.args())
+                                     args)
 
         raise exc.HTTPAccepted()
 
@@ -469,6 +489,11 @@ class StackController(object):
                 req.context, identity)
         }
 
+    @util.identified_stack
+    def restore_snapshot(self, req, identity, snapshot_id):
+        self.rpc_client.stack_restore(req.context, identity, snapshot_id)
+        raise exc.HTTPAccepted()
+
 
 class StackSerializer(serializers.JSONResponseSerializer):
     """Handles serialization of specific controller method responses."""
