@@ -14,15 +14,17 @@
 import base64
 
 from Crypto.Cipher import AES
-from oslo.config import cfg
+from oslo_config import cfg
 
 from heat.openstack.common.crypto import utils
 
 
 auth_opts = [
     cfg.StrOpt('auth_encryption_key',
-               default='notgood but just long enough i think',
-               help="Encryption key used for authentication info in database.")
+               secret=True,
+               default='notgood but just long enough i t',
+               help="Key used to encrypt authentication info in the database. "
+                    "Length of this key must be 16, 24 or 32 characters.")
 ]
 
 cfg.CONF.register_opts(auth_opts)
@@ -61,3 +63,7 @@ def heat_decrypt(auth_info):
     cipher = AES.new(cfg.CONF.auth_encryption_key[:32], AES.MODE_CFB, iv)
     res = cipher.decrypt(auth[AES.block_size:])
     return res
+
+
+def list_opts():
+    yield None, auth_opts
