@@ -1,4 +1,3 @@
-
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -25,21 +24,19 @@ The underlying driver is loaded . SQLAlchemy is currently the only
 supported backend.
 '''
 
-from oslo.config import cfg
-
-from heat.openstack.common.db import api as db_api
-
-db_opts = [
-    cfg.StrOpt('db_backend',
-               default='sqlalchemy',
-               help='The backend to use for db.')]
+from oslo_config import cfg
+from oslo_db import api
 
 CONF = cfg.CONF
-CONF.register_opts(db_opts)
+
 
 _BACKEND_MAPPING = {'sqlalchemy': 'heat.db.sqlalchemy.api'}
 
-IMPL = db_api.DBAPI(backend_mapping=_BACKEND_MAPPING)
+IMPL = api.DBAPI.from_config(CONF, backend_mapping=_BACKEND_MAPPING)
+
+
+def get_engine():
+    return IMPL.get_engine()
 
 
 def get_session():
@@ -54,8 +51,12 @@ def raw_template_create(context, values):
     return IMPL.raw_template_create(context, values)
 
 
-def resource_data_get_all(resource):
-    return IMPL.resource_data_get_all(resource)
+def raw_template_update(context, template_id, values):
+    return IMPL.raw_template_update(context, template_id, values)
+
+
+def resource_data_get_all(resource, data=None):
+    return IMPL.resource_data_get_all(resource, data)
 
 
 def resource_data_get(resource, key):
@@ -83,6 +84,12 @@ def resource_get_all(context):
     return IMPL.resource_get_all(context)
 
 
+def resource_update(context, resource_id, values, atomic_key,
+                    expected_engine_id=None):
+    return IMPL.resource_update(context, resource_id, values, atomic_key,
+                                expected_engine_id)
+
+
 def resource_create(context, values):
     return IMPL.resource_create(context, values)
 
@@ -105,9 +112,11 @@ def resource_get_by_physical_resource_id(context, physical_resource_id):
                                                      physical_resource_id)
 
 
-def stack_get(context, stack_id, show_deleted=False, tenant_safe=True):
+def stack_get(context, stack_id, show_deleted=False, tenant_safe=True,
+              eager_load=False):
     return IMPL.stack_get(context, stack_id, show_deleted=show_deleted,
-                          tenant_safe=tenant_safe)
+                          tenant_safe=tenant_safe,
+                          eager_load=eager_load)
 
 
 def stack_get_by_name_and_owner_id(context, stack_name, owner_id):
@@ -120,18 +129,23 @@ def stack_get_by_name(context, stack_name):
 
 
 def stack_get_all(context, limit=None, sort_keys=None, marker=None,
-                  sort_dir=None, filters=None, tenant_safe=True):
+                  sort_dir=None, filters=None, tenant_safe=True,
+                  show_deleted=False, show_nested=False):
     return IMPL.stack_get_all(context, limit, sort_keys,
-                              marker, sort_dir, filters, tenant_safe)
+                              marker, sort_dir, filters, tenant_safe,
+                              show_deleted, show_nested)
 
 
 def stack_get_all_by_owner_id(context, owner_id):
     return IMPL.stack_get_all_by_owner_id(context, owner_id)
 
 
-def stack_count_all(context, filters=None, tenant_safe=True):
+def stack_count_all(context, filters=None, tenant_safe=True,
+                    show_deleted=False, show_nested=False):
     return IMPL.stack_count_all(context, filters=filters,
-                                tenant_safe=tenant_safe)
+                                tenant_safe=tenant_safe,
+                                show_deleted=show_deleted,
+                                show_nested=show_nested)
 
 
 def stack_create(context, values):
@@ -150,6 +164,10 @@ def stack_lock_create(stack_id, engine_id):
     return IMPL.stack_lock_create(stack_id, engine_id)
 
 
+def stack_lock_get_engine_id(stack_id):
+    return IMPL.stack_lock_get_engine_id(stack_id)
+
+
 def stack_lock_steal(stack_id, old_engine_id, new_engine_id):
     return IMPL.stack_lock_steal(stack_id, old_engine_id, new_engine_id)
 
@@ -158,6 +176,14 @@ def stack_lock_release(stack_id, engine_id):
     return IMPL.stack_lock_release(stack_id, engine_id)
 
 
+def stack_get_root_id(context, stack_id):
+    return IMPL.stack_get_root_id(context, stack_id)
+
+
+def stack_count_total_resources(context, stack_id):
+    return IMPL.stack_count_total_resources(context, stack_id)
+
+
 def user_creds_create(context):
     return IMPL.user_creds_create(context)
 
@@ -178,12 +204,24 @@ def event_get_all(context):
     return IMPL.event_get_all(context)
 
 
-def event_get_all_by_tenant(context):
-    return IMPL.event_get_all_by_tenant(context)
+def event_get_all_by_tenant(context, limit=None, marker=None,
+                            sort_keys=None, sort_dir=None, filters=None):
+    return IMPL.event_get_all_by_tenant(context,
+                                        limit=limit,
+                                        marker=marker,
+                                        sort_keys=sort_keys,
+                                        sort_dir=sort_dir,
+                                        filters=filters)
 
 
-def event_get_all_by_stack(context, stack_id):
-    return IMPL.event_get_all_by_stack(context, stack_id)
+def event_get_all_by_stack(context, stack_id, limit=None, marker=None,
+                           sort_keys=None, sort_dir=None, filters=None):
+    return IMPL.event_get_all_by_stack(context, stack_id,
+                                       limit=limit,
+                                       marker=marker,
+                                       sort_keys=sort_keys,
+                                       sort_dir=sort_dir,
+                                       filters=filters)
 
 
 def event_count_all_by_stack(context, stack_id):
@@ -230,6 +268,10 @@ def watch_data_get_all(context):
     return IMPL.watch_data_get_all(context)
 
 
+def watch_data_get_all_by_watch_rule_id(context, watch_rule_id):
+    return IMPL.watch_data_get_all_by_watch_rule_id(context, watch_rule_id)
+
+
 def software_config_create(context, values):
     return IMPL.software_config_create(context, values)
 
@@ -262,11 +304,78 @@ def software_deployment_delete(context, deployment_id):
     return IMPL.software_deployment_delete(context, deployment_id)
 
 
-def db_sync(version=None):
+def snapshot_create(context, values):
+    return IMPL.snapshot_create(context, values)
+
+
+def snapshot_get(context, snapshot_id):
+    return IMPL.snapshot_get(context, snapshot_id)
+
+
+def snapshot_update(context, snapshot_id, values):
+    return IMPL.snapshot_update(context, snapshot_id, values)
+
+
+def snapshot_delete(context, snapshot_id):
+    return IMPL.snapshot_delete(context, snapshot_id)
+
+
+def snapshot_get_all(context, stack_id):
+    return IMPL.snapshot_get_all(context, stack_id)
+
+
+def service_create(context, values):
+    return IMPL.service_create(context, values)
+
+
+def service_update(context, service_id, values):
+    return IMPL.service_update(context, service_id, values)
+
+
+def service_delete(context, service_id, soft_delete=True):
+    return IMPL.service_delete(context, service_id, soft_delete)
+
+
+def service_get(context, service_id):
+    return IMPL.service_get(context, service_id)
+
+
+def service_get_all(context):
+    return IMPL.service_get_all(context)
+
+
+def service_get_all_by_args(context, host, binary, hostname):
+    return IMPL.service_get_all_by_args(context, host, binary, hostname)
+
+
+def sync_point_delete_all_by_stack_and_traversal(context, stack_id,
+                                                 traversal_id):
+    return IMPL.sync_point_delete_all_by_stack_and_traversal(context,
+                                                             stack_id,
+                                                             traversal_id)
+
+
+def sync_point_create(context, values):
+    return IMPL.sync_point_create(context, values)
+
+
+def sync_point_get(context, entity_id, traversal_id, is_update):
+    return IMPL.sync_point_get(context, entity_id, traversal_id, is_update)
+
+
+def sync_point_update_input_data(context, entity_id,
+                                 traversal_id, is_update, atomic_key,
+                                 input_data):
+    return IMPL.sync_point_update_input_data(context, entity_id,
+                                             traversal_id, is_update,
+                                             atomic_key, input_data)
+
+
+def db_sync(engine, version=None):
     """Migrate the database to `version` or the most recent version."""
-    return IMPL.db_sync(version=version)
+    return IMPL.db_sync(engine, version=version)
 
 
-def db_version():
+def db_version(engine):
     """Display the current database version."""
-    return IMPL.db_version()
+    return IMPL.db_version(engine)
