@@ -15,7 +15,7 @@ import itertools
 import uuid
 
 import migrate.changeset.constraint as constraint
-from oslo.utils import timeutils
+from oslo_utils import timeutils
 import sqlalchemy
 
 
@@ -27,8 +27,15 @@ def upgrade(migrate_engine):
     meta = sqlalchemy.MetaData(bind=migrate_engine)
 
     event_table = sqlalchemy.Table('event', meta, autoload=True)
+    event_uuid_column_kwargs = {}
+    if migrate_engine.name == 'ibm_db_sa':
+        # NOTE(mriedem): DB2 10.5 doesn't support unique constraints over
+        # nullable columns, it creates a unique index instead, so we have
+        # to make the uuid column non-nullable in the DB2 case.
+        event_uuid_column_kwargs['nullable'] = False
     event_uuid = sqlalchemy.Column('uuid', sqlalchemy.String(length=36),
-                                   default=lambda: str(uuid.uuid4))
+                                   default=lambda: str(uuid.uuid4),
+                                   **event_uuid_column_kwargs)
     event_table.create_column(event_uuid)
 
     if migrate_engine.name == 'postgresql':
@@ -39,7 +46,13 @@ def upgrade(migrate_engine):
                                      server_default=sqlalchemy.text(
                                          "nextval('evt')"))
     else:
-        event_id = sqlalchemy.Column('tmp_id', sqlalchemy.Integer)
+        event_id_column_kwargs = {}
+        if migrate_engine.name == 'ibm_db_sa':
+            # NOTE(mriedem): This is turned into a primary key constraint
+            # later so it must be non-nullable.
+            event_id_column_kwargs['nullable'] = False
+        event_id = sqlalchemy.Column('tmp_id', sqlalchemy.Integer,
+                                     **event_id_column_kwargs)
     event_table.create_column(event_id)
 
     fake_autoincrement = itertools.count(1)
@@ -53,27 +66,43 @@ def upgrade(migrate_engine):
             event_table.c.id == event.id).values(values)
         migrate_engine.execute(update)
 
-    cons = constraint.UniqueConstraint('uuid', table=event_table)
+    constraint_kwargs = {'table': event_table}
+    if migrate_engine.name == 'ibm_db_sa':
+        # NOTE(mriedem): DB2 gives a random name to the unique constraint
+        # if one is not provided so let's set the standard name ourselves.
+        constraint_kwargs['name'] = 'uniq_event0uuid0'
+    cons = constraint.UniqueConstraint('uuid', **constraint_kwargs)
     cons.create()
 
     event_table.c.id.drop()
 
-    event_table.c.tmp_id.alter('id', sqlalchemy.Integer)
+    alter_kwargs = {}
+    if migrate_engine.name == 'ibm_db_sa':
+        alter_kwargs['nullable'] = False
+    event_table.c.tmp_id.alter('id', sqlalchemy.Integer, **alter_kwargs)
 
     cons = constraint.PrimaryKeyConstraint('tmp_id', table=event_table)
     cons.create()
 
-    event_table.c.tmp_id.alter(sqlalchemy.Integer, autoincrement=True)
+    if migrate_engine.name == 'ibm_db_sa':
+        # NOTE(chenxiao): For DB2, setting "ID" column "autoincrement=True"
+        # can't make sense after above "tmp_id=>id" transformation,
+        # so should work around it.
+        sql = ("ALTER TABLE EVENT ALTER COLUMN ID SET GENERATED BY "
+               "DEFAULT AS IDENTITY (START WITH 1, INCREMENT BY 1)")
+        migrate_engine.execute(sql)
+    else:
+        event_table.c.tmp_id.alter(sqlalchemy.Integer, autoincrement=True)
 
 
 def upgrade_sqlite(migrate_engine):
     meta = sqlalchemy.MetaData(bind=migrate_engine)
 
-    #(pafuent) Here it isn't recommended to import the table from the models,
-    #because in future migrations the model could change and this migration
-    #could fail.
-    #I know it is ugly but it's the only way that I found to 'freeze' the model
-    #state for this migration.
+    # (pafuent) Here it isn't recommended to import the table from the models,
+    # because in future migrations the model could change and this migration
+    # could fail.
+    # I know it is ugly but it's the only way that I found to 'freeze'
+    # the model state for this migration.
     stack_table = sqlalchemy.Table('stack', meta, autoload=True)
     event_table = sqlalchemy.Table(
         'new_event', meta,
@@ -127,8 +156,13 @@ def downgrade(migrate_engine):
 
     event_table = sqlalchemy.Table('event', meta, autoload=True)
 
+    event_id_column_kwargs = {}
+    if migrate_engine.name == 'ibm_db_sa':
+        event_id_column_kwargs['nullable'] = False
+
     event_id = sqlalchemy.Column('tmp_id', sqlalchemy.String(length=36),
-                                 default=lambda: str(uuid.uuid4))
+                                 default=lambda: str(uuid.uuid4),
+                                 **event_id_column_kwargs)
     event_id.create(event_table)
 
     event_list = event_table.select().execute()
@@ -144,7 +178,13 @@ def downgrade(migrate_engine):
     cons = constraint.PrimaryKeyConstraint('tmp_id', table=event_table)
     cons.create()
 
-    event_table.c.tmp_id.alter('id', default=lambda: str(uuid.uuid4))
+    alter_kwargs = {}
+    # NOTE(mriedem): DB2 won't allow a primary key on a nullable column so
+    # we have to make it non-nullable.
+    if migrate_engine.name == 'ibm_db_sa':
+        alter_kwargs['nullable'] = False
+    event_table.c.tmp_id.alter('id', default=lambda: str(uuid.uuid4),
+                               **alter_kwargs)
     if migrate_engine.name == 'postgresql':
         sequence = sqlalchemy.Sequence('evt')
         sqlalchemy.schema.DropSequence(sequence, bind=migrate_engine).execute()
@@ -153,11 +193,11 @@ def downgrade(migrate_engine):
 def downgrade_sqlite(migrate_engine):
     meta = sqlalchemy.MetaData(bind=migrate_engine)
 
-    #(pafuent) Here it isn't recommended to import the table from the models,
-    #because in future migrations the model could change and this migration
-    #could fail.
-    #I know it is ugly but it's the only way that I found to 'freeze' the model
-    #state for this migration.
+    # (pafuent) Here it isn't recommended to import the table from the models,
+    # because in future migrations the model could change and this migration
+    # could fail.
+    # I know it is ugly but it's the only way that I found to 'freeze'
+    # the model state for this migration.
     stack_table = sqlalchemy.Table('stack', meta, autoload=True)
     event_table = sqlalchemy.Table(
         'new_event', meta,
