@@ -16,18 +16,18 @@ SQLAlchemy models for heat data.
 
 import uuid
 
-from oslo.db.sqlalchemy import models
-from oslo.utils import timeutils
+from oslo_db.sqlalchemy import models
+from oslo_utils import timeutils
 import six
 import sqlalchemy
-from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy.ext import declarative
 from sqlalchemy.orm import backref
 from sqlalchemy.orm import relationship
-from sqlalchemy.orm.session import Session
+from sqlalchemy.orm import session as orm_session
 
-from heat.db.sqlalchemy.types import Json
+from heat.db.sqlalchemy import types
 
-BASE = declarative_base()
+BASE = declarative.declarative_base()
 
 
 def get_session():
@@ -42,7 +42,7 @@ class HeatBase(models.ModelBase, models.TimestampMixin):
     def expire(self, session=None, attrs=None):
         """Expire this object ()."""
         if not session:
-            session = Session.object_session(self)
+            session = orm_session.Session.object_session(self)
             if not session:
                 session = get_session()
         session.expire(self, attrs)
@@ -50,7 +50,7 @@ class HeatBase(models.ModelBase, models.TimestampMixin):
     def refresh(self, session=None, attrs=None):
         """Refresh this object."""
         if not session:
-            session = Session.object_session(self)
+            session = orm_session.Session.object_session(self)
             if not session:
                 session = get_session()
         session.refresh(self, attrs)
@@ -58,7 +58,7 @@ class HeatBase(models.ModelBase, models.TimestampMixin):
     def delete(self, session=None):
         """Delete this object."""
         if not session:
-            session = Session.object_session(self)
+            session = orm_session.Session.object_session(self)
             if not session:
                 session = get_session()
         session.begin()
@@ -67,7 +67,7 @@ class HeatBase(models.ModelBase, models.TimestampMixin):
 
     def update_and_save(self, values, session=None):
         if not session:
-            session = Session.object_session(self)
+            session = orm_session.Session.object_session(self)
             if not session:
                 session = get_session()
         session.begin()
@@ -86,18 +86,9 @@ class SoftDelete(object):
 
 
 class StateAware(object):
-
     action = sqlalchemy.Column('action', sqlalchemy.String(255))
     status = sqlalchemy.Column('status', sqlalchemy.String(255))
-    _status_reason = sqlalchemy.Column('status_reason', sqlalchemy.String(255))
-
-    @property
-    def status_reason(self):
-        return self._status_reason
-
-    @status_reason.setter
-    def status_reason(self, reason):
-        self._status_reason = reason and reason[:255] or ''
+    status_reason = sqlalchemy.Column('status_reason', sqlalchemy.Text)
 
 
 class RawTemplate(BASE, HeatBase):
@@ -105,14 +96,57 @@ class RawTemplate(BASE, HeatBase):
 
     __tablename__ = 'raw_template'
     id = sqlalchemy.Column(sqlalchemy.Integer, primary_key=True)
-    template = sqlalchemy.Column(Json)
-    files = sqlalchemy.Column(Json)
+    template = sqlalchemy.Column(types.Json)
+    files = sqlalchemy.Column(types.Json)
+    environment = sqlalchemy.Column('environment', types.Json)
+    predecessor = sqlalchemy.Column('predecessor', sqlalchemy.Integer,
+                                    sqlalchemy.ForeignKey('raw_template.id'))
+
+
+class StackTag(BASE, HeatBase):
+    """Key/value store of arbitrary stack tags."""
+
+    __tablename__ = 'stack_tag'
+
+    id = sqlalchemy.Column('id',
+                           sqlalchemy.Integer,
+                           primary_key=True,
+                           nullable=False)
+    tag = sqlalchemy.Column('tag', sqlalchemy.Unicode(80))
+    stack_id = sqlalchemy.Column('stack_id',
+                                 sqlalchemy.String(36),
+                                 sqlalchemy.ForeignKey('stack.id'),
+                                 nullable=False)
+
+
+class SyncPoint(BASE, HeatBase):
+    """Represents an syncpoint for an stack that is being worked on."""
+    __tablename__ = 'sync_point'
+    __table_args__ = (
+        sqlalchemy.PrimaryKeyConstraint('entity_id',
+                                        'traversal_id',
+                                        'is_update'),
+        sqlalchemy.ForeignKeyConstraint(['stack_id'], ['stack.id'])
+    )
+
+    entity_id = sqlalchemy.Column(sqlalchemy.String(36))
+    traversal_id = sqlalchemy.Column(sqlalchemy.String(36))
+    is_update = sqlalchemy.Column(sqlalchemy.Boolean)
+    # integer field for atomic update operations
+    atomic_key = sqlalchemy.Column(sqlalchemy.Integer, nullable=False)
+    stack_id = sqlalchemy.Column(sqlalchemy.String(36),
+                                 nullable=False)
+    input_data = sqlalchemy.Column(types.Json)
 
 
 class Stack(BASE, HeatBase, SoftDelete, StateAware):
     """Represents a stack created by the heat engine."""
 
     __tablename__ = 'stack'
+    __table_args__ = (
+        sqlalchemy.Index('ix_stack_name', 'name', mysql_length=255),
+        sqlalchemy.Index('ix_stack_tenant', 'tenant', mysql_length=255),
+    )
 
     id = sqlalchemy.Column(sqlalchemy.String(36), primary_key=True,
                            default=lambda: str(uuid.uuid4()))
@@ -121,20 +155,32 @@ class Stack(BASE, HeatBase, SoftDelete, StateAware):
         sqlalchemy.Integer,
         sqlalchemy.ForeignKey('raw_template.id'),
         nullable=False)
-    raw_template = relationship(RawTemplate, backref=backref('stack'))
+    raw_template = relationship(RawTemplate, backref=backref('stack'),
+                                foreign_keys=[raw_template_id])
+    prev_raw_template_id = sqlalchemy.Column(
+        'prev_raw_template_id',
+        sqlalchemy.Integer,
+        sqlalchemy.ForeignKey('raw_template.id'))
+    prev_raw_template = relationship(RawTemplate,
+                                     foreign_keys=[prev_raw_template_id])
     username = sqlalchemy.Column(sqlalchemy.String(256))
     tenant = sqlalchemy.Column(sqlalchemy.String(256))
-    parameters = sqlalchemy.Column('parameters', Json)
     user_creds_id = sqlalchemy.Column(
         sqlalchemy.Integer,
-        sqlalchemy.ForeignKey('user_creds.id'),
-        nullable=False)
-    owner_id = sqlalchemy.Column(sqlalchemy.String(36), nullable=True)
+        sqlalchemy.ForeignKey('user_creds.id'))
+    owner_id = sqlalchemy.Column(sqlalchemy.String(36))
+    parent_resource_name = sqlalchemy.Column(sqlalchemy.String(255))
     timeout = sqlalchemy.Column(sqlalchemy.Integer)
     disable_rollback = sqlalchemy.Column(sqlalchemy.Boolean, nullable=False)
-    stack_user_project_id = sqlalchemy.Column(sqlalchemy.String(64),
-                                              nullable=True)
+    stack_user_project_id = sqlalchemy.Column(sqlalchemy.String(64))
     backup = sqlalchemy.Column('backup', sqlalchemy.Boolean)
+    nested_depth = sqlalchemy.Column('nested_depth', sqlalchemy.Integer)
+    convergence = sqlalchemy.Column('convergence', sqlalchemy.Boolean)
+    tags = relationship(StackTag, cascade="all,delete",
+                        backref=backref('stack'))
+    current_traversal = sqlalchemy.Column('current_traversal',
+                                          sqlalchemy.String(36))
+    current_deps = sqlalchemy.Column('current_deps', types.Json)
 
     # Override timestamp column to store the correct value: it should be the
     # time the create/update call was issued, not the time the DB entry is
@@ -164,9 +210,10 @@ class UserCreds(BASE, HeatBase):
     id = sqlalchemy.Column(sqlalchemy.Integer, primary_key=True)
     username = sqlalchemy.Column(sqlalchemy.String(255))
     password = sqlalchemy.Column(sqlalchemy.String(255))
+    region_name = sqlalchemy.Column(sqlalchemy.String(255))
     decrypt_method = sqlalchemy.Column(sqlalchemy.String(64))
     tenant = sqlalchemy.Column(sqlalchemy.String(1024))
-    auth_url = sqlalchemy.Column(sqlalchemy.String)
+    auth_url = sqlalchemy.Column(sqlalchemy.Text)
     tenant_id = sqlalchemy.Column(sqlalchemy.String(256))
     trust_id = sqlalchemy.Column(sqlalchemy.String(255))
     trustor_user_id = sqlalchemy.Column(sqlalchemy.String(64))
@@ -215,11 +262,11 @@ class ResourceData(BASE, HeatBase):
                            primary_key=True,
                            nullable=False)
     key = sqlalchemy.Column('key', sqlalchemy.String(255))
-    value = sqlalchemy.Column('value', sqlalchemy.String)
+    value = sqlalchemy.Column('value', sqlalchemy.Text)
     redact = sqlalchemy.Column('redact', sqlalchemy.Boolean)
     decrypt_method = sqlalchemy.Column(sqlalchemy.String(64))
     resource_id = sqlalchemy.Column('resource_id',
-                                    sqlalchemy.String(36),
+                                    sqlalchemy.Integer,
                                     sqlalchemy.ForeignKey('resource.id'),
                                     nullable=False)
 
@@ -229,13 +276,14 @@ class Resource(BASE, HeatBase, StateAware):
 
     __tablename__ = 'resource'
 
-    id = sqlalchemy.Column(sqlalchemy.String(36),
-                           primary_key=True,
-                           default=lambda: str(uuid.uuid4()))
-    name = sqlalchemy.Column('name', sqlalchemy.String(255), nullable=True)
+    id = sqlalchemy.Column(sqlalchemy.Integer, primary_key=True)
+    uuid = sqlalchemy.Column(sqlalchemy.String(36),
+                             default=lambda: str(uuid.uuid4()),
+                             unique=True)
+    name = sqlalchemy.Column('name', sqlalchemy.String(255))
     nova_instance = sqlalchemy.Column('nova_instance', sqlalchemy.String(255))
     # odd name as "metadata" is reserved
-    rsrc_metadata = sqlalchemy.Column('rsrc_metadata', Json)
+    rsrc_metadata = sqlalchemy.Column('rsrc_metadata', types.Json)
 
     stack_id = sqlalchemy.Column(sqlalchemy.String(36),
                                  sqlalchemy.ForeignKey('stack.id'),
@@ -249,7 +297,20 @@ class Resource(BASE, HeatBase, StateAware):
     # time the create/update call was issued, not the time the DB entry is
     # created/modified. (bug #1193269)
     updated_at = sqlalchemy.Column(sqlalchemy.DateTime)
-    properties_data = sqlalchemy.Column('properties_data', Json)
+    properties_data = sqlalchemy.Column('properties_data', types.Json)
+    engine_id = sqlalchemy.Column(sqlalchemy.String(36))
+    atomic_key = sqlalchemy.Column(sqlalchemy.Integer)
+
+    needed_by = sqlalchemy.Column('needed_by', types.List)
+    requires = sqlalchemy.Column('requires', types.List)
+    replaces = sqlalchemy.Column('replaces', sqlalchemy.Integer,
+                                 default=None)
+    replaced_by = sqlalchemy.Column('replaced_by', sqlalchemy.Integer,
+                                    default=None)
+    current_template_id = sqlalchemy.Column(
+        'current_template_id',
+        sqlalchemy.Integer,
+        sqlalchemy.ForeignKey('raw_template.id'))
 
 
 class WatchRule(BASE, HeatBase):
@@ -258,8 +319,8 @@ class WatchRule(BASE, HeatBase):
     __tablename__ = 'watch_rule'
 
     id = sqlalchemy.Column(sqlalchemy.Integer, primary_key=True)
-    name = sqlalchemy.Column('name', sqlalchemy.String(255), nullable=True)
-    rule = sqlalchemy.Column('rule', Json)
+    name = sqlalchemy.Column('name', sqlalchemy.String(255))
+    rule = sqlalchemy.Column('rule', types.Json)
     state = sqlalchemy.Column('state', sqlalchemy.String(255))
     last_evaluated = sqlalchemy.Column(sqlalchemy.DateTime,
                                        default=timeutils.utcnow)
@@ -276,7 +337,7 @@ class WatchData(BASE, HeatBase):
     __tablename__ = 'watch_data'
 
     id = sqlalchemy.Column(sqlalchemy.Integer, primary_key=True)
-    data = sqlalchemy.Column('data', Json)
+    data = sqlalchemy.Column('data', types.Json)
 
     watch_rule_id = sqlalchemy.Column(
         sqlalchemy.Integer,
@@ -295,12 +356,11 @@ class SoftwareConfig(BASE, HeatBase):
 
     id = sqlalchemy.Column('id', sqlalchemy.String(36), primary_key=True,
                            default=lambda: str(uuid.uuid4()))
-    name = sqlalchemy.Column('name', sqlalchemy.String(255),
-                             nullable=True)
+    name = sqlalchemy.Column('name', sqlalchemy.String(255))
     group = sqlalchemy.Column('group', sqlalchemy.String(255))
-    config = sqlalchemy.Column('config', Json)
+    config = sqlalchemy.Column('config', types.Json)
     tenant = sqlalchemy.Column(
-        'tenant', sqlalchemy.String(64), nullable=False)
+        'tenant', sqlalchemy.String(64), nullable=False, index=True)
 
 
 class SoftwareDeployment(BASE, HeatBase, StateAware):
@@ -310,6 +370,8 @@ class SoftwareDeployment(BASE, HeatBase, StateAware):
     """
 
     __tablename__ = 'software_deployment'
+    __table_args__ = (
+        sqlalchemy.Index('ix_software_deployment_created_at', 'created_at'),)
 
     id = sqlalchemy.Column('id', sqlalchemy.String(36), primary_key=True,
                            default=lambda: str(uuid.uuid4()))
@@ -320,13 +382,13 @@ class SoftwareDeployment(BASE, HeatBase, StateAware):
         nullable=False)
     config = relationship(SoftwareConfig, backref=backref('deployments'))
     server_id = sqlalchemy.Column('server_id', sqlalchemy.String(36),
-                                  nullable=False)
-    input_values = sqlalchemy.Column('input_values', Json)
-    output_values = sqlalchemy.Column('output_values', Json)
+                                  nullable=False, index=True)
+    input_values = sqlalchemy.Column('input_values', types.Json)
+    output_values = sqlalchemy.Column('output_values', types.Json)
     tenant = sqlalchemy.Column(
-        'tenant', sqlalchemy.String(64), nullable=False)
-    stack_user_project_id = sqlalchemy.Column(sqlalchemy.String(64),
-                                              nullable=True)
+        'tenant', sqlalchemy.String(64), nullable=False, index=True)
+    stack_user_project_id = sqlalchemy.Column(sqlalchemy.String(64))
+    updated_at = sqlalchemy.Column(sqlalchemy.DateTime)
 
 
 class Snapshot(BASE, HeatBase):
@@ -338,10 +400,38 @@ class Snapshot(BASE, HeatBase):
     stack_id = sqlalchemy.Column(sqlalchemy.String(36),
                                  sqlalchemy.ForeignKey('stack.id'),
                                  nullable=False)
-    name = sqlalchemy.Column('name', sqlalchemy.String(255), nullable=True)
-    data = sqlalchemy.Column('data', Json)
+    name = sqlalchemy.Column('name', sqlalchemy.String(255))
+    data = sqlalchemy.Column('data', types.Json)
     tenant = sqlalchemy.Column(
-        'tenant', sqlalchemy.String(64), nullable=False)
+        'tenant', sqlalchemy.String(64), nullable=False, index=True)
     status = sqlalchemy.Column('status', sqlalchemy.String(255))
     status_reason = sqlalchemy.Column('status_reason', sqlalchemy.String(255))
     stack = relationship(Stack, backref=backref('snapshot'))
+
+
+class Service(BASE, HeatBase, SoftDelete):
+
+    __tablename__ = 'service'
+
+    id = sqlalchemy.Column('id',
+                           sqlalchemy.String(36),
+                           primary_key=True,
+                           default=lambda: str(uuid.uuid4()))
+    engine_id = sqlalchemy.Column('engine_id',
+                                  sqlalchemy.String(36),
+                                  nullable=False)
+    host = sqlalchemy.Column('host',
+                             sqlalchemy.String(255),
+                             nullable=False)
+    hostname = sqlalchemy.Column('hostname',
+                                 sqlalchemy.String(255),
+                                 nullable=False)
+    binary = sqlalchemy.Column('binary',
+                               sqlalchemy.String(255),
+                               nullable=False)
+    topic = sqlalchemy.Column('topic',
+                              sqlalchemy.String(255),
+                              nullable=False)
+    report_interval = sqlalchemy.Column('report_interval',
+                                        sqlalchemy.Integer,
+                                        nullable=False)
