@@ -15,10 +15,11 @@ import collections
 import numbers
 import re
 
-from oslo.utils import strutils
+from oslo_utils import strutils
 import six
 
 from heat.common import exception
+from heat.common.i18n import _
 from heat.engine import resources
 
 
@@ -108,12 +109,11 @@ class Schema(collections.Mapping):
         self.default = default
 
     def validate(self, context=None):
-        '''
-        Validates the schema.
+        """Validates the schema.
 
         This method checks if the schema itself is valid, and if the
         default value - if present - complies to the schema's constraints.
-        '''
+        """
         for c in self.constraints:
             if not self._is_valid_constraint(c):
                 err_msg = _('%(name)s constraint '
@@ -134,7 +134,8 @@ class Schema(collections.Mapping):
     def _validate_default(self, context):
         if self.default is not None:
             try:
-                self.validate_constraints(self.default, context)
+                self.validate_constraints(self.default, context,
+                                          [CustomConstraint])
             except (ValueError, TypeError) as exc:
                 raise exception.InvalidSchemaError(
                     message=_('Invalid default %(default)s (%(exc)s)') %
@@ -183,10 +184,14 @@ class Schema(collections.Mapping):
 
         return value
 
-    def validate_constraints(self, value, context=None):
+    def validate_constraints(self, value, context=None, skipped=None):
+        if not skipped:
+            skipped = []
+
         try:
             for constraint in self.constraints:
-                constraint.validate(value, self, context)
+                if type(constraint) not in skipped:
+                    constraint.validate(value, self, context)
         except ValueError as ex:
             raise exception.StackValidationFailed(message=six.text_type(ex))
 
@@ -239,7 +244,7 @@ class AnyIndexDict(collections.Mapping):
         self.value = value
 
     def __getitem__(self, key):
-        if key != self.ANYTHING and not isinstance(key, (int, long)):
+        if key != self.ANYTHING and not isinstance(key, six.integer_types):
             raise KeyError(_('Invalid key %s') % str(key))
 
         return self.value
@@ -328,7 +333,7 @@ class Range(Constraint):
         self.max = max
 
         for param in (min, max):
-            if not isinstance(param, (float, int, long, type(None))):
+            if not isinstance(param, (float, six.integer_types, type(None))):
                 raise exception.InvalidSchemaError(
                     message=_('min/max must be numeric'))
 
@@ -397,7 +402,7 @@ class Length(Range):
         super(Length, self).__init__(min, max, description)
 
         for param in (min, max):
-            if not isinstance(param, (int, long, type(None))):
+            if not isinstance(param, (six.integer_types, type(None))):
                 msg = _('min/max length must be integral')
                 raise exception.InvalidSchemaError(message=msg)
 
@@ -437,7 +442,7 @@ class AllowedValues(Constraint):
     def __init__(self, allowed, description=None):
         super(AllowedValues, self).__init__(description)
         if (not isinstance(allowed, collections.Sequence) or
-                isinstance(allowed, basestring)):
+                isinstance(allowed, six.string_types)):
             raise exception.InvalidSchemaError(
                 message=_('AllowedValues must be a list'))
         self.allowed = tuple(allowed)
@@ -482,7 +487,7 @@ class AllowedPattern(Constraint):
 
     def __init__(self, pattern, description=None):
         super(AllowedPattern, self).__init__(description)
-        if not isinstance(pattern, basestring):
+        if not isinstance(pattern, six.string_types):
             raise exception.InvalidSchemaError(
                 message=_('AllowedPattern must be a string'))
         self.pattern = pattern
