@@ -11,12 +11,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
 
 from heat.common import messaging
-from heat.openstack.common import log
 
-LOG = log.getLogger(__name__)
 SERVICE = 'orchestration'
 INFO = 'INFO'
 ERROR = 'ERROR'
@@ -50,3 +48,7 @@ def notify(context, event_type, level, body):
 
     method = getattr(client, level.lower())
     method(context, "%s.%s" % (SERVICE, event_type), body)
+
+
+def list_opts():
+    yield None, notifier_opts
