@@ -11,9 +11,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from heat.common.exception import StackValidationFailed
+from oslo_log import log as logging
+
+from heat.common import exception
 from heat.common.i18n import _
-from heat.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
@@ -27,7 +28,7 @@ class ParameterGroups(object):
     '''
     def __init__(self, tmpl):
         self.tmpl = tmpl
-        self.parameters = tmpl.parameters(None, {})
+        self.parameters = tmpl.parameters(None, {}, param_defaults={})
         LOG.debug(self.tmpl)
         LOG.debug(self.parameters)
         self.parameter_names = []
@@ -43,27 +44,27 @@ class ParameterGroups(object):
         LOG.debug('Validating Parameter Groups.')
         LOG.debug(self.parameter_names)
         if self.parameter_groups is not None:
-            #Loop through groups and validate parameters
+            # Loop through groups and validate parameters
             grouped_parameters = []
             for group in self.parameter_groups:
                 parameters = group.get(PARAMETERS)
 
                 if parameters is None:
-                    raise StackValidationFailed(message=_(
+                    raise exception.StackValidationFailed(message=_(
                         'Parameters must be provided for '
                         'each Parameter Group.'))
 
                 for param in parameters:
-                    #Check if param has been added to a previous group
+                    # Check if param has been added to a previous group
                     if param in grouped_parameters:
-                        raise StackValidationFailed(message=_(
+                        raise exception.StackValidationFailed(message=_(
                             'The %s parameter must be assigned to one '
                             'Parameter Group only.') % param)
                     else:
                         grouped_parameters.append(param)
 
-                    #Check that grouped parameter references a valid Parameter
+                    # Check that grouped parameter references a valid Parameter
                     if param not in self.parameter_names:
-                        raise StackValidationFailed(message=_(
+                        raise exception.StackValidationFailed(message=_(
                             'The Parameter name (%s) does not reference '
                             'an existing parameter.') % param)
