@@ -293,14 +293,18 @@ class Resource(object):
                             % {'a': action, 'h': hook})
             self.trigger_hook(hook)
             LOG.info(_LI('Reached hook on %s'), six.text_type(self))
-        while self.has_hook(hook) and self.status != self.FAILED:
-            try:
-                yield
-            except Exception:
-                self.clear_hook(hook)
-                self._add_event(
-                    self.action, self.status,
-                    "Failure occured while waiting.")
+
+            while self.has_hook(hook) and self.status != self.FAILED:
+                try:
+                    yield
+                except BaseException as exc:
+                    self.clear_hook(hook)
+                    self._add_event(
+                        self.action, self.status,
+                        "Failure occurred while waiting.")
+                    if (isinstance(exc, AssertionError) or
+                            not isinstance(exc, Exception)):
+                        raise
 
     def has_nested(self):
         # common resources have not nested, StackResource overrides it
@@ -410,10 +414,24 @@ class Resource(object):
             if psv.immutable():
                 immutable_set.add(psk)
 
+        def prop_changed(key):
+            try:
+                before = before_props.get(key)
+            except (TypeError, ValueError) as exc:
+                # We shouldn't get here usually, but there is a known issue
+                # with template resources and new parameters in non-convergence
+                # stacks (see bug 1543685). The error should be harmless
+                # because we're on the before properties, which have presumably
+                # already been validated.
+                LOG.warning(_LW('Ignoring error in old property value '
+                                '%(prop_name)s: %(msg)s'),
+                            {'prop_name': key, 'msg': six.text_type(exc)})
+                return True
+
+            return before != after_props.get(key)
+
         # Create a set of keys which differ (or are missing/added)
-        changed_properties_set = set(k for k in after_props
-                                     if before_props.get(k) !=
-                                     after_props.get(k))
+        changed_properties_set = set(k for k in after_props if prop_changed(k))
 
         # Create a list of updated properties offending property immutability
         update_replace_forbidden = [k for k in changed_properties_set
