@@ -24,16 +24,16 @@ from heat.engine import attributes
 from heat.engine import constraints
 from heat.engine import properties
 from heat.engine import resource
+from heat.engine.resources import scheduler_hints as sh
 from heat.engine import scheduler
 from heat.engine import volume_tasks as vol_task
 
 cfg.CONF.import_opt('instance_user', 'heat.common.config')
-cfg.CONF.import_opt('stack_scheduler_hints', 'heat.common.config')
 
 LOG = logging.getLogger(__name__)
 
 
-class Instance(resource.Resource):
+class Instance(resource.Resource, sh.SchedulerHintsMixin):
 
     PROPERTIES = (
         IMAGE_ID, INSTANCE_TYPE, KEY_NAME, AVAILABILITY_ZONE,
@@ -525,14 +525,7 @@ class Instance(resource.Resource):
                     scheduler_hints[hint] = hint_value
         else:
             scheduler_hints = None
-        if cfg.CONF.stack_scheduler_hints:
-            if scheduler_hints is None:
-                scheduler_hints = {}
-            scheduler_hints['heat_root_stack_id'] = self.stack.root_stack_id()
-            scheduler_hints['heat_stack_id'] = self.stack.id
-            scheduler_hints['heat_stack_name'] = self.stack.name
-            scheduler_hints['heat_path_in_stack'] = self.stack.path_in_stack()
-            scheduler_hints['heat_resource_name'] = self.name
+        scheduler_hints = self._scheduler_hints(scheduler_hints)
 
         nics = self._build_nics(self.properties[self.NETWORK_INTERFACES],
                                 security_groups=security_groups,
