@@ -74,14 +74,14 @@ class Subnet(resource.Resource):
 
     attributes_schema = {
         AVAILABILITY_ZONE: attributes.Schema(
-            _('Availability Zone of the subnet.'),
-            type=attributes.Schema.STRING
+            _('Availability Zone of the subnet.')
         ),
     }
 
     default_client_name = 'neutron'
 
     def handle_create(self):
+        client = self.neutron()
         # TODO(sbaker) Verify that this CidrBlock is within the vpc CidrBlock
         network_id = self.properties.get(self.VPC_ID)
 
@@ -91,12 +91,12 @@ class Subnet(resource.Resource):
             'name': self.physical_resource_name(),
             'ip_version': 4
         }
-        subnet = self.client().create_subnet({'subnet': props})['subnet']
+        subnet = client.create_subnet({'subnet': props})['subnet']
         self.resource_id_set(subnet['id'])
 
-        router = vpc.VPC.router_for_vpc(self.client(), network_id)
+        router = vpc.VPC.router_for_vpc(self.neutron(), network_id)
         if router:
-            self.client().add_interface_router(
+            client.add_interface_router(
                 router['id'],
                 {'subnet_id': subnet['id']})
 
@@ -104,20 +104,21 @@ class Subnet(resource.Resource):
         if self.resource_id is None:
             return
 
+        client = self.neutron()
         network_id = self.properties.get(self.VPC_ID)
         subnet_id = self.resource_id
 
         try:
-            router = vpc.VPC.router_for_vpc(self.client(), network_id)
+            router = vpc.VPC.router_for_vpc(self.neutron(), network_id)
             if router:
-                self.client().remove_interface_router(
+                client.remove_interface_router(
                     router['id'],
                     {'subnet_id': subnet_id})
         except Exception as ex:
             self.client_plugin().ignore_not_found(ex)
 
         try:
-            self.client().delete_subnet(subnet_id)
+            client.delete_subnet(subnet_id)
         except Exception as ex:
             self.client_plugin().ignore_not_found(ex)
 
