@@ -11,45 +11,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from heat.common import exception
 from heat.common import grouputils
 from heat.common.i18n import _
 from heat.engine import attributes
 from heat.engine import constraints
-from heat.engine.hot import template
-from heat.engine import output
 from heat.engine import properties
 from heat.engine.resources.aws.autoscaling import autoscaling_group as aws_asg
 from heat.engine import rsrc_defn
-from heat.engine import support
-
-
-class HOTInterpreter(template.HOTemplate20150430):
-    def __new__(cls):
-        return object.__new__(cls)
-
-    def __init__(self):
-        version = {'heat_template_version': '2015-04-30'}
-        super(HOTInterpreter, self).__init__(version)
-
-    def parse(self, stack, snippet, path=''):
-        return snippet
-
-    def parse_conditions(self, stack, snippet, path=''):
-        return snippet
 
 
 class AutoScalingResourceGroup(aws_asg.AutoScalingGroup):
-    """An autoscaling group that can scale arbitrary resources.
-
-    An autoscaling group allows the creation of a desired count of similar
-    resources, which are defined with the resource property in HOT format.
-    If there is a need to create many of the same resources (e.g. one
-    hundred sets of Server, WaitCondition and WaitConditionHandle or even
-    Neutron Nets), AutoScalingGroup is a convenient and easy way to do that.
-    """
+    """An autoscaling group that can scale arbitrary resources."""
 
     PROPERTIES = (
         RESOURCE, MAX_SIZE, MIN_SIZE, COOLDOWN, DESIRED_CAPACITY,
@@ -66,9 +39,9 @@ class AutoScalingResourceGroup(aws_asg.AutoScalingGroup):
     )
 
     ATTRIBUTES = (
-        OUTPUTS, OUTPUTS_LIST, CURRENT_SIZE, REFS, REFS_MAP,
+        OUTPUTS, OUTPUTS_LIST, CURRENT_SIZE,
     ) = (
-        'outputs', 'outputs_list', 'current_size', 'refs', 'refs_map',
+        'outputs', 'outputs_list', 'current_size',
     )
 
     properties_schema = {
@@ -108,18 +81,19 @@ class AutoScalingResourceGroup(aws_asg.AutoScalingGroup):
         ROLLING_UPDATES: properties.Schema(
             properties.Schema.MAP,
             _('Policy for rolling updates for this scaling group.'),
+            required=False,
             update_allowed=True,
             schema={
                 MIN_IN_SERVICE: properties.Schema(
-                    properties.Schema.INTEGER,
+                    properties.Schema.NUMBER,
                     _('The minimum number of resources in service while '
                       'rolling updates are being executed.'),
                     constraints=[constraints.Range(min=0)],
                     default=0),
                 MAX_BATCH_SIZE: properties.Schema(
-                    properties.Schema.INTEGER,
+                    properties.Schema.NUMBER,
                     _('The maximum number of resources to replace at once.'),
-                    constraints=[constraints.Range(min=1)],
+                    constraints=[constraints.Range(min=0)],
                     default=1),
                 PAUSE_TIME: properties.Schema(
                     properties.Schema.NUMBER,
@@ -140,45 +114,23 @@ class AutoScalingResourceGroup(aws_asg.AutoScalingGroup):
     attributes_schema = {
         OUTPUTS: attributes.Schema(
             _("A map of resource names to the specified attribute of each "
-              "individual resource that is part of the AutoScalingGroup. "
-              "This map specifies output parameters that are available "
-              "once the AutoScalingGroup has been instantiated."),
-            support_status=support.SupportStatus(version='2014.2'),
-            type=attributes.Schema.MAP
+              "individual resource.")
         ),
         OUTPUTS_LIST: attributes.Schema(
-            _("A list of the specified attribute of each individual resource "
-              "that is part of the AutoScalingGroup. This list of attributes "
-              "is available as an output once the AutoScalingGroup has been "
-              "instantiated."),
-            support_status=support.SupportStatus(version='2014.2'),
-            type=attributes.Schema.LIST
+            _("A list of the specified attribute of each individual resource.")
         ),
         CURRENT_SIZE: attributes.Schema(
-            _("The current size of AutoscalingResourceGroup."),
-            support_status=support.SupportStatus(version='2015.1'),
-            type=attributes.Schema.INTEGER
+            _("The current size of AutoscalingResourceGroup.")
         ),
-        REFS: attributes.Schema(
-            _("A list of resource IDs for the resources in the group."),
-            type=attributes.Schema.LIST,
-            support_status=support.SupportStatus(version='7.0.0'),
-        ),
-        REFS_MAP: attributes.Schema(
-            _("A map of resource names to IDs for the resources in "
-              "the group."),
-            type=attributes.Schema.MAP,
-            support_status=support.SupportStatus(version='7.0.0'),
-        ),
-
     }
     update_policy_schema = {}
 
-    def _get_resource_definition(self):
-        resource_def = self.properties[self.RESOURCE]
-        defn_data = dict(HOTInterpreter()._rsrc_defn_args(None, 'member',
-                                                          resource_def))
-        return rsrc_defn.ResourceDefinition(None, **defn_data)
+    def _get_instance_definition(self):
+        rsrc = self.properties[self.RESOURCE]
+        return rsrc_defn.ResourceDefinition(
+            None, rsrc['type'],
+            properties=rsrc.get('properties'),
+            metadata=rsrc.get('metadata'))
 
     def _try_rolling_update(self, prop_diff):
         if self.RESOURCE in prop_diff:
@@ -189,22 +141,15 @@ class AutoScalingResourceGroup(aws_asg.AutoScalingGroup):
 
     def _create_template(self, num_instances, num_replace=0,
                          template_version=('heat_template_version',
-                                           '2015-04-30')):
+                                           '2013-05-23')):
         """Create a template in the HOT format for the nested stack."""
         return super(AutoScalingResourceGroup,
                      self)._create_template(num_instances, num_replace,
                                             template_version=template_version)
 
-    def get_attribute(self, key, *path):
+    def FnGetAtt(self, key, *path):
         if key == self.CURRENT_SIZE:
             return grouputils.get_size(self)
-        if key == self.REFS:
-            refs = grouputils.get_member_refids(self)
-            return refs
-        if key == self.REFS_MAP:
-            members = grouputils.get_members(self)
-            refs_map = {m.name: m.resource_id for m in members}
-            return refs_map
         if path:
             members = grouputils.get_members(self)
             attrs = ((rsrc.name, rsrc.FnGetAtt(*path)) for rsrc in members)
@@ -219,36 +164,6 @@ class AutoScalingResourceGroup(aws_asg.AutoScalingGroup):
         raise exception.InvalidTemplateAttribute(resource=self.name,
                                                  key=key)
 
-    def _nested_output_defns(self, resource_names, get_attr_fn, get_res_fn):
-        for attr in self.referenced_attrs():
-            if isinstance(attr, six.string_types):
-                key, path = attr, []
-            else:
-                key, path = attr[0], list(attr[1:])
-            # Always use map types, as list order is not defined at
-            # template generation time.
-            if key == self.OUTPUTS_LIST:
-                key = self.OUTPUTS
-            if key == self.REFS:
-                key = self.REFS_MAP
-            if key.startswith("resource."):
-                keycomponents = key.split('.', 2)
-                path = keycomponents[2:] + path
-                if path:
-                    key = self.OUTPUTS
-                else:
-                    key = self.REFS_MAP
-            output_name = ', '.join(six.text_type(a) for a in [key] + path)
-            value = None
-
-            if key == self.REFS_MAP:
-                value = {r: get_res_fn(r) for r in resource_names}
-            elif key == self.OUTPUTS and path:
-                value = {r: get_attr_fn([r] + path) for r in resource_names}
-
-            if value is not None:
-                yield output.OutputDefinition(output_name, value)
-
 
 def resource_mapping():
     return {
