@@ -15,6 +15,7 @@ from oslo_log import log as logging
 import six
 
 from heat.common.i18n import _
+from heat.common.i18n import _LI
 from heat.engine import attributes
 from heat.engine import constraints
 from heat.engine import properties
@@ -28,16 +29,12 @@ class Restarter(signal_responder.SignalResponder):
 
     support_status = support.SupportStatus(
         support.DEPRECATED,
-        _('The HARestarter resource type is deprecated and will be removed '
+        _('The HARestarter resource type is unsupported and will be removed '
           'in a future release of Heat, once it has support for auto-healing '
           'any type of resource. Note that HARestarter does *not* actually '
           'restart servers - it deletes and then recreates them. It also does '
           'the same to all dependent resources, and may therefore exhibit '
-          'unexpected and undesirable behaviour. Instead, use the '
-          'mark-unhealthy API to mark a resource as needing replacement, and '
-          'then a stack update to perform the replacement while respecting  '
-          'the dependencies and not deleting them unnecessarily.'),
-        version='2015.1'
+          'unexpected and undesirable behaviour. Avoid.')
     )
 
     PROPERTIES = (
@@ -65,8 +62,7 @@ class Restarter(signal_responder.SignalResponder):
 
     attributes_schema = {
         ALARM_URL: attributes.Schema(
-            _("A signed url to handle the alarm (Heat extension)."),
-            type=attributes.Schema.STRING
+            _("A signed url to handle the alarm (Heat extension).")
         ),
     }
 
@@ -80,7 +76,7 @@ class Restarter(signal_responder.SignalResponder):
         else:
             alarm_state = details.get('state', 'alarm').lower()
 
-        LOG.info('%(name)s Alarm, new state %(state)s',
+        LOG.info(_LI('%(name)s Alarm, new state %(state)s'),
                  {'name': self.name, 'state': alarm_state})
 
         if alarm_state != 'alarm':
@@ -89,24 +85,23 @@ class Restarter(signal_responder.SignalResponder):
         target_id = self.properties[self.INSTANCE_ID]
         victim = self.stack.resource_by_refid(target_id)
         if victim is None:
-            LOG.info('%(name)s Alarm, can not find instance '
-                     '%(instance)s',
+            LOG.info(_LI('%(name)s Alarm, can not find instance '
+                         '%(instance)s'),
                      {'name': self.name,
                       'instance': target_id})
             return
 
-        LOG.info('%(name)s Alarm, restarting resource: %(victim)s',
+        LOG.info(_LI('%(name)s Alarm, restarting resource: %(victim)s'),
                  {'name': self.name, 'victim': victim.name})
         self.stack.restart_resource(victim.name)
 
     def _resolve_attribute(self, name):
-        """Resolves the resource's attributes.
-
-        Heat extension: "AlarmUrl" returns the url to post to the policy
+        '''
+        heat extension: "AlarmUrl" returns the url to post to the policy
         when there is an alarm.
-        """
+        '''
         if name == self.ALARM_URL and self.resource_id is not None:
-            return six.text_type(self._get_ec2_signed_url())
+            return six.text_type(self._get_signed_url())
 
 
 def resource_mapping():
