@@ -11,29 +11,28 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_serialization import jsonutils
+from oslo_log import log as logging
 import six
 
 from heat.common import context
 from heat.common import exception
 from heat.common.i18n import _
+from heat.common.i18n import _LE
 from heat.common import template_format
 from heat.engine import attributes
 from heat.engine import environment
+from heat.engine import function
 from heat.engine import properties
 from heat.engine import resource
-from heat.engine import template
+
+LOG = logging.getLogger(__name__)
 
 
 class RemoteStack(resource.Resource):
-    """A Resource representing a stack.
-
-    A resource that allowing for the creating stack, where should be defined
-    stack template in HOT format, parameters (if template has any parameters
-    with no default value), and timeout of creating. After creating current
-    stack will have remote stack.
     """
-    default_client_name = 'heat'
+    A Resource representing a stack which can be created using specified
+    context.
+    """
 
     PROPERTIES = (
         CONTEXT, TEMPLATE, TIMEOUT, PARAMETERS,
@@ -73,7 +72,7 @@ class RemoteStack(resource.Resource):
             update_allowed=True
         ),
         TIMEOUT: properties.Schema(
-            properties.Schema.INTEGER,
+            properties.Schema.NUMBER,
             _('Number of minutes to wait for this stack creation.'),
             update_allowed=True
         ),
@@ -87,12 +86,10 @@ class RemoteStack(resource.Resource):
 
     attributes_schema = {
         NAME_ATTR: attributes.Schema(
-            _('Name of the stack.'),
-            type=attributes.Schema.STRING
+            _('Name of the stack.')
         ),
         OUTPUTS: attributes.Schema(
-            _('A dict of key-value pairs output from the stack.'),
-            type=attributes.Schema.MAP
+            _('A dict of key-value pairs output from the stack.')
         ),
     }
 
@@ -113,18 +110,17 @@ class RemoteStack(resource.Resource):
 
         # Build RequestContext from existing one
         dict_ctxt = self.context.to_dict()
-        dict_ctxt.update({'region_name': self._region_name,
-                          'overwrite': False})
+        dict_ctxt.update({'region_name': self._region_name})
         self._local_context = context.RequestContext.from_dict(dict_ctxt)
         return self._local_context
 
     def heat(self):
         # A convenience method overriding Resource.heat()
-        return self._context().clients.client(self.default_client_name)
+        return self._context().clients.heat()
 
     def client_plugin(self):
         # A convenience method overriding Resource.client_plugin()
-        return self._context().clients.client_plugin(self.default_client_name)
+        return self._context().clients.client_plugin('heat')
 
     def validate(self):
         super(RemoteStack, self).validate()
@@ -149,6 +145,7 @@ class RemoteStack(resource.Resource):
             self.heat().stacks.validate(**args)
         except Exception as ex:
             exc_info = dict(region=self._region_name, exc=six.text_type(ex))
+            LOG.error(_LE('exception: %s'), type(ex))
             msg = _('Failed validating stack template using Heat endpoint at '
                     'region "%(region)s" due to "%(exc)s"') % exc_info
             raise exception.StackValidationFailed(message=msg)
@@ -171,8 +168,10 @@ class RemoteStack(resource.Resource):
 
     def handle_delete(self):
         if self.resource_id is not None:
-            with self.client_plugin().ignore_not_found:
+            try:
                 self.heat().stacks.delete(stack_id=self.resource_id)
+            except Exception as e:
+                self.client_plugin().ignore_not_found(e)
 
     def handle_resume(self):
         if self.resource_id is None:
@@ -186,35 +185,8 @@ class RemoteStack(resource.Resource):
                                   % self.name)
         self.heat().actions.suspend(stack_id=self.resource_id)
 
-    def handle_snapshot(self):
-        snapshot = self.heat().stacks.snapshot(stack_id=self.resource_id)
-        self.data_set('snapshot_id', snapshot['id'])
-
-    def handle_restore(self, defn, restore_data):
-        snapshot_id = restore_data['resource_data']['snapshot_id']
-        snapshot = self.heat().stacks.snapshot_show(self.resource_id,
-                                                    snapshot_id)
-        s_data = snapshot['snapshot']['data']
-        env = environment.Environment(s_data['environment'])
-        files = s_data['files']
-        tmpl = template.Template(s_data['template'], env=env, files=files)
-        props = dict((k, v) for k, v in self.properties.items()
-                     if k in self.properties.data)
-        props[self.TEMPLATE] = jsonutils.dumps(tmpl.t)
-        props[self.PARAMETERS] = env.params
-
-        return defn.freeze(properties=props)
-
-    def handle_check(self):
-        self.heat().actions.check(stack_id=self.resource_id)
-
     def _needs_update(self, after, before, after_props, before_props,
-                      prev_resource, check_init_complete=True):
-        # If resource is in CHECK_FAILED state, raise UpdateReplace
-        # to replace the failed stack.
-        if self.state == (self.CHECK, self.FAILED):
-            raise resource.UpdateReplace(self)
-
+                      prev_resource):
         # Always issue an update to the remote stack and let the individual
         # resources in it decide if they need updating.
         return True
@@ -223,8 +195,11 @@ class RemoteStack(resource.Resource):
         # Always issue an update to the remote stack and let the individual
         # resources in it decide if they need updating.
         if self.resource_id:
-            self.properties = json_snippet.properties(self.properties_schema,
-                                                      self.context)
+            snippet = json_snippet.get('Properties', {})
+            self.properties = properties.Properties(self.properties_schema,
+                                                    snippet,
+                                                    function.resolve,
+                                                    self.name)
 
             params = self.properties[self.PARAMETERS]
             env = environment.get_child_environment(self.stack.env, params)
@@ -242,23 +217,28 @@ class RemoteStack(resource.Resource):
 
     def _check_action_complete(self, action):
         stack = self.heat().stacks.get(stack_id=self.resource_id)
-        if stack.action != action:
-            return False
-
-        if stack.status == self.IN_PROGRESS:
-            return False
-        elif stack.status == self.COMPLETE:
-            return True
-        elif stack.status == self.FAILED:
-            raise exception.ResourceInError(
-                resource_status=stack.stack_status,
-                status_reason=stack.stack_status_reason)
+        if stack.action == action:
+            if stack.status == self.IN_PROGRESS:
+                return False
+            elif stack.status == self.COMPLETE:
+                return True
+            elif stack.status == self.FAILED:
+                raise resource.ResourceInError(
+                    resource_status=stack.stack_status,
+                    status_reason=stack.stack_status_reason)
+            else:
+                # Note: this should never happen, so it really means that
+                # the resource/engine is in serious problem if it happens.
+                raise resource.ResourceUnknownStatus(
+                    resource_status=stack.stack_status,
+                    status_reason=stack.stack_status_reason)
         else:
-            # Note: this should never happen, so it really means that
-            # the resource/engine is in serious problem if it happens.
-            raise exception.ResourceUnknownStatus(
+            msg = _('Resource action mismatch detected: expected=%(expected)s '
+                    'actual=%(actual)s') % dict(expected=action,
+                                                actual=stack.action)
+            raise resource.ResourceUnknownStatus(
                 resource_status=stack.stack_status,
-                status_reason=stack.stack_status_reason)
+                status_reason=msg)
 
     def check_create_complete(self, *args):
         return self._check_action_complete(action=self.CREATE)
@@ -282,16 +262,13 @@ class RemoteStack(resource.Resource):
     def check_update_complete(self, *args):
         return self._check_action_complete(action=self.UPDATE)
 
-    def check_snapshot_complete(self, *args):
-        return self._check_action_complete(action=self.SNAPSHOT)
-
-    def check_check_complete(self, *args):
-        return self._check_action_complete(action=self.CHECK)
-
     def _resolve_attribute(self, name):
-        if self.resource_id is None:
-            return
-        stack = self.heat().stacks.get(stack_id=self.resource_id)
+        try:
+            stack = self.heat().stacks.get(stack_id=self.resource_id)
+        except Exception as e:
+            self.client_plugin().ignore_not_found(e)
+            return None
+
         if name == self.NAME_ATTR:
             value = getattr(stack, name, None)
             return value or self.physical_resource_name_or_FnGetRefId()
@@ -301,7 +278,7 @@ class RemoteStack(resource.Resource):
             return dict((output['output_key'], output['output_value'])
                         for output in outputs)
 
-    def get_reference_id(self):
+    def FnGetRefId(self):
         return self.resource_id
 
 
