@@ -20,15 +20,8 @@ from heat.engine import support
 
 
 class MeteringLabel(neutron.NeutronResource):
-    """A resource for creating neutron metering label.
-
-    The idea is to meter this at the L3 routers levels. The point is to allow
-    operators to configure IP ranges and to assign a label to them. For example
-    we will be able to set two labels; one for the internal traffic, and the
-    other one for the external traffic. Each label will measure the traffic for
-    a specific set of IP range. Then, bandwidth measurement will be sent for
-    each label to the Oslo notification system and could be collected by
-    Ceilometer.
+    """
+    A resource for creating neutron metering label.
     """
 
     support_status = support.SupportStatus(version='2014.1')
@@ -65,16 +58,13 @@ class MeteringLabel(neutron.NeutronResource):
 
     attributes_schema = {
         NAME_ATTR: attributes.Schema(
-            _('Name of the metering label.'),
-            type=attributes.Schema.STRING
+            _('Name of the metering label.')
         ),
         DESCRIPTION_ATTR: attributes.Schema(
-            _('Description of the metering label.'),
-            type=attributes.Schema.STRING
+            _('Description of the metering label.')
         ),
         SHARED_ATTR: attributes.Schema(
-            _('Shared status of the metering label.'),
-            type=attributes.Schema.STRING
+            _('Shared status of the metering label.')
         ),
     }
 
@@ -83,18 +73,18 @@ class MeteringLabel(neutron.NeutronResource):
             self.properties,
             self.physical_resource_name())
 
-        metering_label = self.client().create_metering_label(
+        metering_label = self.neutron().create_metering_label(
             {'metering_label': props})['metering_label']
 
         self.resource_id_set(metering_label['id'])
 
     def _show_resource(self):
-        return self.client().show_metering_label(
+        return self.neutron().show_metering_label(
             self.resource_id)['metering_label']
 
     def handle_delete(self):
         try:
-            self.client().delete_metering_label(self.resource_id)
+            self.neutron().delete_metering_label(self.resource_id)
         except Exception as ex:
             self.client_plugin().ignore_not_found(ex)
         else:
@@ -102,10 +92,8 @@ class MeteringLabel(neutron.NeutronResource):
 
 
 class MeteringRule(neutron.NeutronResource):
-    """A resource to create rule for some label.
-
-    Resource for allowing specified label to measure the traffic for a specific
-    set of ip range.
+    """
+    A resource to create rule for some label.
     """
 
     support_status = support.SupportStatus(version='2014.1')
@@ -155,20 +143,16 @@ class MeteringRule(neutron.NeutronResource):
 
     attributes_schema = {
         DIRECTION_ATTR: attributes.Schema(
-            _('The direction in which metering rule is applied.'),
-            type=attributes.Schema.STRING
+            _('The direction in which metering rule is applied.')
         ),
         EXCLUDED_ATTR: attributes.Schema(
-            _('Exclude state for cidr.'),
-            type=attributes.Schema.STRING
+            _('Exclude state for cidr.')
         ),
         METERING_LABEL_ID_ATTR: attributes.Schema(
-            _('The metering label ID to associate with this metering rule.'),
-            type=attributes.Schema.STRING
+            _('The metering label ID to associate with this metering rule.')
         ),
         REMOTE_IP_PREFIX_ATTR: attributes.Schema(
-            _('CIDR to be associated with this metering rule.'),
-            type=attributes.Schema.STRING
+            _('CIDR to be associated with this metering rule.')
         ),
     }
 
@@ -177,18 +161,18 @@ class MeteringRule(neutron.NeutronResource):
             self.properties,
             self.physical_resource_name())
 
-        metering_label_rule = self.client().create_metering_label_rule(
+        metering_label_rule = self.neutron().create_metering_label_rule(
             {'metering_label_rule': props})['metering_label_rule']
 
         self.resource_id_set(metering_label_rule['id'])
 
     def _show_resource(self):
-        return self.client().show_metering_label_rule(
+        return self.neutron().show_metering_label_rule(
             self.resource_id)['metering_label_rule']
 
     def handle_delete(self):
         try:
-            self.client().delete_metering_label_rule(self.resource_id)
+            self.neutron().delete_metering_label_rule(self.resource_id)
         except Exception as ex:
             self.client_plugin().ignore_not_found(ex)
         else:
