@@ -21,19 +21,15 @@ from heat.engine import constraints
 from heat.engine import properties
 from heat.engine.resources.openstack.neutron import neutron
 from heat.engine import support
-from heat.engine import translation
 
 
 class NetworkGateway(neutron.NeutronResource):
-    """Network Gateway resource in Neutron Network Gateway.
-
-    Resource for connecting internal networks with specified devices.
-    """
+    '''
+    A resource for the Network Gateway resource in Neutron Network Gateway.
+    '''
 
     support_status = support.SupportStatus(version='2014.1')
 
-    entity = 'network_gateway'
-
     PROPERTIES = (
         NAME, DEVICES, CONNECTIONS,
     ) = (
@@ -41,9 +37,9 @@ class NetworkGateway(neutron.NeutronResource):
     )
 
     ATTRIBUTES = (
-        DEFAULT,
+        DEFAULT, SHOW,
     ) = (
-        'default',
+        'default', 'show',
     )
 
     _DEVICES_KEYS = (
@@ -99,14 +95,9 @@ class NetworkGateway(neutron.NeutronResource):
                     NETWORK_ID: properties.Schema(
                         properties.Schema.STRING,
                         support_status=support.SupportStatus(
-                            status=support.HIDDEN,
-                            message=_('Use property %s.') % NETWORK,
-                            version='5.0.0',
-                            previous_status=support.SupportStatus(
-                                status=support.DEPRECATED,
-                                version='2014.2'
-                            )
-                        ),
+                            support.DEPRECATED,
+                            _('Use property %s.') % NETWORK),
+                        required=False,
                         constraints=[
                             constraints.CustomConstraint('neutron.network')
                         ],
@@ -116,8 +107,8 @@ class NetworkGateway(neutron.NeutronResource):
                         description=_(
                             'The internal network to connect on '
                             'the network gateway.'),
+                        required=False,
                         support_status=support.SupportStatus(version='2014.2'),
-                        required=True,
                         constraints=[
                             constraints.CustomConstraint('neutron.network')
                         ],
@@ -146,35 +137,27 @@ class NetworkGateway(neutron.NeutronResource):
 
     attributes_schema = {
         DEFAULT: attributes.Schema(
-            _("A boolean value of default flag."),
-            type=attributes.Schema.STRING
+            _("A boolean value of default flag.")
+        ),
+        SHOW: attributes.Schema(
+            _("All attributes.")
         ),
     }
 
-    def translation_rules(self, props):
-        return [
-            translation.TranslationRule(
-                props,
-                translation.TranslationRule.REPLACE,
-                [self.CONNECTIONS, self.NETWORK],
-                value_name=self.NETWORK_ID
-            ),
-            translation.TranslationRule(
-                props,
-                translation.TranslationRule.RESOLVE,
-                [self.CONNECTIONS, self.NETWORK],
-                client_plugin=self.client_plugin(),
-                finder='find_resourceid_by_name_or_id',
-                entity='network'
-            )
-        ]
+    def _show_resource(self):
+        return self.neutron().show_network_gateway(
+            self.resource_id)['network_gateway']
 
     def validate(self):
-        """Validate any of the provided params."""
+        '''
+        Validate any of the provided params
+        '''
         super(NetworkGateway, self).validate()
         connections = self.properties[self.CONNECTIONS]
 
         for connection in connections:
+            self._validate_depr_property_required(
+                connection, self.NETWORK, self.NETWORK_ID)
             segmentation_type = connection[self.SEGMENTATION_TYPE]
             segmentation_id = connection.get(self.SEGMENTATION_ID)
 
@@ -194,66 +177,79 @@ class NetworkGateway(neutron.NeutronResource):
             self.physical_resource_name())
 
         connections = props.pop(self.CONNECTIONS)
-        ret = self.client().create_network_gateway(
+        ret = self.neutron().create_network_gateway(
             {'network_gateway': props})['network_gateway']
 
         self.resource_id_set(ret['id'])
 
         for connection in connections:
-            if self.NETWORK in connection:
-                connection['network_id'] = connection.pop(self.NETWORK)
-            self.client().connect_network_gateway(
+            self.client_plugin().resolve_network(
+                connection, self.NETWORK, 'network_id')
+            if self.NETWORK in connection.keys():
+                connection.pop(self.NETWORK)
+            self.neutron().connect_network_gateway(
                 ret['id'], connection
             )
 
     def handle_delete(self):
         if not self.resource_id:
             return
+        client = self.neutron()
 
         connections = self.properties[self.CONNECTIONS]
         for connection in connections:
-            with self.client_plugin().ignore_not_found:
-                if self.NETWORK in connection:
-                    connection['network_id'] = connection.pop(self.NETWORK)
-                self.client().disconnect_network_gateway(
+            try:
+                self.client_plugin().resolve_network(
+                    connection, self.NETWORK, 'network_id')
+                if self.NETWORK in connection.keys():
+                    connection.pop(self.NETWORK)
+                client.disconnect_network_gateway(
                     self.resource_id, connection
                 )
+            except Exception as ex:
+                self.client_plugin().ignore_not_found(ex)
+
         try:
-            self.client().delete_network_gateway(self.resource_id)
+            client.delete_network_gateway(self.resource_id)
         except Exception as ex:
             self.client_plugin().ignore_not_found(ex)
         else:
             return True
 
     def handle_update(self, json_snippet, tmpl_diff, prop_diff):
-        connections = None
-        if self.CONNECTIONS in prop_diff:
-            connections = prop_diff.pop(self.CONNECTIONS)
+        props = self.prepare_update_properties(json_snippet)
+        connections = props.pop(self.CONNECTIONS)
 
         if self.DEVICES in prop_diff:
             self.handle_delete()
-            self.properties.data.update(prop_diff)
+            self.properties.data.update(props)
             self.handle_create()
             return
+        else:
+            props.pop(self.DEVICES, None)
 
-        if prop_diff:
-            self.prepare_update_properties(prop_diff)
-            self.client().update_network_gateway(
-                self.resource_id, {'network_gateway': prop_diff})
+        if self.NAME in prop_diff:
+            self.neutron().update_network_gateway(
+                self.resource_id, {'network_gateway': props})
 
-        if connections:
+        if self.CONNECTIONS in prop_diff:
             for connection in self.properties[self.CONNECTIONS]:
-                with self.client_plugin().ignore_not_found:
-                    if self.NETWORK in connection:
-                        connection[
-                            'network_id'] = connection.pop(self.NETWORK)
-                    self.client().disconnect_network_gateway(
+                try:
+                    self.client_plugin().resolve_network(
+                        connection, self.NETWORK, 'network_id')
+                    if self.NETWORK in connection.keys():
+                        connection.pop(self.NETWORK)
+                    self.neutron().disconnect_network_gateway(
                         self.resource_id, connection
                     )
+                except Exception as ex:
+                    self.client_plugin().ignore_not_found(ex)
             for connection in connections:
-                if self.NETWORK in connection:
-                    connection['network_id'] = connection.pop(self.NETWORK)
-                self.client().connect_network_gateway(
+                self.client_plugin().resolve_network(
+                    connection, self.NETWORK, 'network_id')
+                if self.NETWORK in connection.keys():
+                    connection.pop(self.NETWORK)
+                self.neutron().connect_network_gateway(
                     self.resource_id, connection
                 )
 
