@@ -13,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import re
-
 from oslo_log import log as logging
 
 from heat.common import exception
@@ -43,7 +41,6 @@ class SaharaNodeGroupTemplate(resource.Resource):
         SECURITY_GROUPS, AUTO_SECURITY_GROUP,
         AVAILABILITY_ZONE, VOLUMES_AVAILABILITY_ZONE,
         NODE_PROCESSES, FLOATING_IP_POOL, NODE_CONFIGS, IMAGE_ID,
-        IS_PROXY_GATEWAY, VOLUME_LOCAL_TO_INSTANCE, USE_AUTOCONFIG
 
     ) = (
         'name', 'plugin_name', 'hadoop_version', 'flavor', 'description',
@@ -51,7 +48,6 @@ class SaharaNodeGroupTemplate(resource.Resource):
         'security_groups', 'auto_security_group',
         'availability_zone', 'volumes_availability_zone',
         'node_processes', 'floating_ip_pool', 'node_configs', 'image_id',
-        'is_proxy_gateway', 'volume_local_to_instance', 'use_autoconfig'
     )
 
     properties_schema = {
@@ -72,9 +68,6 @@ class SaharaNodeGroupTemplate(resource.Resource):
             properties.Schema.STRING,
             _('Plugin name.'),
             required=True,
-            constraints=[
-                constraints.CustomConstraint('sahara.plugin')
-            ]
         ),
         HADOOP_VERSION: properties.Schema(
             properties.Schema.STRING,
@@ -160,35 +153,17 @@ class SaharaNodeGroupTemplate(resource.Resource):
                 constraints.CustomConstraint('sahara.image'),
             ],
         ),
-        IS_PROXY_GATEWAY: properties.Schema(
-            properties.Schema.BOOLEAN,
-            _("Provide access to nodes using other nodes of the cluster "
-              "as proxy gateways."),
-            support_status=support.SupportStatus(version='5.0.0')
-        ),
-        VOLUME_LOCAL_TO_INSTANCE: properties.Schema(
-            properties.Schema.BOOLEAN,
-            _("Create volumes on the same physical port as an instance."),
-            support_status=support.SupportStatus(version='5.0.0')
-        ),
-        USE_AUTOCONFIG: properties.Schema(
-            properties.Schema.BOOLEAN,
-            _("Configure most important configs automatically."),
-            support_status=support.SupportStatus(version='5.0.0')
-        )
     }
 
     default_client_name = 'sahara'
 
     physical_resource_name_limit = 50
 
-    entity = 'node_group_templates'
-
     def _ngt_name(self):
-        name = self.properties[self.NAME]
+        name = self.properties.get(self.NAME)
         if name:
             return name
-        return re.sub('[^a-zA-Z0-9-]', '', self.physical_resource_name())
+        return self.physical_resource_name()
 
     def handle_create(self):
         plugin_name = self.properties[self.PLUGIN_NAME]
@@ -197,10 +172,10 @@ class SaharaNodeGroupTemplate(resource.Resource):
         description = self.properties[self.DESCRIPTION]
         flavor_id = self.client_plugin("nova").get_flavor_id(
             self.properties[self.FLAVOR])
-        volumes_per_node = self.properties[self.VOLUMES_PER_NODE]
-        volumes_size = self.properties[self.VOLUMES_SIZE]
-        volume_type = self.properties[self.VOLUME_TYPE]
-        floating_ip_pool = self.properties[self.FLOATING_IP_POOL]
+        volumes_per_node = self.properties.get(self.VOLUMES_PER_NODE)
+        volumes_size = self.properties.get(self.VOLUMES_SIZE)
+        volume_type = self.properties.get(self.VOLUME_TYPE)
+        floating_ip_pool = self.properties.get(self.FLOATING_IP_POOL)
         security_groups = self.properties[self.SECURITY_GROUPS]
         auto_security_group = self.properties[self.AUTO_SECURITY_GROUP]
         availability_zone = self.properties[self.AVAILABILITY_ZONE]
@@ -210,11 +185,7 @@ class SaharaNodeGroupTemplate(resource.Resource):
             floating_ip_pool = self.client_plugin(
                 'neutron').find_neutron_resource(
                     self.properties, self.FLOATING_IP_POOL, 'network')
-        node_configs = self.properties[self.NODE_CONFIGS]
-        is_proxy_gateway = self.properties[self.IS_PROXY_GATEWAY]
-        volume_local_to_instance = self.properties[
-            self.VOLUME_LOCAL_TO_INSTANCE]
-        use_autoconfig = self.properties[self.USE_AUTOCONFIG]
+        node_configs = self.properties.get(self.NODE_CONFIGS)
 
         node_group_template = self.client().node_group_templates.create(
             self._ngt_name(),
@@ -230,16 +201,24 @@ class SaharaNodeGroupTemplate(resource.Resource):
             auto_security_group=auto_security_group,
             availability_zone=availability_zone,
             volumes_availability_zone=vol_availability_zone,
-            image_id=image_id,
-            is_proxy_gateway=is_proxy_gateway,
-            volume_local_to_instance=volume_local_to_instance,
-            use_autoconfig=use_autoconfig
+            image_id=image_id
         )
         LOG.info(_LI("Node Group Template '%s' has been created"),
                  node_group_template.name)
         self.resource_id_set(node_group_template.id)
         return self.resource_id
 
+    def handle_delete(self):
+        if not self.resource_id:
+            return
+        try:
+            self.client().node_group_templates.delete(
+                self.resource_id)
+        except Exception as ex:
+            self.client_plugin().ignore_not_found(ex)
+        LOG.info(_LI("Node Group Template '%s' has been deleted."),
+                 self._ngt_name())
+
     def validate(self):
         res = super(SaharaNodeGroupTemplate, self).validate()
         if res:
@@ -265,11 +244,6 @@ class SaharaNodeGroupTemplate(resource.Resource):
                             message=ex.message)
                     raise
 
-        self.client_plugin().validate_hadoop_version(
-            self.properties[self.PLUGIN_NAME],
-            self.properties[self.HADOOP_VERSION]
-        )
-
 
 class SaharaClusterTemplate(resource.Resource):
 
@@ -278,11 +252,11 @@ class SaharaClusterTemplate(resource.Resource):
     PROPERTIES = (
         NAME, PLUGIN_NAME, HADOOP_VERSION, DESCRIPTION,
         ANTI_AFFINITY, MANAGEMENT_NETWORK,
-        CLUSTER_CONFIGS, NODE_GROUPS, IMAGE_ID, USE_AUTOCONFIG
+        CLUSTER_CONFIGS, NODE_GROUPS, IMAGE_ID,
     ) = (
         'name', 'plugin_name', 'hadoop_version', 'description',
         'anti_affinity', 'neutron_management_network',
-        'cluster_configs', 'node_groups', 'default_image_id', 'use_autoconfig'
+        'cluster_configs', 'node_groups', 'default_image_id',
     )
 
     _NODE_GROUP_KEYS = (
@@ -299,28 +273,21 @@ class SaharaClusterTemplate(resource.Resource):
                 constraints.Length(min=1, max=50),
                 constraints.AllowedPattern(SAHARA_NAME_REGEX),
             ],
-            update_allowed=True
         ),
         DESCRIPTION: properties.Schema(
             properties.Schema.STRING,
             _('Description of the Sahara Group Template.'),
             default="",
-            update_allowed=True
         ),
         PLUGIN_NAME: properties.Schema(
             properties.Schema.STRING,
             _('Plugin name.'),
             required=True,
-            constraints=[
-                constraints.CustomConstraint('sahara.plugin')
-            ],
-            update_allowed=True
         ),
         HADOOP_VERSION: properties.Schema(
             properties.Schema.STRING,
             _('Version of Hadoop running on instances.'),
             required=True,
-            update_allowed=True
         ),
         IMAGE_ID: properties.Schema(
             properties.Schema.STRING,
@@ -328,7 +295,6 @@ class SaharaClusterTemplate(resource.Resource):
             constraints=[
                 constraints.CustomConstraint('sahara.image'),
             ],
-            update_allowed=True
         ),
         MANAGEMENT_NETWORK: properties.Schema(
             properties.Schema.STRING,
@@ -336,7 +302,6 @@ class SaharaClusterTemplate(resource.Resource):
             constraints=[
                 constraints.CustomConstraint('neutron.network')
             ],
-            update_allowed=True
         ),
         ANTI_AFFINITY: properties.Schema(
             properties.Schema.LIST,
@@ -344,12 +309,10 @@ class SaharaClusterTemplate(resource.Resource):
             schema=properties.Schema(
                 properties.Schema.STRING,
             ),
-            update_allowed=True
         ),
         CLUSTER_CONFIGS: properties.Schema(
             properties.Schema.MAP,
             _('Cluster configs dictionary.'),
-            update_allowed=True
         ),
         NODE_GROUPS: properties.Schema(
             properties.Schema.LIST,
@@ -377,65 +340,61 @@ class SaharaClusterTemplate(resource.Resource):
                     ),
                 }
             ),
-            update_allowed=True
+
         ),
-        USE_AUTOCONFIG: properties.Schema(
-            properties.Schema.BOOLEAN,
-            _("Configure most important configs automatically."),
-            support_status=support.SupportStatus(version='5.0.0')
-        )
     }
 
     default_client_name = 'sahara'
 
     physical_resource_name_limit = 50
 
-    entity = 'cluster_templates'
-
     def _cluster_template_name(self):
-        name = self.properties[self.NAME]
+        name = self.properties.get(self.NAME)
         if name:
             return name
-        return re.sub('[^a-zA-Z0-9-]', '', self.physical_resource_name())
-
-    def _prepare_properties(self):
-        props = {
-            'name': self._cluster_template_name(),
-            'plugin_name': self.properties[self.PLUGIN_NAME],
-            'hadoop_version': self.properties[self.HADOOP_VERSION],
-            'description': self.properties[self.DESCRIPTION],
-            'cluster_configs': self.properties[self.CLUSTER_CONFIGS],
-            'node_groups': self.properties[self.NODE_GROUPS],
-            'anti_affinity': self.properties[self.ANTI_AFFINITY],
-            'net_id': self.properties[self.MANAGEMENT_NETWORK],
-            'default_image_id': self.properties[self.IMAGE_ID],
-            'use_autoconfig': self.properties[self.USE_AUTOCONFIG],
-        }
-        if props['net_id']:
-            if self.is_using_neutron():
-                props['net_id'] = self.client_plugin(
-                    'neutron').find_neutron_resource(
-                    self.properties, self.MANAGEMENT_NETWORK, 'network')
-            else:
-                props['net_id'] = self.client_plugin(
-                    'nova').get_nova_network_id(props['net_id'])
-        return props
+        return self.physical_resource_name()
 
     def handle_create(self):
-        args = self._prepare_properties()
-        cluster_template = self.client().cluster_templates.create(**args)
+        plugin_name = self.properties[self.PLUGIN_NAME]
+        hadoop_version = self.properties[self.HADOOP_VERSION]
+        description = self.properties.get(self.DESCRIPTION)
+        image_id = self.properties.get(self.IMAGE_ID)
+        net_id = self.properties.get(self.MANAGEMENT_NETWORK)
+        if net_id:
+            if self.is_using_neutron():
+                net_id = self.client_plugin('neutron').find_neutron_resource(
+                    self.properties, self.MANAGEMENT_NETWORK, 'network')
+            else:
+                net_id = self.client_plugin('nova').get_nova_network_id(
+                    net_id)
+        anti_affinity = self.properties.get(self.ANTI_AFFINITY)
+        cluster_configs = self.properties.get(self.CLUSTER_CONFIGS)
+        node_groups = self.properties.get(self.NODE_GROUPS)
+        cluster_template = self.client().cluster_templates.create(
+            self._cluster_template_name(),
+            plugin_name, hadoop_version,
+            description=description,
+            default_image_id=image_id,
+            anti_affinity=anti_affinity,
+            net_id=net_id,
+            cluster_configs=cluster_configs,
+            node_groups=node_groups
+        )
         LOG.info(_LI("Cluster Template '%s' has been created"),
                  cluster_template.name)
         self.resource_id_set(cluster_template.id)
         return self.resource_id
 
-    def handle_update(self, json_snippet, tmpl_diff, prop_diff):
-        if prop_diff:
-            self.properties = json_snippet.properties(
-                self.properties_schema,
-                self.context)
-            args = self._prepare_properties()
-            self.client().cluster_templates.update(self.resource_id, **args)
+    def handle_delete(self):
+        if not self.resource_id:
+            return
+        try:
+            self.client().cluster_templates.delete(
+                self.resource_id)
+        except Exception as ex:
+            self.client_plugin().ignore_not_found(ex)
+        LOG.info(_LI("Cluster Template '%s' has been deleted."),
+                 self._cluster_template_name())
 
     def validate(self):
         res = super(SaharaClusterTemplate, self).validate()
@@ -443,16 +402,11 @@ class SaharaClusterTemplate(resource.Resource):
             return res
         # check if running on neutron and MANAGEMENT_NETWORK missing
         if (self.is_using_neutron() and
-                not self.properties[self.MANAGEMENT_NETWORK]):
+                not self.properties.get(self.MANAGEMENT_NETWORK)):
             msg = _("%s must be provided"
                     ) % self.MANAGEMENT_NETWORK
             raise exception.StackValidationFailed(message=msg)
 
-        self.client_plugin().validate_hadoop_version(
-            self.properties[self.PLUGIN_NAME],
-            self.properties[self.HADOOP_VERSION]
-        )
-
 
 def resource_mapping():
     return {
