@@ -13,29 +13,29 @@
 # under the License.
 
 
-"""SoftwareDeployment object."""
+"""
+SoftwareDeployment object
+"""
+
 
 from oslo_versionedobjects import base
 from oslo_versionedobjects import fields
 
-from heat.db.sqlalchemy import api as db_api
-from heat.objects import base as heat_base
+from heat.db import api as db_api
 from heat.objects import fields as heat_fields
 from heat.objects import software_config
 
 
-class SoftwareDeployment(
-        heat_base.HeatObject,
-        base.VersionedObjectDictCompat,
-        base.ComparableVersionedObject,
-):
+class SoftwareDeployment(base.VersionedObject,
+                         base.VersionedObjectDictCompat,
+                         base.ComparableVersionedObject):
     fields = {
-        'id': fields.StringField(),
-        'config_id': fields.StringField(),
-        'server_id': fields.StringField(),
+        'id': fields.StringField(nullable=False),
+        'config_id': fields.StringField(nullable=False),
+        'server_id': fields.StringField(nullable=False),
         'input_values': heat_fields.JsonField(nullable=True),
         'output_values': heat_fields.JsonField(nullable=True),
-        'tenant': fields.StringField(),
+        'tenant': fields.StringField(nullable=False),
         'stack_user_project_id': fields.StringField(nullable=True),
         'action': fields.StringField(nullable=True),
         'status': fields.StringField(nullable=True),
@@ -79,10 +79,6 @@ class SoftwareDeployment(
 
     @classmethod
     def update_by_id(cls, context, deployment_id, values):
-        """Note this is a bit unusual as it returns the object.
-
-        Other update_by_id methods return a bool (was it updated).
-        """
         return cls._from_db_object(
             context, cls(),
             db_api.software_deployment_update(context, deployment_id, values))
