@@ -12,11 +12,18 @@
 #    under the License.
 
 ENGINE_TOPIC = 'engine'
+LISTENER_TOPIC = 'heat-engine-listener'
 
 PARAM_KEYS = (
-    PARAM_TIMEOUT, PARAM_DISABLE_ROLLBACK, PARAM_ADOPT_STACK_DATA
+    PARAM_TIMEOUT, PARAM_DISABLE_ROLLBACK, PARAM_ADOPT_STACK_DATA,
+    PARAM_SHOW_DELETED, PARAM_SHOW_NESTED, PARAM_EXISTING,
+    PARAM_CLEAR_PARAMETERS, PARAM_GLOBAL_TENANT, PARAM_LIMIT,
+    PARAM_NESTED_DEPTH,
 ) = (
-    'timeout_mins', 'disable_rollback', 'adopt_stack_data'
+    'timeout_mins', 'disable_rollback', 'adopt_stack_data',
+    'show_deleted', 'show_nested', 'existing',
+    'clear_parameters', 'global_tenant', 'limit',
+    'nested_depth',
 )
 
 STACK_KEYS = (
@@ -26,7 +33,8 @@ STACK_KEYS = (
     STACK_DESCRIPTION, STACK_TMPL_DESCRIPTION,
     STACK_PARAMETERS, STACK_OUTPUTS, STACK_ACTION,
     STACK_STATUS, STACK_STATUS_DATA, STACK_CAPABILITIES,
-    STACK_DISABLE_ROLLBACK, STACK_TIMEOUT,
+    STACK_DISABLE_ROLLBACK, STACK_TIMEOUT, STACK_OWNER,
+    STACK_PARENT, STACK_USER_PROJECT_ID
 ) = (
     'stack_name', 'stack_identity',
     'creation_time', 'updated_time', 'deletion_time',
@@ -34,15 +42,18 @@ STACK_KEYS = (
     'description', 'template_description',
     'parameters', 'outputs', 'stack_action',
     'stack_status', 'stack_status_reason', 'capabilities',
-    'disable_rollback', 'timeout_mins',
+    'disable_rollback', 'timeout_mins', 'stack_owner',
+    'parent', 'stack_user_project_id'
 )
 
 STACK_OUTPUT_KEYS = (
     OUTPUT_DESCRIPTION,
     OUTPUT_KEY, OUTPUT_VALUE,
+    OUTPUT_ERROR,
 ) = (
     'description',
     'output_key', 'output_value',
+    'output_error',
 )
 
 RES_KEYS = (
@@ -50,13 +61,15 @@ RES_KEYS = (
     RES_NAME, RES_PHYSICAL_ID, RES_METADATA,
     RES_ACTION, RES_STATUS, RES_STATUS_DATA,
     RES_TYPE, RES_ID, RES_STACK_ID, RES_STACK_NAME,
-    RES_REQUIRED_BY,
+    RES_REQUIRED_BY, RES_NESTED_STACK_ID, RES_NESTED_RESOURCES,
+    RES_PARENT_RESOURCE,
 ) = (
     'description', 'updated_time',
     'resource_name', 'physical_resource_id', 'metadata',
     'resource_action', 'resource_status', 'resource_status_reason',
     'resource_type', 'resource_identity', STACK_ID, STACK_NAME,
-    'required_by',
+    'required_by', 'nested_stack_id', 'nested_resources',
+    'parent_resource',
 )
 
 RES_SCHEMA_KEYS = (
@@ -163,20 +176,22 @@ VALIDATE_PARAM_KEYS = (
     PARAM_TYPE, PARAM_DEFAULT, PARAM_NO_ECHO,
     PARAM_ALLOWED_VALUES, PARAM_ALLOWED_PATTERN, PARAM_MAX_LENGTH,
     PARAM_MIN_LENGTH, PARAM_MAX_VALUE, PARAM_MIN_VALUE,
-    PARAM_DESCRIPTION, PARAM_CONSTRAINT_DESCRIPTION, PARAM_LABEL
+    PARAM_DESCRIPTION, PARAM_CONSTRAINT_DESCRIPTION, PARAM_LABEL,
+    PARAM_CUSTOM_CONSTRAINT
 ) = (
     'Type', 'Default', 'NoEcho',
     'AllowedValues', 'AllowedPattern', 'MaxLength',
     'MinLength', 'MaxValue', 'MinValue',
-    'Description', 'ConstraintDescription', 'Label'
+    'Description', 'ConstraintDescription', 'Label',
+    'CustomConstraint'
 )
 
 VALIDATE_PARAM_TYPES = (
     PARAM_TYPE_STRING, PARAM_TYPE_NUMBER, PARAM_TYPE_COMMA_DELIMITED_LIST,
-    PARAM_TYPE_JSON
+    PARAM_TYPE_JSON, PARAM_TYPE_BOOLEAN
 ) = (
     'String', 'Number', 'CommaDelimitedList',
-    'Json'
+    'Json', 'Boolean'
 )
 
 SOFTWARE_CONFIG_KEYS = (
@@ -187,6 +202,7 @@ SOFTWARE_CONFIG_KEYS = (
     SOFTWARE_CONFIG_INPUTS,
     SOFTWARE_CONFIG_OUTPUTS,
     SOFTWARE_CONFIG_OPTIONS,
+    SOFTWARE_CONFIG_CREATION_TIME
 ) = (
     'id',
     'name',
@@ -195,6 +211,7 @@ SOFTWARE_CONFIG_KEYS = (
     'inputs',
     'outputs',
     'options',
+    'creation_time'
 )
 
 SOFTWARE_DEPLOYMENT_KEYS = (
@@ -205,7 +222,9 @@ SOFTWARE_DEPLOYMENT_KEYS = (
     SOFTWARE_DEPLOYMENT_OUTPUT_VALUES,
     SOFTWARE_DEPLOYMENT_ACTION,
     SOFTWARE_DEPLOYMENT_STATUS,
-    SOFTWARE_DEPLOYMENT_STATUS_REASON
+    SOFTWARE_DEPLOYMENT_STATUS_REASON,
+    SOFTWARE_DEPLOYMENT_CREATION_TIME,
+    SOFTWARE_DEPLOYMENT_UPDATED_TIME
 ) = (
     'id',
     'config_id',
@@ -214,5 +233,47 @@ SOFTWARE_DEPLOYMENT_KEYS = (
     'output_values',
     'action',
     'status',
-    'status_reason'
+    'status_reason',
+    'creation_time',
+    'updated_time'
 )
+
+SOFTWARE_DEPLOYMENT_STATUSES = (
+    SOFTWARE_DEPLOYMENT_IN_PROGRESS,
+    SOFTWARE_DEPLOYMENT_FAILED,
+    SOFTWARE_DEPLOYMENT_COMPLETE
+) = (
+    'IN_PROGRESS',
+    'FAILED',
+    'COMPLETE'
+)
+
+SOFTWARE_DEPLOYMENT_OUTPUTS = (
+    SOFTWARE_DEPLOYMENT_OUTPUT_STDOUT,
+    SOFTWARE_DEPLOYMENT_OUTPUT_STDERR,
+    SOFTWARE_DEPLOYMENT_OUTPUT_STATUS_CODE
+) = (
+    'deploy_stdout',
+    'deploy_stderr',
+    'deploy_status_code'
+)
+
+SNAPSHOT_KEYS = (
+    SNAPSHOT_ID,
+    SNAPSHOT_NAME,
+    SNAPSHOT_STACK_ID,
+    SNAPSHOT_DATA,
+    SNAPSHOT_STATUS,
+    SNAPSHOT_STATUS_REASON,
+    SNAPSHOT_CREATION_TIME,
+) = (
+    'id',
+    'name',
+    'stack_id',
+    'data',
+    'status',
+    'status_reason',
+    'creation_time'
+)
+
+THREAD_MESSAGES = (THREAD_CANCEL,) = ('cancel',)
