@@ -23,11 +23,12 @@ from heat.engine import scheduler
 
 
 def reload_loadbalancers(group, load_balancers, exclude=None):
-    """Notify the LoadBalancer to reload its config.
+    '''
+    Notify the LoadBalancer to reload its config.
 
     This must be done after activation (instance in ACTIVE state), otherwise
     the instances' IP addresses may not be available.
-    """
+    '''
     exclude = exclude or []
     id_list = grouputils.get_member_refids(group, exclude=exclude)
     for name, lb in six.iteritems(load_balancers):
@@ -44,7 +45,7 @@ def reload_loadbalancers(group, load_balancers, exclude=None):
             lb.name,
             lb.type(),
             properties=props,
-            metadata=lb.t.metadata(),
-            deletion_policy=lb.t.deletion_policy())
+            metadata=lb.t.get('Metadata'),
+            deletion_policy=lb.t.get('DeletionPolicy'))
 
         scheduler.TaskRunner(lb.update, lb_defn)()
