@@ -12,13 +12,13 @@
 #    under the License.
 
 import mock
+from oslo_config import cfg
 import six
 
 from heat.common import exception
 from heat.common import short_id
 from heat.common import template_format
 from heat.engine.clients.os import nova
-from heat.engine import node_data
 from heat.engine import scheduler
 from heat.tests.autoscaling import inline_templates
 from heat.tests import common
@@ -26,9 +26,14 @@ from heat.tests import utils
 
 
 class LaunchConfigurationTest(common.HeatTestCase):
-    def validate_launch_config(self, stack, lc_name='LaunchConfig'):
+    def setUp(self):
+        super(LaunchConfigurationTest, self).setUp()
+        cfg.CONF.set_default('heat_waitcondition_server_url',
+                             'http://server.test:8000/v1/waitcondition')
+
+    def validate_launch_config(self, t, stack, resource_name):
         # create the launch configuration resource
-        conf = stack[lc_name]
+        conf = stack['LaunchConfig']
         self.assertIsNone(conf.validate())
         scheduler.TaskRunner(conf.create)()
         self.assertEqual((conf.CREATE, conf.COMPLETE), conf.state)
@@ -59,20 +64,6 @@ class LaunchConfigurationTest(common.HeatTestCase):
         self.assertIsNone(rsrc.resource_id)
         self.assertEqual('LaunchConfig', rsrc.FnGetRefId())
 
-    def test_launch_config_refid_convergence_cache_data(self):
-        t = template_format.parse(inline_templates.as_template)
-        cache_data = {'LaunchConfig': node_data.NodeData.from_dict({
-            'uuid': mock.ANY,
-            'id': mock.ANY,
-            'action': 'CREATE',
-            'status': 'COMPLETE',
-            'reference_id': 'convg_xyz'
-        })}
-        stack = utils.parse_stack(t, params=inline_templates.as_params,
-                                  cache_data=cache_data)
-        rsrc = stack.defn['LaunchConfig']
-        self.assertEqual('convg_xyz', rsrc.FnGetRefId())
-
     def test_launch_config_create_with_instanceid(self):
         t = template_format.parse(inline_templates.as_template)
         lcp = t['Resources']['LaunchConfig']['Properties']
@@ -92,12 +83,15 @@ class LaunchConfigurationTest(common.HeatTestCase):
         self.stub_ImageConstraint_validate()
         self.stub_FlavorConstraint_validate()
         self.stub_SnapshotConstraint_validate()
-        self.stub_ServerConstraint_validate()
+        self.patchobject(nova.ServerConstraint, 'validate', return_value=True)
+        self.m.ReplayAll()
 
         self.assertIsNone(rsrc.validate())
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
 
+        self.m.VerifyAll()
+
     def test_lc_validate_without_InstanceId_and_ImageId(self):
         t = template_format.parse(inline_templates.as_template)
         lcp = t['Resources']['LaunchConfig']['Properties']
@@ -106,12 +100,13 @@ class LaunchConfigurationTest(common.HeatTestCase):
         rsrc = stack['LaunchConfig']
         self.stub_SnapshotConstraint_validate()
         self.stub_FlavorConstraint_validate()
-
+        self.m.ReplayAll()
         e = self.assertRaises(exception.StackValidationFailed,
                               rsrc.validate)
         ex_msg = ('If without InstanceId, '
                   'ImageId and InstanceType are required.')
         self.assertIn(ex_msg, six.text_type(e))
+        self.m.VerifyAll()
 
     def test_lc_validate_without_InstanceId_and_InstanceType(self):
         t = template_format.parse(inline_templates.as_template)
@@ -121,12 +116,13 @@ class LaunchConfigurationTest(common.HeatTestCase):
         rsrc = stack['LaunchConfig']
         self.stub_SnapshotConstraint_validate()
         self.stub_ImageConstraint_validate()
-
+        self.m.ReplayAll()
         e = self.assertRaises(exception.StackValidationFailed,
                               rsrc.validate)
         ex_msg = ('If without InstanceId, '
                   'ImageId and InstanceType are required.')
         self.assertIn(ex_msg, six.text_type(e))
+        self.m.VerifyAll()
 
     def test_launch_config_create_with_instanceid_not_found(self):
         t = template_format.parse(inline_templates.as_template)
@@ -134,18 +130,13 @@ class LaunchConfigurationTest(common.HeatTestCase):
         lcp['InstanceId'] = '5678'
         stack = utils.parse_stack(t, params=inline_templates.as_params)
         rsrc = stack['LaunchConfig']
-        self.stub_SnapshotConstraint_validate()
-        self.stub_ImageConstraint_validate()
-        self.stub_FlavorConstraint_validate()
 
         self.patchobject(nova.NovaClientPlugin, 'get_server',
-                         side_effect=exception.EntityNotFound(
-                             entity='Server', name='5678'))
+                         side_effect=exception.ServerNotFound(server='5678'))
         msg = ("Property error: "
                "Resources.LaunchConfig.Properties.InstanceId: "
-               "Error validating value '5678': The Server (5678) "
+               "Error validating value '5678': The server (5678) "
                "could not be found.")
-
         exc = self.assertRaises(exception.StackValidationFailed,
                                 rsrc.validate)
         self.assertIn(msg, six.text_type(exc))
@@ -159,13 +150,17 @@ class LaunchConfigurationTest(common.HeatTestCase):
 
         self.stub_ImageConstraint_validate()
         self.stub_FlavorConstraint_validate()
+        self.m.ReplayAll()
 
         e = self.assertRaises(exception.StackValidationFailed,
-                              self.validate_launch_config, stack)
+                              self.validate_launch_config, t,
+                              stack, 'LaunchConfig')
 
         self.assertIn("Ebs is missing, this is required",
                       six.text_type(e))
 
+        self.m.VerifyAll()
+
     def test_validate_BlockDeviceMappings_without_SnapshotId_property(self):
         t = template_format.parse(inline_templates.as_template)
         lcp = t['Resources']['LaunchConfig']['Properties']
@@ -176,12 +171,15 @@ class LaunchConfigurationTest(common.HeatTestCase):
 
         self.stub_ImageConstraint_validate()
         self.stub_FlavorConstraint_validate()
+        self.m.ReplayAll()
 
         e = self.assertRaises(exception.StackValidationFailed,
-                              self.validate_launch_config, stack)
+                              self.validate_launch_config, t,
+                              stack, 'LaunchConfig')
 
         self.assertIn("SnapshotId is missing, this is required",
                       six.text_type(e))
+        self.m.VerifyAll()
 
     def test_validate_BlockDeviceMappings_without_DeviceName_property(self):
         t = template_format.parse(inline_templates.as_template)
@@ -191,14 +189,16 @@ class LaunchConfigurationTest(common.HeatTestCase):
         lcp['BlockDeviceMappings'] = bdm
         stack = utils.parse_stack(t, params=inline_templates.as_params)
         self.stub_ImageConstraint_validate()
-        self.stub_FlavorConstraint_validate()
-        self.stub_SnapshotConstraint_validate()
+        self.m.ReplayAll()
 
         e = self.assertRaises(exception.StackValidationFailed,
-                              self.validate_launch_config, stack)
+                              self.validate_launch_config, t,
+                              stack, 'LaunchConfig')
 
         excepted_error = (
             'Property error: '
             'Resources.LaunchConfig.Properties.BlockDeviceMappings[0]: '
             'Property DeviceName not assigned')
         self.assertIn(excepted_error, six.text_type(e))
+
+        self.m.VerifyAll()
