@@ -27,8 +27,8 @@ from heat.engine.resources.aws.ec2 import instance
 from heat.engine.resources.aws.ec2 import volume as aws_vol
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
-from heat.tests.openstack.cinder import test_volume_utils as vt_base
-from heat.tests.openstack.nova import fakes as fakes_nova
+from heat.tests.nova import fakes as fakes_nova
+from heat.tests import test_volume_utils as vt_base
 from heat.tests import utils
 
 
@@ -168,7 +168,6 @@ class VolumeTest(vt_base.BaseVolumeTest):
         self.m.ReplayAll()
 
         stack = utils.parse_stack(self.t, stack_name=stack_name)
-        stack._update_all_resource_data(True, False)
 
         rsrc = stack['DataVolume']
         self.assertIsNone(rsrc.validate())
@@ -309,13 +308,10 @@ class VolumeTest(vt_base.BaseVolumeTest):
         self._mock_create_server_volume_script(fva)
         self.stub_VolumeConstraint_validate()
         # delete script
-        self.fc.volumes.delete_server_volume(u'WikiDatabase',
-                                             'vol-123').AndReturn(None)
+        self.fc.volumes.get_server_volume(u'WikiDatabase',
+                                          'vol-123').AndReturn(fva)
         self.cinder_fc.volumes.get(fva.id).AndRaise(
             cinder_exp.NotFound('Not found'))
-        self.fc.volumes.get_server_volume(u'WikiDatabase', 'vol-123'
-                                          ).AndRaise(
-                                              fakes_nova.fake_exception())
 
         self.m.ReplayAll()
 
@@ -337,12 +333,9 @@ class VolumeTest(vt_base.BaseVolumeTest):
         self._mock_create_server_volume_script(fva)
         self.stub_VolumeConstraint_validate()
         # delete script
-        self.fc.volumes.delete_server_volume(u'WikiDatabase',
-                                             'vol-123').AndReturn(None)
+        self.fc.volumes.get_server_volume(u'WikiDatabase',
+                                          'vol-123').AndReturn(fva)
         self.cinder_fc.volumes.get(fva.id).AndReturn(fva)
-        self.fc.volumes.get_server_volume(u'WikiDatabase', 'vol-123'
-                                          ).AndRaise(
-                                              fakes_nova.fake_exception())
 
         self.m.ReplayAll()
 
@@ -402,8 +395,11 @@ class VolumeTest(vt_base.BaseVolumeTest):
         self.stub_VolumeConstraint_validate()
         # delete script
         fva = vt_base.FakeVolume('in-use')
+        self.fc.volumes.get_server_volume(u'WikiDatabase',
+                                          'vol-123').AndReturn(fva)
+        self.cinder_fc.volumes.get(fva.id).AndReturn(fva)
         self.fc.volumes.delete_server_volume(
-            'WikiDatabase', 'vol-123').AndReturn(None)
+            'WikiDatabase', 'vol-123').MultipleTimes().AndReturn(None)
         self.cinder_fc.volumes.get(fva.id).AndReturn(
             vt_base.FakeVolume('error', id=fva.id))
         self.m.ReplayAll()
@@ -449,12 +445,12 @@ class VolumeTest(vt_base.BaseVolumeTest):
                                       stack_name)
 
         self.cinder_fc.volumes.get(fv.id).AndReturn(
-            vt_base.FakeVolume('deleting'))
+            vt_base.FakeVolume('available'))
+        self.cinder_fc.volumes.delete(fv.id).AndReturn(True)
         self.cinder_fc.volumes.get(fv.id).AndReturn(
             vt_base.FakeVolume('deleting'))
         self.cinder_fc.volumes.get(fv.id).AndRaise(
-            cinder_exp.NotFound('NotFound'))
-
+            cinder_exp.NotFound('Not found'))
         self.m.ReplayAll()
 
         stack = utils.parse_stack(self.t, stack_name=stack_name)
@@ -463,31 +459,6 @@ class VolumeTest(vt_base.BaseVolumeTest):
 
         self.m.VerifyAll()
 
-    def test_volume_delete_error(self):
-        fv = vt_base.FakeVolume('creating')
-        stack_name = 'test_volume_deleting_stack'
-
-        fv = self._mock_create_volume(vt_base.FakeVolume('creating'),
-                                      stack_name)
-
-        self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
-        self.cinder_fc.volumes.delete(fv.id).AndReturn(True)
-        self.cinder_fc.volumes.get(fv.id).AndReturn(
-            vt_base.FakeVolume('deleting'))
-        self.cinder_fc.volumes.get(fv.id).AndReturn(
-            vt_base.FakeVolume('error_deleting'))
-
-        self.m.ReplayAll()
-
-        stack = utils.parse_stack(self.t, stack_name=stack_name)
-        rsrc = self.create_volume(self.t, stack, 'DataVolume')
-        deleter = scheduler.TaskRunner(rsrc.destroy)
-        self.assertRaisesRegex(exception.ResourceFailure,
-                               ".*ResourceInError.*error_deleting.*delete",
-                               deleter)
-
-        self.m.VerifyAll()
-
     def test_volume_update_not_supported(self):
         stack_name = 'test_volume_updnotsup_stack'
         fv = vt_base.FakeVolume('creating')
@@ -518,7 +489,6 @@ class VolumeTest(vt_base.BaseVolumeTest):
     def test_volume_check(self):
         stack = utils.parse_stack(self.t, stack_name='volume_check')
         res = stack['DataVolume']
-        res.state_set(res.CREATE, res.COMPLETE)
         fake_volume = vt_base.FakeVolume('available')
         cinder = mock.Mock()
         cinder.volumes.get.return_value = fake_volume
@@ -528,14 +498,13 @@ class VolumeTest(vt_base.BaseVolumeTest):
         self.assertEqual((res.CHECK, res.COMPLETE), res.state)
 
         fake_volume = vt_base.FakeVolume('in-use')
-        res.client().volumes.get.return_value = fake_volume
+        res.cinder().volumes.get.return_value = fake_volume
         scheduler.TaskRunner(res.check)()
         self.assertEqual((res.CHECK, res.COMPLETE), res.state)
 
     def test_volume_check_not_available(self):
         stack = utils.parse_stack(self.t, stack_name='volume_check_na')
         res = stack['DataVolume']
-        res.state_set(res.CREATE, res.COMPLETE)
         cinder = mock.Mock()
         fake_volume = vt_base.FakeVolume('foobar')
         cinder.volumes.get.return_value = fake_volume
@@ -549,7 +518,6 @@ class VolumeTest(vt_base.BaseVolumeTest):
     def test_volume_check_fail(self):
         stack = utils.parse_stack(self.t, stack_name='volume_check_fail')
         res = stack['DataVolume']
-        res.state_set(res.CREATE, res.COMPLETE)
         cinder = mock.Mock()
         cinder.volumes.get.side_effect = Exception('boom')
         self.patchobject(res, 'client', return_value=cinder)
@@ -566,10 +534,8 @@ class VolumeTest(vt_base.BaseVolumeTest):
 
         # snapshot script
         self.m.StubOutWithMock(self.cinder_fc.backups, 'create')
-        self.m.StubOutWithMock(self.cinder_fc.backups, 'get')
-        fb = vt_base.FakeBackup('available')
-        self.cinder_fc.backups.create(fv.id).AndReturn(fb)
-        self.cinder_fc.backups.get(fb.id).AndReturn(fb)
+        self.cinder_fc.backups.create(fv.id).AndReturn(
+            vt_base.FakeBackup('available'))
         self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
         self._mock_delete_volume(fv)
 
@@ -590,11 +556,10 @@ class VolumeTest(vt_base.BaseVolumeTest):
                                       stack_name)
 
         # snapshot script
+        self.cinder_fc.volumes.get(fv.id).AndReturn(fv)
         self.m.StubOutWithMock(self.cinder_fc.backups, 'create')
-        self.m.StubOutWithMock(self.cinder_fc.backups, 'get')
         fb = vt_base.FakeBackup('error')
         self.cinder_fc.backups.create(fv.id).AndReturn(fb)
-        self.cinder_fc.backups.get(fb.id).AndReturn(fb)
         self.m.ReplayAll()
 
         self.t['Resources']['DataVolume']['DeletionPolicy'] = 'Snapshot'
@@ -645,7 +610,6 @@ class VolumeTest(vt_base.BaseVolumeTest):
         # create script
         cinder.CinderClientPlugin._create().AndReturn(
             self.cinder_fc)
-        self.patchobject(self.cinder_fc.backups, 'get')
         self.m.StubOutWithMock(self.cinder_fc.restores, 'restore')
         self.cinder_fc.restores.restore('backup-123').AndReturn(fvbr)
         self.cinder_fc.volumes.get('vol-123').AndReturn(fv)
@@ -674,7 +638,6 @@ class VolumeTest(vt_base.BaseVolumeTest):
         # create script
         cinder.CinderClientPlugin._create().AndReturn(
             self.cinder_fc)
-        self.patchobject(self.cinder_fc.backups, 'get')
         self.m.StubOutWithMock(self.cinder_fc.restores, 'restore')
         self.cinder_fc.restores.restore('backup-123').AndReturn(fvbr)
         self.cinder_fc.volumes.get('vol-123').AndReturn(fv)
@@ -740,14 +703,3 @@ class VolumeTest(vt_base.BaseVolumeTest):
                       six.text_type(ex))
         self.assertEqual((rsrc.UPDATE, rsrc.FAILED), rsrc.state)
         self.m.VerifyAll()
-
-    def test_validate_deletion_policy(self):
-        cfg.CONF.set_override('backups_enabled', False, group='volumes')
-        stack_name = 'test_volume_validate_deletion_policy'
-        self.t['Resources']['DataVolume']['DeletionPolicy'] = 'Snapshot'
-        stack = utils.parse_stack(self.t, stack_name=stack_name)
-        rsrc = self.get_volume(self.t, stack, 'DataVolume')
-        self.assertRaisesRegex(
-            exception.StackValidationFailed,
-            'volume backup service is not enabled',
-            rsrc.validate)
