@@ -11,15 +11,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from heat.common.i18n import _
+from oslo_log import log as logging
+import six
+
 from heat.common.i18n import _LW
 from heat.engine import attributes
 from heat.engine import constraints
 from heat.engine import properties
 from heat.engine import resource
-from heat.engine import signal_responder
-from heat.engine import stack_user
-from heat.openstack.common import log as logging
+from heat.engine.resources import signal_responder
+from heat.engine.resources import stack_resource
+from heat.engine.resources import stack_user
 
 LOG = logging.getLogger(__name__)
 
@@ -58,10 +60,11 @@ class GenericResource(resource.Resource):
 
 class ResWithComplexPropsAndAttrs(GenericResource):
 
-    properties_schema = {'a_string': {'Type': 'String'},
-                         'a_list': {'Type': 'List'},
-                         'a_map': {'Type': 'Map'},
-                         'an_int': {'Type': 'Integer'}}
+    properties_schema = {
+        'a_string': properties.Schema(properties.Schema.STRING),
+        'a_list': properties.Schema(properties.Schema.LIST),
+        'a_map': properties.Schema(properties.Schema.MAP),
+        'an_int': properties.Schema(properties.Schema.INTEGER)}
 
     attributes_schema = {'list': attributes.Schema('A list'),
                          'map': attributes.Schema('A map'),
@@ -76,8 +79,9 @@ class ResWithComplexPropsAndAttrs(GenericResource):
 
 
 class ResourceWithProps(GenericResource):
-    properties_schema = {'Foo': {'Type': 'String'},
-                         'FooInt': {'Type': 'Integer'}}
+    properties_schema = {
+        'Foo': properties.Schema(properties.Schema.STRING),
+        'FooInt': properties.Schema(properties.Schema.INTEGER)}
 
 
 class ResourceWithPropsAndAttrs(ResourceWithProps):
@@ -85,7 +89,7 @@ class ResourceWithPropsAndAttrs(ResourceWithProps):
 
 
 class ResourceWithResourceID(GenericResource):
-    properties_schema = {'ID': {'Type': 'String'}}
+    properties_schema = {'ID': properties.Schema(properties.Schema.STRING)}
 
     def handle_create(self):
         super(ResourceWithResourceID, self).handle_create()
@@ -124,8 +128,17 @@ class ResourceWithComplexAttributes(GenericResource):
 
 
 class ResourceWithRequiredProps(GenericResource):
-    properties_schema = {'Foo': {'Type': 'String',
-                                 'Required': True}}
+    properties_schema = {'Foo': properties.Schema(properties.Schema.STRING,
+                                                  required=True)}
+
+
+class ResourceWithMultipleRequiredProps(GenericResource):
+    properties_schema = {'Foo1': properties.Schema(properties.Schema.STRING,
+                                                   required=True),
+                         'Foo2': properties.Schema(properties.Schema.STRING,
+                                                   required=True),
+                         'Foo3': properties.Schema(properties.Schema.STRING,
+                                                   required=True)}
 
 
 class SignalResource(signal_responder.SignalResponder):
@@ -137,16 +150,12 @@ class SignalResource(signal_responder.SignalResponder):
         self.resource_id_set(self._get_user_id())
 
     def handle_signal(self, details=None):
-        if self.action in (self.SUSPEND, self.DELETE):
-            msg = _('Cannot signal resource during %s') % self.action
-            raise Exception(msg)
-
         LOG.warn(_LW('Signaled resource (Type "%(type)s") %(details)s'),
                  {'type': self.type(), 'details': details})
 
     def _resolve_attribute(self, name):
         if name == 'AlarmUrl' and self.resource_id is not None:
-            return unicode(self._get_signed_url())
+            return six.text_type(self._get_signed_url())
 
 
 class StackUserResource(stack_user.StackUser):
@@ -159,7 +168,34 @@ class StackUserResource(stack_user.StackUser):
 
 
 class ResourceWithCustomConstraint(GenericResource):
-    properties_schema = \
-        {'Foo': properties.Schema(
+    properties_schema = {
+        'Foo': properties.Schema(
             properties.Schema.STRING,
             constraints=[constraints.CustomConstraint('neutron.network')])}
+
+
+class StackResourceType(stack_resource.StackResource, GenericResource):
+    def physical_resource_name(self):
+        return "cb2f2b28-a663-4683-802c-4b40c916e1ff"
+
+    def set_template(self, nested_template, params):
+        self.nested_template = nested_template
+        self.nested_params = params
+
+    def handle_create(self):
+        return self.create_with_template(self.nested_template,
+                                         self.nested_params)
+
+    def handle_adopt(self, resource_data):
+        return self.create_with_template(self.nested_template,
+                                         self.nested_params,
+                                         adopt_data=resource_data)
+
+    def handle_delete(self):
+        self.delete_nested()
+
+    def has_nested(self):
+        if self.nested() is not None:
+            return True
+
+        return False
