@@ -26,50 +26,62 @@ from heat.tests import utils
 
 
 firewall_template = '''
-heat_template_version: 2015-04-30
-description: Template to test neutron firewall resource
-resources:
-  firewall:
-    type: OS::Neutron::Firewall
-    properties:
-      name: test-firewall
-      firewall_policy_id: policy-id
-      admin_state_up: True
-      shared: True
-      value_specs:
-         router_ids:
-           - router_1
-           - router_2
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test neutron firewall resource",
+  "Parameters" : {},
+  "Resources" : {
+    "firewall": {
+      "Type": "OS::Neutron::Firewall",
+      "Properties": {
+        "name": "test-firewall",
+        "firewall_policy_id": "policy-id",
+        "admin_state_up": True,
+        "shared": True,
+      }
+    }
+  }
+}
 '''
 
 firewall_policy_template = '''
-heat_template_version: 2015-04-30
-description: Template to test neutron firewall policy resource
-resources:
-  firewall_policy:
-    type: OS::Neutron::FirewallPolicy
-    properties:
-      name: test-firewall-policy
-      shared: True
-      audited: True
-      firewall_rules:
-        - rule-id-1
-        - rule-id-2
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test neutron firewall policy resource",
+  "Parameters" : {},
+  "Resources" : {
+    "firewall_policy": {
+      "Type": "OS::Neutron::FirewallPolicy",
+      "Properties": {
+        "name": "test-firewall-policy",
+        "shared": True,
+        "audited": True,
+        "firewall_rules": ['rule-id-1', 'rule-id-2'],
+      }
+    }
+  }
+}
 '''
 
 firewall_rule_template = '''
-heat_template_version: 2015-04-30
-description: Template to test neutron firewall rule resource
-resources:
-  firewall_rule:
-    type: OS::Neutron::FirewallRule
-    properties:
-      name: test-firewall-rule
-      shared: True
-      protocol: tcp
-      action: allow
-      enabled: True
-      ip_version: 4
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test neutron firewall rule resource",
+  "Parameters" : {},
+  "Resources" : {
+    "firewall_rule": {
+      "Type": "OS::Neutron::FirewallRule",
+      "Properties": {
+        "name": "test-firewall-rule",
+        "shared": True,
+        "protocol": "tcp",
+        "action": "allow",
+        "enabled": True,
+        "ip_version": "4",
+      }
+    }
+  }
+}
 '''
 
 
@@ -86,7 +98,6 @@ class FirewallTest(common.HeatTestCase):
         neutronclient.Client.create_firewall({
             'firewall': {
                 'name': 'test-firewall', 'admin_state_up': True,
-                'router_ids': ['router_1', 'router_2'],
                 'firewall_policy_id': 'policy-id', 'shared': True}}
         ).AndReturn({'firewall': {'id': '5678'}})
 
@@ -107,7 +118,6 @@ class FirewallTest(common.HeatTestCase):
         neutronclient.Client.create_firewall({
             'firewall': {
                 'name': 'test-firewall', 'admin_state_up': True,
-                'router_ids': ['router_1', 'router_2'],
                 'firewall_policy_id': 'policy-id', 'shared': True}}
         ).AndRaise(exceptions.NeutronClientException())
         self.m.ReplayAll()
