@@ -13,7 +13,6 @@
 
 import copy
 
-import mock
 import mox
 from neutronclient.common import exceptions as qe
 from neutronclient.neutron import v2_0 as neutronV20
@@ -24,8 +23,6 @@ from heat.common import template_format
 from heat.engine.cfn import functions as cfn_funcs
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
-from heat.engine import stack as parser
-from heat.engine import template as tmpl
 from heat.tests import common
 from heat.tests import utils
 
@@ -131,19 +128,6 @@ class NeutronFloatingIPTest(common.HeatTestCase):
         self.m.StubOutWithMock(neutronV20,
                                'find_resourceid_by_name_or_id')
 
-    def test_floating_ip_validate(self):
-        t = template_format.parse(neutron_floating_no_assoc_template)
-        stack = utils.parse_stack(t)
-        fip = stack['floating_ip']
-        self.assertIsNone(fip.validate())
-        del t['resources']['floating_ip']['properties']['port_id']
-        t['resources']['floating_ip']['properties'][
-            'fixed_ip_address'] = '10.0.0.12'
-        stack = utils.parse_stack(t)
-        fip = stack['floating_ip']
-        self.assertRaises(exception.ResourcePropertyDependency,
-                          fip.validate)
-
     def test_floating_ip_router_interface(self):
         t = template_format.parse(neutron_floating_template)
         del t['resources']['gateway']
@@ -157,21 +141,11 @@ class NeutronFloatingIPTest(common.HeatTestCase):
     def test_floating_ip_deprecated_router_interface(self):
         t = template_format.parse(neutron_floating_template_deprecated)
         del t['resources']['gateway']
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'network',
-            'abcd1234'
-        ).MultipleTimes().AndReturn('abcd1234')
         self._test_floating_ip(t, resolve_neutron=False)
 
     def test_floating_ip_deprecated_router_gateway(self):
         t = template_format.parse(neutron_floating_template_deprecated)
         del t['resources']['router_interface']
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'network',
-            'abcd1234'
-        ).MultipleTimes().AndReturn('abcd1234')
         self._test_floating_ip(t, resolve_neutron=False, r_iface=False)
 
     def _test_floating_ip(self, tmpl, resolve_neutron=True, r_iface=True):
@@ -240,28 +214,6 @@ class NeutronFloatingIPTest(common.HeatTestCase):
 
         self.m.VerifyAll()
 
-    def test_FnGetRefId(self):
-        t = template_format.parse(neutron_floating_template)
-        stack = utils.parse_stack(t)
-        rsrc = stack['floating_ip']
-        rsrc.resource_id = 'xyz'
-        self.assertEqual('xyz', rsrc.FnGetRefId())
-
-    def test_FnGetRefId_convergence_cache_data(self):
-        t = template_format.parse(neutron_floating_template)
-        template = tmpl.Template(t)
-        stack = parser.Stack(utils.dummy_context(), 'test', template,
-                             cache_data={
-                                 'floating_ip': {
-                                     'uuid': mock.ANY,
-                                     'id': mock.ANY,
-                                     'action': 'CREATE',
-                                     'status': 'COMPLETE',
-                                     'reference_id': 'abc'}})
-
-        rsrc = stack['floating_ip']
-        self.assertEqual('abc', rsrc.FnGetRefId())
-
     def test_port(self):
         self.stub_NetworkConstraint_validate()
         self.stub_SubnetConstraint_validate()
@@ -584,42 +536,6 @@ class NeutronFloatingIPTest(common.HeatTestCase):
         self.assertIn(stack['floating_ip'], required_by)
         p_show.assert_called_once_with('net_uuid')
 
-    def test_floatingip_create_specify_ip_address(self):
-        t = template_format.parse(neutron_floating_template)
-        props = t['resources']['floating_ip']['properties']
-        props['floating_ip_address'] = '172.24.4.98'
-        stack = utils.parse_stack(t)
-
-        self.stub_NetworkConstraint_validate()
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'network',
-            'abcd1234'
-        ).AndReturn('xyz1234')
-        neutronclient.Client.create_floatingip({
-            'floatingip': {'floating_network_id': u'xyz1234',
-                           'floating_ip_address': '172.24.4.98'}
-        }).AndReturn({'floatingip': {
-            'status': 'ACTIVE',
-            'id': 'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
-            'floating_ip_address': '172.24.4.98'
-        }})
-        neutronclient.Client.show_floatingip(
-            'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
-        ).MultipleTimes().AndReturn({'floatingip': {
-            'status': 'ACTIVE',
-            'id': 'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
-            'floating_ip_address': '172.24.4.98'
-        }})
-
-        self.m.ReplayAll()
-        fip = stack['floating_ip']
-        scheduler.TaskRunner(fip.create)()
-        self.assertEqual((fip.CREATE, fip.COMPLETE), fip.state)
-        self.assertEqual('172.24.4.98', fip.FnGetAtt('floating_ip_address'))
-
-        self.m.VerifyAll()
-
     def test_floatip_port(self):
         neutronV20.find_resourceid_by_name_or_id(
             mox.IsA(neutronclient.Client),
