@@ -32,140 +32,192 @@ from heat.tests import utils
 
 
 health_monitor_template = '''
-heat_template_version: 2015-04-30
-description: Template to test load balancer resources
-resources:
-  monitor:
-    type: OS::Neutron::HealthMonitor
-    properties:
-      type: HTTP
-      delay: 3
-      max_retries: 5
-      timeout: 10
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test load balancer resources",
+  "Parameters" : {},
+  "Resources" : {
+    "monitor": {
+      "Type": "OS::Neutron::HealthMonitor",
+      "Properties": {
+        "type": "HTTP",
+        "delay": 3,
+        "max_retries": 5,
+        "timeout": 10
+      }
+    }
+  }
+}
 '''
 
 pool_template_with_vip_subnet = '''
-heat_template_version: 2015-04-30
-description: Template to test load balancer resources
-resources:
-  pool:
-    type: OS::Neutron::Pool
-    properties:
-      protocol: HTTP
-      subnet: sub123
-      lb_method: ROUND_ROBIN
-      vip:
-        protocol_port: 80
-        subnet: sub9999
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test load balancer resources",
+  "Parameters" : {},
+  "Resources" : {
+    "pool": {
+      "Type": "OS::Neutron::Pool",
+      "Properties": {
+        "protocol": "HTTP",
+        "subnet": "sub123",
+        "lb_method": "ROUND_ROBIN",
+        "vip": {
+          "protocol_port": 80,
+          "subnet": "sub9999"
+        }
+      }
+    }
+  }
+}
 '''
 
-pool_template_with_provider = '''
-heat_template_version: 2015-04-30
-description: Template to test load balancer resources
-resources:
-  pool:
-    type: OS::Neutron::Pool
-    properties:
-      protocol: HTTP
-      subnet: sub123
-      lb_method: ROUND_ROBIN
-      provider: test_prov
-      vip:
-        protocol_port: 80
-
+pool_template_deprecated = '''
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test load balancer resources",
+  "Parameters" : {},
+  "Resources" : {
+    "pool": {
+      "Type": "OS::Neutron::Pool",
+      "Properties": {
+        "protocol": "HTTP",
+        "subnet_id": "sub123",
+        "lb_method": "ROUND_ROBIN",
+        "vip": {
+          "protocol_port": 80
+        }
+      }
+    }
+  }
+}
 '''
 
 pool_template = '''
-heat_template_version: 2015-04-30
-description: Template to test load balancer resources
-resources:
-  pool:
-    type: OS::Neutron::Pool
-    properties:
-      protocol: HTTP
-      subnet: sub123
-      lb_method: ROUND_ROBIN
-      vip:
-        protocol_port: 80
-
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test load balancer resources",
+  "Parameters" : {},
+  "Resources" : {
+    "pool": {
+      "Type": "OS::Neutron::Pool",
+      "Properties": {
+        "protocol": "HTTP",
+        "subnet": "sub123",
+        "lb_method": "ROUND_ROBIN",
+        "vip": {
+          "protocol_port": 80
+        }
+      }
+    }
+  }
+}
 '''
 
-pool_template_deprecated = pool_template.replace('subnet', 'subnet_id')
 
 member_template = '''
-heat_template_version: 2015-04-30
-description: Template to test load balancer member
-resources:
-  member:
-    type: OS::Neutron::PoolMember
-    properties:
-      protocol_port: 8080
-      pool_id: pool123
-      address: 1.2.3.4
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test load balancer member",
+  "Resources" : {
+    "member": {
+      "Type": "OS::Neutron::PoolMember",
+      "Properties": {
+        "protocol_port": 8080,
+        "pool_id": "pool123",
+        "address": "1.2.3.4"
+      }
+    }
+  }
+}
 '''
 
 lb_template = '''
-heat_template_version: 2015-04-30
-description: Template to test load balancer resources
-resources:
-  lb:
-    type: OS::Neutron::LoadBalancer
-    properties:
-      protocol_port: 8080
-      pool_id: pool123
-      members: [1234]
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test load balancer resources",
+  "Parameters" : {},
+  "Resources" : {
+    "lb": {
+      "Type": "OS::Neutron::LoadBalancer",
+      "Properties": {
+        "protocol_port": 8080,
+        "pool_id": "pool123",
+        "members": ["1234"]
+      }
+    }
+  }
+}
 '''
 
 
 pool_with_session_persistence_template = '''
-heat_template_version: 2015-04-30
-description: Template to test load balancer resources
-resources:
-  pool:
-    type: OS::Neutron::Pool
-    properties:
-      protocol: HTTP
-      subnet: sub123
-      lb_method: ROUND_ROBIN
-      vip:
-        protocol_port: 80
-        session_persistence:
-          type: APP_COOKIE
-          cookie_name: cookie
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test load balancer resources wit",
+  "Parameters" : {},
+  "Resources" : {
+    "pool": {
+      "Type": "OS::Neutron::Pool",
+      "Properties": {
+        "protocol": "HTTP",
+        "subnet": "sub123",
+        "lb_method": "ROUND_ROBIN",
+        "vip": {
+          "protocol_port": 80,
+          "session_persistence": {
+            "type": "APP_COOKIE",
+            "cookie_name": "cookie"
+          }
+        }
+      }
+    }
+  }
+}
 '''
 
 
 pool_with_health_monitors_template = '''
-heat_template_version: 2015-04-30
-description: Template to test load balancer resources
-resources:
-  monitor1:
-    type: OS::Neutron::HealthMonitor
-    properties:
-      type: HTTP
-      delay: 3
-      max_retries: 5
-      timeout: 10
-
-  monitor2:
-    type: OS::Neutron::HealthMonitor
-    properties:
-      type: HTTP
-      delay: 3
-      max_retries: 5
-      timeout: 10
-
-  pool:
-    type: OS::Neutron::Pool
-    properties:
-      protocol: HTTP
-      subnet_id: sub123
-      lb_method: ROUND_ROBIN
-      vip:
-        protocol_port: 80
-      monitors:
-        - {get_resource: monitor1}
-        - {get_resource: monitor2}
+{
+  "AWSTemplateFormatVersion" : "2010-09-09",
+  "Description" : "Template to test load balancer resources",
+  "Parameters" : {},
+  "Resources" : {
+    "monitor1": {
+      "Type": "OS::Neutron::HealthMonitor",
+      "Properties": {
+        "type": "HTTP",
+        "delay": 3,
+        "max_retries": 5,
+        "timeout": 10
+        }
+    },
+    "monitor2": {
+      "Type": "OS::Neutron::HealthMonitor",
+      "Properties": {
+        "type": "HTTP",
+        "delay": 3,
+        "max_retries": 5,
+        "timeout": 10
+        }
+    },
+    "pool": {
+      "Type": "OS::Neutron::Pool",
+      "Properties": {
+        "protocol": "HTTP",
+        "subnet_id": "sub123",
+        "lb_method": "ROUND_ROBIN",
+        "vip": {
+          "protocol_port": 80
+        },
+        "monitors": [
+          {"Ref": "monitor1"},
+          {"Ref": "monitor2"}
+        ]
+      }
+    }
+  }
+}
 '''
 
 
@@ -334,12 +386,12 @@ class PoolTest(common.HeatTestCase):
         stvippsn['vip']['subnet_id'] = 'sub123'
         self.stub_SubnetConstraint_validate()
 
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'subnet',
-            'sub123'
-        ).AndReturn('sub123')
         if resolve_neutron and with_vip_subnet:
+            neutronV20.find_resourceid_by_name_or_id(
+                mox.IsA(neutronclient.Client),
+                'subnet',
+                'sub123'
+            ).AndReturn('sub123')
             neutronV20.find_resourceid_by_name_or_id(
                 mox.IsA(neutronclient.Client),
                 'subnet',
@@ -350,6 +402,11 @@ class PoolTest(common.HeatTestCase):
                                             ).AndReturn({'vip': {'id': 'xyz'}})
 
         elif resolve_neutron and not with_vip_subnet:
+            neutronV20.find_resourceid_by_name_or_id(
+                mox.IsA(neutronclient.Client),
+                'subnet',
+                'sub123'
+            ).AndReturn('sub123')
             snippet = template_format.parse(pool_template)
             neutronclient.Client.create_vip(stvippsn
                                             ).AndReturn({'vip': {'id': 'xyz'}})
@@ -563,46 +620,12 @@ class PoolTest(common.HeatTestCase):
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
         self.m.VerifyAll()
 
-    def test_create_pool_with_provider(self):
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'subnet',
-            'sub123'
-        ).MultipleTimes().AndReturn('sub123')
-        neutronclient.Client.create_pool({
-            'pool': {
-                'subnet_id': 'sub123', 'protocol': u'HTTP',
-                'name': utils.PhysName('test_stack', 'pool'),
-                'lb_method': 'ROUND_ROBIN', 'admin_state_up': True,
-                'provider': 'test_prov'}}
-        ).AndReturn({'pool': {'id': '5678'}})
-        neutronclient.Client.create_vip({
-            'vip': {
-                'protocol': u'HTTP', 'name': 'pool.vip',
-                'admin_state_up': True, 'subnet_id': u'sub123',
-                'pool_id': '5678', 'protocol_port': 80}}
-        ).AndReturn({'vip': {'id': 'xyz'}})
-        neutronclient.Client.show_pool('5678').MultipleTimes().AndReturn(
-            {'pool': {'status': 'ACTIVE', 'provider': 'test_prov'}})
-        neutronclient.Client.show_vip('xyz').AndReturn(
-            {'vip': {'status': 'ACTIVE'}})
-        snippet = template_format.parse(pool_template_with_provider)
-        self.stack = utils.parse_stack(snippet)
-        resource_defns = self.stack.t.resource_definitions(self.stack)
-        rsrc = loadbalancer.Pool(
-            'pool', resource_defns['pool'], self.stack)
-        self.m.ReplayAll()
-        scheduler.TaskRunner(rsrc.create)()
-        self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
-        self.assertEqual("test_prov", rsrc.FnGetAtt("provider"))
-        self.m.VerifyAll()
-
     def test_failing_validation_with_session_persistence(self):
         msg = _('Property cookie_name is required, when '
                 'session_persistence type is set to APP_COOKIE.')
         snippet = template_format.parse(pool_with_session_persistence_template)
-        pool = snippet['resources']['pool']
-        persistence = pool['properties']['vip']['session_persistence']
+        pool = snippet['Resources']['pool']
+        persistence = pool['Properties']['vip']['session_persistence']
 
         # When persistence type is set to APP_COOKIE, cookie_name is required
         persistence['type'] = 'APP_COOKIE'
@@ -655,8 +678,8 @@ class PoolTest(common.HeatTestCase):
             {'vip': {'status': 'ACTIVE'}})
 
         snippet = template_format.parse(pool_with_session_persistence_template)
-        pool = snippet['resources']['pool']
-        persistence = pool['properties']['vip']['session_persistence']
+        pool = snippet['Resources']['pool']
+        persistence = pool['Properties']['vip']['session_persistence']
 
         # change persistence type to HTTP_COOKIE that not require cookie_name
         persistence['type'] = 'HTTP_COOKIE'
@@ -816,7 +839,7 @@ class PoolTest(common.HeatTestCase):
 
         snippet = template_format.parse(pool_template)
         self.stack = utils.parse_stack(snippet)
-        snippet['resources']['pool']['properties']['monitors'] = [
+        snippet['Resources']['pool']['Properties']['monitors'] = [
             'mon123', 'mon456']
         resource_defns = self.stack.t.resource_definitions(self.stack)
         rsrc = loadbalancer.Pool('pool', resource_defns['pool'], self.stack)
@@ -869,8 +892,8 @@ class PoolMemberTest(common.HeatTestCase):
                 'address': '1.2.3.4'}}
         ).AndReturn({'member': {'id': 'member5678'}})
         snippet = template_format.parse(member_template)
-        snippet['resources']['member']['properties']['admin_state_up'] = False
-        snippet['resources']['member']['properties']['weight'] = 100
+        snippet['Resources']['member']['Properties']['admin_state_up'] = False
+        snippet['Resources']['member']['Properties']['weight'] = 100
         self.stack = utils.parse_stack(snippet)
         resource_defns = self.stack.t.resource_definitions(self.stack)
         rsrc = loadbalancer.PoolMember(
@@ -1035,7 +1058,6 @@ class PoolUpdateHealthMonitorsTest(common.HeatTestCase):
         self.m.StubOutWithMock(neutronclient.Client, 'create_vip')
         self.m.StubOutWithMock(neutronclient.Client, 'delete_vip')
         self.m.StubOutWithMock(neutronclient.Client, 'show_vip')
-        self.m.StubOutWithMock(neutronV20, 'find_resourceid_by_name_or_id')
 
     def _create_pool_with_health_monitors(self):
         neutronclient.Client.create_health_monitor({
@@ -1050,11 +1072,6 @@ class PoolUpdateHealthMonitorsTest(common.HeatTestCase):
                 'timeout': 10, 'admin_state_up': True}}
         ).AndReturn({'health_monitor': {'id': '6666'}})
         self.stub_SubnetConstraint_validate()
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'subnet',
-            'sub123'
-        ).AndReturn('sub123')
         neutronclient.Client.create_pool({
             'pool': {
                 'subnet_id': 'sub123', 'protocol': u'HTTP',
@@ -1089,8 +1106,8 @@ class PoolUpdateHealthMonitorsTest(common.HeatTestCase):
         self.assertEqual((self.stack.CREATE, self.stack.COMPLETE),
                          self.stack.state)
 
-        snippet['resources']['pool']['properties']['monitors'] = [
-            {u'get_resource': u'monitor1'}]
+        snippet['Resources']['pool']['Properties']['monitors'] = [
+            {u'Ref': u'monitor1'}]
         updated_stack = utils.parse_stack(snippet)
         self.stack.update(updated_stack)
         self.assertEqual((self.stack.UPDATE, self.stack.COMPLETE),
@@ -1112,7 +1129,7 @@ class PoolUpdateHealthMonitorsTest(common.HeatTestCase):
         self.assertEqual((self.stack.CREATE, self.stack.COMPLETE),
                          self.stack.state)
 
-        snippet['resources']['pool']['properties']['monitors'] = []
+        snippet['Resources']['pool']['Properties']['monitors'] = []
         updated_stack = utils.parse_stack(snippet)
         self.stack.update(updated_stack)
         self.assertEqual((self.stack.UPDATE, self.stack.COMPLETE),
@@ -1134,7 +1151,7 @@ class PoolUpdateHealthMonitorsTest(common.HeatTestCase):
         self.assertEqual((self.stack.CREATE, self.stack.COMPLETE),
                          self.stack.state)
 
-        snippet['resources']['pool']['properties'].pop('monitors')
+        snippet['Resources']['pool']['Properties'].pop('monitors')
         updated_stack = utils.parse_stack(snippet)
         self.stack.update(updated_stack)
         self.assertEqual((self.stack.UPDATE, self.stack.COMPLETE),
