@@ -11,16 +11,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import copy
-import mock
 import mox
 from neutronclient.common import exceptions as qe
 from neutronclient.neutron import v2_0 as neutronV20
 from neutronclient.v2_0 import client as neutronclient
-from oslo_serialization import jsonutils
 
 from heat.common import exception
 from heat.common import template_format
+from heat.engine import resource
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
 from heat.tests import common
@@ -56,18 +54,6 @@ resources:
 '''
 
 
-neutron_port_security_template = '''
-heat_template_version: 2015-04-30
-description: Template to test port Neutron resource
-resources:
-  port:
-    type: OS::Neutron::Port
-    properties:
-      network: abcd1234
-      port_security_enabled: False
-'''
-
-
 class NeutronPortTest(common.HeatTestCase):
 
     def setUp(self):
@@ -225,39 +211,6 @@ class NeutronPortTest(common.HeatTestCase):
         scheduler.TaskRunner(port.create)()
         self.m.VerifyAll()
 
-    def test_port_security_enabled(self):
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'network',
-            'abcd1234'
-        ).MultipleTimes().AndReturn('abcd1234')
-
-        neutronclient.Client.create_port({'port': {
-            'network_id': u'abcd1234',
-            'port_security_enabled': False,
-            'name': utils.PhysName('test_stack', 'port'),
-            'admin_state_up': True}}
-        ).AndReturn({'port': {
-            "status": "BUILD",
-            "id": "fc68ea2c-b60b-4b4f-bd82-94ec81110766"
-        }})
-
-        neutronclient.Client.show_port(
-            'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
-        ).AndReturn({'port': {
-            "status": "ACTIVE",
-            "id": "fc68ea2c-b60b-4b4f-bd82-94ec81110766",
-        }})
-
-        self.m.ReplayAll()
-
-        t = template_format.parse(neutron_port_security_template)
-        stack = utils.parse_stack(t)
-
-        port = stack['port']
-        scheduler.TaskRunner(port.create)()
-        self.m.VerifyAll()
-
     def test_missing_mac_address(self):
         neutronV20.find_resourceid_by_name_or_id(
             mox.IsA(neutronclient.Client),
@@ -294,42 +247,6 @@ class NeutronPortTest(common.HeatTestCase):
         scheduler.TaskRunner(port.create)()
         self.m.VerifyAll()
 
-    def test_ip_address_is_cidr(self):
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'network',
-            'abcd1234'
-        ).MultipleTimes().AndReturn('abcd1234')
-        neutronclient.Client.create_port({'port': {
-            'network_id': u'abcd1234',
-            'allowed_address_pairs': [{
-                'ip_address': u'10.0.3.0/24',
-                'mac_address': u'00-B0-D0-86-BB-F7'
-            }],
-            'name': utils.PhysName('test_stack', 'port'),
-            'admin_state_up': True}}
-        ).AndReturn({'port': {
-            "status": "BUILD",
-            "id": "2e00180a-ff9d-42c4-b701-a0606b243447"
-        }})
-        neutronclient.Client.show_port(
-            '2e00180a-ff9d-42c4-b701-a0606b243447'
-        ).AndReturn({'port': {
-            "status": "ACTIVE",
-            "id": "2e00180a-ff9d-42c4-b701-a0606b243447"
-        }})
-
-        self.m.ReplayAll()
-
-        t = template_format.parse(neutron_port_with_address_pair_template)
-        t['resources']['port']['properties'][
-            'allowed_address_pairs'][0]['ip_address'] = '10.0.3.0/24'
-        stack = utils.parse_stack(t)
-
-        port = stack['port']
-        scheduler.TaskRunner(port.create)()
-        self.m.VerifyAll()
-
     def _mock_create_with_security_groups(self, port_prop):
         neutronV20.find_resourceid_by_name_or_id(
             mox.IsA(neutronclient.Client),
@@ -410,10 +327,6 @@ class NeutronPortTest(common.HeatTestCase):
         new_props['name'] = "new_name"
         new_props['security_groups'] = [
             '8a2f582a-e1cd-480f-b85d-b02631c10656']
-        new_props['allowed_address_pairs'] = [{
-            'ip_address': u'10.0.3.0/24',
-            'mac_address': u'00-B0-D0-86-BB-F7'
-        }]
         new_props_update = new_props.copy()
         new_props_update.pop('network_id')
 
@@ -436,7 +349,6 @@ class NeutronPortTest(common.HeatTestCase):
         }})
         neutronclient.Client.show_port(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
-        ).MultipleTimes(
         ).AndReturn({'port': {
             "status": "ACTIVE",
             "id": "fc68ea2c-b60b-4b4f-bd82-94ec81110766",
@@ -482,24 +394,11 @@ class NeutronPortTest(common.HeatTestCase):
         # update port
         update_snippet = rsrc_defn.ResourceDefinition(port.name, port.type(),
                                                       new_props)
-        scheduler.TaskRunner(port.update, update_snippet)()
+        self.assertIsNone(port.handle_update(update_snippet, {}, {}))
         # update again to test port without security group
-        update_snippet1 = rsrc_defn.ResourceDefinition(port.name, port.type(),
-                                                       new_props1)
-        scheduler.TaskRunner(port.update, update_snippet1)()
-
-        # check, that update does not cause of Update Replace
-        create_snippet = rsrc_defn.ResourceDefinition(port.name, port.type(),
-                                                      props)
-        before_props = create_snippet.properties(port.properties_schema,
-                                                 port.context)
-
-        after_props = update_snippet.properties(port.properties_schema,
-                                                port.context)
-        port.translate_properties(after_props)
-        port.translate_properties(before_props)
-        self.assertIsNotNone(
-            port.update_template_diff_properties(after_props, before_props))
+        update_snippet = rsrc_defn.ResourceDefinition(port.name, port.type(),
+                                                      new_props1)
+        self.assertIsNone(port.handle_update(update_snippet, {}, {}))
 
         self.m.VerifyAll()
 
@@ -548,7 +447,7 @@ class NeutronPortTest(common.HeatTestCase):
         new_props['network'] = new_props.pop('network_id')
         update_snippet = rsrc_defn.ResourceDefinition(port.name, port.type(),
                                                       new_props)
-        self.assertRaises(exception.UpdateReplace, port._needs_update,
+        self.assertRaises(resource.UpdateReplace, port._needs_update,
                           update_snippet, port.frozen_definition(),
                           new_props, port.properties, None)
 
@@ -642,7 +541,7 @@ class NeutronPortTest(common.HeatTestCase):
         new_props['network'] = 'new_network'
         update_snippet = rsrc_defn.ResourceDefinition(port.name, port.type(),
                                                       new_props)
-        self.assertRaises(exception.UpdateReplace, port._needs_update,
+        self.assertRaises(resource.UpdateReplace, port._needs_update,
                           update_snippet, port.frozen_definition(),
                           new_props, port.properties, None)
 
@@ -785,7 +684,7 @@ class NeutronPortTest(common.HeatTestCase):
             '8a2f582a-e1cd-480f-b85d-b02631c10656']
         new_port_prop.pop('network_id')
 
-        prop_update = copy.deepcopy(new_port_prop)
+        prop_update = new_port_prop.copy()
         new_port_prop['replacement_policy'] = 'AUTO'
         new_port_prop['network'] = u'net1234'
 
@@ -798,7 +697,7 @@ class NeutronPortTest(common.HeatTestCase):
             mox.IsA(neutronclient.Client),
             'subnet',
             'sub1234'
-        ).MultipleTimes().AndReturn('sub1234')
+        ).AndReturn('sub1234')
         neutronclient.Client.create_port({'port': port_prop}).AndReturn(
             {'port': {
                 "status": "BUILD",
@@ -827,7 +726,7 @@ class NeutronPortTest(common.HeatTestCase):
             "id": "fc68ea2c-b60b-4b4f-bd82-94ec81110766"
         }})
 
-        prop_update2 = copy.deepcopy(prop_update)
+        prop_update2 = prop_update.copy()
         prop_update2['binding:vnic_type'] = 'direct'
         neutronclient.Client.update_port(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
@@ -851,96 +750,16 @@ class NeutronPortTest(common.HeatTestCase):
         # update to normal
         update_snippet = rsrc_defn.ResourceDefinition(port.name, port.type(),
                                                       new_port_prop)
-        new_port_prop2 = copy.deepcopy(new_port_prop)
         scheduler.TaskRunner(port.update, update_snippet)()
         self.assertEqual((port.UPDATE, port.COMPLETE), port.state)
         self.assertEqual('normal', port.properties['binding:vnic_type'])
 
         # update back to direct
-        new_port_prop2['binding:vnic_type'] = 'direct'
+        new_port_prop['binding:vnic_type'] = 'direct'
         update_snippet = rsrc_defn.ResourceDefinition(port.name, port.type(),
-                                                      new_port_prop2)
+                                                      new_port_prop)
         scheduler.TaskRunner(port.update, update_snippet)()
         self.assertEqual((port.UPDATE, port.COMPLETE), port.state)
         self.assertEqual('direct', port.properties['binding:vnic_type'])
 
         self.m.VerifyAll()
-
-    def test_prepare_for_replace_port_not_created(self):
-        t = template_format.parse(neutron_port_template)
-        stack = utils.parse_stack(t)
-        port = stack['port']
-        port._show_resource = mock.Mock()
-        port.data_set = mock.Mock()
-        n_client = mock.Mock()
-        port.client = mock.Mock(return_value=n_client)
-
-        self.assertIsNone(port.resource_id)
-
-        # execute prepare_for_replace
-        port.prepare_for_replace()
-
-        # check, if the port is not created, do nothing in
-        # prepare_for_replace()
-        self.assertFalse(port._show_resource.called)
-        self.assertFalse(port.data_set.called)
-        self.assertFalse(n_client.update_port.called)
-
-    def test_prepare_for_replace_port(self):
-        t = template_format.parse(neutron_port_template)
-        stack = utils.parse_stack(t)
-        port = stack['port']
-        port.resource_id = 'test_res_id'
-        _value = {
-            'fixed_ips': {
-                'subnet_id': 'test_subnet',
-                'ip_address': '42.42.42.42'
-            }
-        }
-        port._show_resource = mock.Mock(return_value=_value)
-        port.data_set = mock.Mock()
-        n_client = mock.Mock()
-        port.client = mock.Mock(return_value=n_client)
-
-        # execute prepare_for_replace
-        port.prepare_for_replace()
-
-        # check, that data was stored
-        port.data_set.assert_called_once_with(
-            'port_fip', jsonutils.dumps(_value.get('fixed_ips')))
-
-        # check, that port was updated and ip was removed
-        expected_props = {'port': {'fixed_ips': []}}
-        n_client.update_port.assert_called_once_with('test_res_id',
-                                                     expected_props)
-
-    def test_restore_after_rollback_port(self):
-        t = template_format.parse(neutron_port_template)
-        stack = utils.parse_stack(t)
-        new_port = stack['port']
-        new_port.resource_id = 'new_res_id'
-        # mock backup stack to return only one mocked old_port
-        old_port = mock.Mock()
-        new_port.stack._backup_stack = mock.Mock()
-        new_port.stack._backup_stack().resources.get.return_value = old_port
-        old_port.resource_id = 'old_res_id'
-        _value = {
-            'subnet_id': 'test_subnet',
-            'ip_address': '42.42.42.42'
-        }
-        old_port.data = mock.Mock(
-            return_value={'port_fip': jsonutils.dumps(_value)})
-
-        n_client = mock.Mock()
-        new_port.client = mock.Mock(return_value=n_client)
-
-        # execute prepare_for_replace
-        new_port.restore_after_rollback()
-
-        # check, that ports were updated: old port get ip and
-        # same ip was removed from old port
-        expected_new_props = {'port': {'fixed_ips': []}}
-        expected_old_props = {'port': {'fixed_ips': _value}}
-        n_client.update_port.assert_has_calls([
-            mock.call('new_res_id', expected_new_props),
-            mock.call('old_res_id', expected_old_props)])
