@@ -16,11 +16,11 @@ import copy
 
 from heat.common import template_format
 from heat.engine import resource
-from heat.engine.resources import cloud_watch
+from heat.engine.resources.openstack.heat import cloud_watch
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
 from heat.engine import watchrule
-from heat.tests.common import HeatTestCase
+from heat.tests import common
 from heat.tests import utils
 
 
@@ -50,7 +50,7 @@ alarm_template = '''
 '''
 
 
-class CloudWatchAlarmTest(HeatTestCase):
+class CloudWatchAlarmTest(common.HeatTestCase):
     def setUp(self):
         super(CloudWatchAlarmTest, self).setUp()
 
@@ -71,7 +71,7 @@ class CloudWatchAlarmTest(HeatTestCase):
         '''
         t = template_format.parse(alarm_template)
 
-        #short circuit the alarm's references
+        # short circuit the alarm's references
         properties = t['Resources']['MEMAlarmHigh']['Properties']
         properties['AlarmActions'] = ['a']
         properties['Dimensions'] = [{'a': 'v'}]
@@ -107,7 +107,7 @@ class CloudWatchAlarmTest(HeatTestCase):
         '''
         t = template_format.parse(alarm_template)
 
-        #short circuit the alarm's references
+        # short circuit the alarm's references
         properties = t['Resources']['MEMAlarmHigh']['Properties']
         properties['AlarmActions'] = ['a']
         properties['Dimensions'] = [{'a': 'v'}]
@@ -132,7 +132,8 @@ class CloudWatchAlarmTest(HeatTestCase):
 
     def test_suspend_resume(self):
         t = template_format.parse(alarm_template)
-        stack = utils.parse_stack(t)
+        stack_name = "test_cw_alarm_sus_res_stack"
+        stack = utils.parse_stack(t, stack_name=stack_name)
         # the watch rule needs a valid stack_id
         stack.store()
 
@@ -144,7 +145,7 @@ class CloudWatchAlarmTest(HeatTestCase):
         self.ctx = utils.dummy_context()
 
         wr = watchrule.WatchRule.load(
-            self.ctx, watch_name="test_stack-MEMAlarmHigh")
+            self.ctx, watch_name="%s-MEMAlarmHigh" % stack_name)
 
         self.assertEqual(watchrule.WatchRule.SUSPENDED, wr.state)
 
@@ -152,7 +153,7 @@ class CloudWatchAlarmTest(HeatTestCase):
         self.assertEqual((rsrc.RESUME, rsrc.COMPLETE), rsrc.state)
 
         wr = watchrule.WatchRule.load(
-            self.ctx, watch_name="test_stack-MEMAlarmHigh")
+            self.ctx, watch_name="%s-MEMAlarmHigh" % stack_name)
 
         self.assertEqual(watchrule.WatchRule.NODATA, wr.state)
 
