@@ -20,12 +20,12 @@ from heat.engine.clients.os import neutron
 from heat.engine.clients.os import nova
 from heat.engine import environment
 from heat.engine import parser
-from heat.engine.resources import instance as instances
-from heat.engine.resources import network_interface as network_interfaces
+from heat.engine.resources.aws.ec2 import instance as instances
+from heat.engine.resources.aws.ec2 import network_interface as net_interfaces
 from heat.engine import scheduler
-from heat.tests.common import HeatTestCase
+from heat.tests import common
+from heat.tests.nova import fakes as fakes_nova
 from heat.tests import utils
-from heat.tests.v1_1 import fakes
 
 
 wp_template = '''
@@ -149,10 +149,10 @@ class FakeNeutron(object):
         return None
 
 
-class instancesTest(HeatTestCase):
+class instancesTest(common.HeatTestCase):
     def setUp(self):
         super(instancesTest, self).setUp()
-        self.fc = fakes.FakeClient()
+        self.fc = fakes_nova.FakeClient()
 
     def _mock_get_image_id_success(self, imageId_input, imageId):
         self.m.StubOutWithMock(glance.GlanceClientPlugin, 'get_image_id')
@@ -187,7 +187,7 @@ class instancesTest(HeatTestCase):
             d2['server']['status'] = vm_delete_status
             get().AndReturn((200, d2))
         else:
-            get().AndRaise(fakes.fake_exception())
+            get().AndRaise(fakes_nova.fake_exception())
 
         self.m.ReplayAll()
 
@@ -198,25 +198,25 @@ class instancesTest(HeatTestCase):
     def _create_test_instance(self, return_server, name):
         stack_name = '%s_s' % name
         t = template_format.parse(wp_template)
-        template = parser.Template(t)
         kwargs = {'KeyName': 'test',
                   'InstanceType': 'm1.large',
                   'SubnetId': '4156c7a5-e8c4-4aff-a6e1-8f3c7bc83861'}
-        stack = parser.Stack(utils.dummy_context(), stack_name, template,
-                             environment.Environment(kwargs),
-                             stack_id=str(uuid.uuid4()))
+        template = parser.Template(t,
+                                   env=environment.Environment(kwargs))
+        self.stack = parser.Stack(utils.dummy_context(), stack_name, template,
+                                  stack_id=str(uuid.uuid4()))
         image_id = 'CentOS 5.2'
         t['Resources']['WebServer']['Properties']['ImageId'] = image_id
-        resource_defns = stack.t.resource_definitions(stack)
+        resource_defns = self.stack.t.resource_definitions(self.stack)
         instance = instances.Instance('%s_name' % name,
-                                      resource_defns['WebServer'], stack)
+                                      resource_defns['WebServer'], self.stack)
         metadata = instance.metadata_get()
 
         self.m.StubOutWithMock(nova.NovaClientPlugin, '_create')
         nova.NovaClientPlugin._create().AndReturn(self.fc)
 
         self._mock_get_image_id_success(image_id, 1)
-
+        self.stub_SubnetConstraint_validate()
         self.m.StubOutWithMock(instance, 'neutron')
         instance.neutron().MultipleTimes().AndReturn(FakeNeutron())
 
@@ -253,26 +253,27 @@ class instancesTest(HeatTestCase):
     def _create_test_instance_with_nic(self, return_server, name):
         stack_name = '%s_s' % name
         t = template_format.parse(wp_template_with_nic)
-        template = parser.Template(t)
         kwargs = {'KeyName': 'test',
                   'InstanceType': 'm1.large',
                   'SubnetId': '4156c7a5-e8c4-4aff-a6e1-8f3c7bc83861'}
-        stack = parser.Stack(utils.dummy_context(), stack_name, template,
-                             environment.Environment(kwargs),
-                             stack_id=str(uuid.uuid4()))
+        template = parser.Template(t,
+                                   env=environment.Environment(kwargs))
+        self.stack = parser.Stack(utils.dummy_context(), stack_name, template,
+                                  stack_id=str(uuid.uuid4()))
         image_id = 'CentOS 5.2'
         t['Resources']['WebServer']['Properties']['ImageId'] = image_id
 
-        resource_defns = stack.t.resource_definitions(stack)
-        nic = network_interfaces.NetworkInterface('%s_nic' % name,
-                                                  resource_defns['nic1'],
-                                                  stack)
+        resource_defns = self.stack.t.resource_definitions(self.stack)
+        nic = net_interfaces.NetworkInterface('%s_nic' % name,
+                                              resource_defns['nic1'],
+                                              self.stack)
 
         instance = instances.Instance('%s_name' % name,
-                                      resource_defns['WebServer'], stack)
+                                      resource_defns['WebServer'], self.stack)
         metadata = instance.metadata_get()
 
         self._mock_get_image_id_success(image_id, 1)
+        self.stub_SubnetConstraint_validate()
         self.m.StubOutWithMock(nic, 'neutron')
         nic.neutron().MultipleTimes().AndReturn(FakeNeutron())
 
@@ -308,7 +309,7 @@ class instancesTest(HeatTestCase):
 
         # create network interface
         scheduler.TaskRunner(nic.create)()
-        stack.resources["nic1"] = nic
+        self.stack.resources["nic1"] = nic
 
         scheduler.TaskRunner(instance.create)()
         return instance
