@@ -15,7 +15,7 @@ import copy
 
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
-from heat.tests.common import HeatTestCase
+from heat.tests import common
 from heat.tests import utils
 
 try:
@@ -36,7 +36,7 @@ test_template = {
 }
 
 
-class NetworkInterfaceTest(HeatTestCase):
+class NetworkInterfaceTest(common.HeatTestCase):
     def setUp(self):
         super(NetworkInterfaceTest, self).setUp()
         self.ctx = utils.dummy_context()
@@ -44,7 +44,6 @@ class NetworkInterfaceTest(HeatTestCase):
         self.m.StubOutWithMock(neutronclient.Client, 'create_port')
         self.m.StubOutWithMock(neutronclient.Client, 'delete_port')
         self.m.StubOutWithMock(neutronclient.Client, 'update_port')
-        self.stub_keystoneclient()
 
     def mock_show_subnet(self):
         neutronclient.Client.show_subnet('ssss').AndReturn({
@@ -109,10 +108,12 @@ class NetworkInterfaceTest(HeatTestCase):
         neutronclient.Client.delete_port(port_id).AndReturn(None)
 
     def test_network_interface_create_update_delete(self):
-        my_stack = utils.parse_stack(test_template, stack_name='my_stack')
+        my_stack = utils.parse_stack(test_template,
+                                     stack_name='test_nif_cud_stack')
         nic_rsrc = my_stack['my_nic']
 
         self.mock_show_subnet()
+        self.stub_SubnetConstraint_validate()
         self.mock_create_network_interface()
 
         update_props = {}
