@@ -13,30 +13,30 @@
 
 """Tests for :module:'heat.engine.resources.nova_utls'."""
 
-import mock
-import six
 import uuid
 
+import mock
 from novaclient import exceptions as nova_exceptions
+import six
 
 from heat.common import exception
-from heat.engine.resources import nova_utils
+from heat.engine import nova_utils
 from heat.engine import scheduler
-from heat.tests.common import HeatTestCase
-from heat.tests.v1_1 import fakes
+from heat.tests import common
+from heat.tests.nova import fakes as fakes_nova
 
 
-class NovaUtilsTests(HeatTestCase):
+class NovaUtilsTests(common.HeatTestCase):
     """
     Basic tests for the helper methods in
-    :module:'heat.engine.resources.nova_utils'.
+    :module:'heat.engine.nova_utils'.
     """
 
     def setUp(self):
         super(NovaUtilsTests, self).setUp()
         self.nova_client = self.m.CreateMockAnything()
         self.mock_warnings = mock.patch(
-            'heat.engine.resources.nova_utils.warnings')
+            'heat.engine.nova_utils.warnings')
         self.mock_warnings.start()
         self.addCleanup(self.mock_warnings.stop)
 
@@ -91,7 +91,7 @@ class NovaUtilsTests(HeatTestCase):
         self.nova_client.keypairs.get(
             my_key_name).AndReturn(my_key)
         self.nova_client.keypairs.get(
-            'notakey').AndRaise(fakes.fake_exception())
+            'notakey').AndRaise(fakes_nova.fake_exception())
         self.m.ReplayAll()
         self.assertEqual(my_key, nova_utils.get_keypair(self.nova_client,
                                                         my_key_name))
@@ -128,12 +128,12 @@ class NovaUtilsTests(HeatTestCase):
                       six.text_type(err))
 
 
-class NovaUtilsRefreshServerTests(HeatTestCase):
+class NovaUtilsRefreshServerTests(common.HeatTestCase):
 
     def setUp(self):
         super(NovaUtilsRefreshServerTests, self).setUp()
         self.mock_warnings = mock.patch(
-            'heat.engine.resources.nova_utils.warnings')
+            'heat.engine.nova_utils.warnings')
         self.mock_warnings.start()
         self.addCleanup(self.mock_warnings.stop)
 
@@ -147,12 +147,12 @@ class NovaUtilsRefreshServerTests(HeatTestCase):
 
     def test_overlimit_error(self):
         server = mock.Mock()
-        server.get.side_effect = fakes.fake_exception(413)
+        server.get.side_effect = fakes_nova.fake_exception(413)
         self.assertIsNone(nova_utils.refresh_server(server))
 
     def test_500_error(self):
         server = self.m.CreateMockAnything()
-        server.get().AndRaise(fakes.fake_exception(500))
+        server.get().AndRaise(fakes_nova.fake_exception(500))
         self.m.ReplayAll()
 
         self.assertIsNone(nova_utils.refresh_server(server))
@@ -160,7 +160,7 @@ class NovaUtilsRefreshServerTests(HeatTestCase):
 
     def test_503_error(self):
         server = self.m.CreateMockAnything()
-        server.get().AndRaise(fakes.fake_exception(503))
+        server.get().AndRaise(fakes_nova.fake_exception(503))
         self.m.ReplayAll()
 
         self.assertIsNone(nova_utils.refresh_server(server))
@@ -168,7 +168,7 @@ class NovaUtilsRefreshServerTests(HeatTestCase):
 
     def test_unhandled_exception(self):
         server = self.m.CreateMockAnything()
-        server.get().AndRaise(fakes.fake_exception(501))
+        server.get().AndRaise(fakes_nova.fake_exception(501))
         self.m.ReplayAll()
 
         self.assertRaises(nova_exceptions.ClientException,
@@ -176,13 +176,13 @@ class NovaUtilsRefreshServerTests(HeatTestCase):
         self.m.VerifyAll()
 
 
-class NovaUtilsUserdataTests(HeatTestCase):
+class NovaUtilsUserdataTests(common.HeatTestCase):
 
     def setUp(self):
         super(NovaUtilsUserdataTests, self).setUp()
         self.nova_client = self.m.CreateMockAnything()
         self.mock_warnings = mock.patch(
-            'heat.engine.resources.nova_utils.warnings')
+            'heat.engine.nova_utils.warnings')
         self.mock_warnings.start()
         self.addCleanup(self.mock_warnings.stop)
 
@@ -241,12 +241,12 @@ class NovaUtilsUserdataTests(HeatTestCase):
         self.m.VerifyAll()
 
 
-class NovaUtilsMetadataTests(HeatTestCase):
+class NovaUtilsMetadataTests(common.HeatTestCase):
 
     def setUp(self):
         super(NovaUtilsMetadataTests, self).setUp()
         self.mock_warnings = mock.patch(
-            'heat.engine.resources.nova_utils.warnings')
+            'heat.engine.nova_utils.warnings')
         self.mock_warnings.start()
         self.addCleanup(self.mock_warnings.stop)
 
