@@ -17,31 +17,62 @@
 Unit Tests for heat.rpc.client
 """
 
-
 import copy
-import mock
-import stubout
-import testtools
 
+import mock
+from oslo_messaging._drivers import common as rpc_common
+import stubout
+
+from heat.common import exception
 from heat.common import identifier
-from heat.common import messaging
 from heat.rpc import client as rpc_client
+from heat.tests import common
 from heat.tests import utils
 
 
-class EngineRpcAPITestCase(testtools.TestCase):
+class EngineRpcAPITestCase(common.HeatTestCase):
 
     def setUp(self):
-        messaging.setup("fake://", optional=True)
-        self.addCleanup(messaging.cleanup)
-        self.context = utils.dummy_context()
-
+        super(EngineRpcAPITestCase, self).setUp()
         self.stubs = stubout.StubOutForTesting()
         self.identity = dict(identifier.HeatIdentifier('engine_test_tenant',
                                                        '6',
                                                        'wordpress'))
         self.rpcapi = rpc_client.EngineClient()
-        super(EngineRpcAPITestCase, self).setUp()
+
+    def _to_remote_error(self, error):
+        """Converts the given exception to the one with the _Remote suffix.
+        """
+        exc_info = (type(error), error, None)
+        serialized = rpc_common.serialize_remote_exception(exc_info)
+        remote_error = rpc_common.deserialize_remote_exception(
+            serialized, ["heat.common.exception"])
+        return remote_error
+
+    def test_local_error_name(self):
+        ex = exception.NotFound()
+        self.assertEqual('NotFound', self.rpcapi.local_error_name(ex))
+
+        exr = self._to_remote_error(ex)
+        self.assertEqual('NotFound_Remote', exr.__class__.__name__)
+        self.assertEqual('NotFound', self.rpcapi.local_error_name(exr))
+
+    def test_ignore_error_named(self):
+        ex = exception.NotFound()
+        exr = self._to_remote_error(ex)
+
+        self.rpcapi.ignore_error_named(ex, 'NotFound')
+        self.rpcapi.ignore_error_named(exr, 'NotFound')
+        self.assertRaises(
+            exception.NotFound,
+            self.rpcapi.ignore_error_named,
+            ex,
+            'NotSupported')
+        self.assertRaises(
+            exception.NotFound,
+            self.rpcapi.ignore_error_named,
+            exr,
+            'NotSupported')
 
     def _test_engine_api(self, method, rpc_method, **kwargs):
         ctxt = utils.dummy_context()
@@ -118,6 +149,10 @@ class EngineRpcAPITestCase(testtools.TestCase):
                       args={'timeout_mins': u'30'})
         call_kwargs = copy.deepcopy(kwargs)
         call_kwargs['owner_id'] = None
+        call_kwargs['nested_depth'] = 0
+        call_kwargs['user_creds_id'] = None
+        call_kwargs['stack_user_project_id'] = None
+        call_kwargs['parent_resource_name'] = None
         expected_message = self.rpcapi.make_msg('create_stack', **call_kwargs)
         kwargs['expected_message'] = expected_message
         self._test_engine_api('create_stack', 'call', **kwargs)
@@ -169,7 +204,8 @@ class EngineRpcAPITestCase(testtools.TestCase):
     def test_describe_stack_resource(self):
         self._test_engine_api('describe_stack_resource', 'call',
                               stack_identity=self.identity,
-                              resource_name='LogicalResourceId')
+                              resource_name='LogicalResourceId',
+                              with_attr=None)
 
     def test_find_physical_resource(self):
         self._test_engine_api('find_physical_resource', 'call',
@@ -207,7 +243,8 @@ class EngineRpcAPITestCase(testtools.TestCase):
         self._test_engine_api('resource_signal', 'call',
                               stack_identity=self.identity,
                               resource_name='LogicalResourceId',
-                              details={u'wordpress': []})
+                              details={u'wordpress': []},
+                              sync_call=True)
 
     def test_create_watch_data(self):
         self._test_engine_api('create_watch_data', 'call',
@@ -274,7 +311,8 @@ class EngineRpcAPITestCase(testtools.TestCase):
                               output_values={},
                               action='DEPLOYED',
                               status='COMPLETE',
-                              status_reason=None)
+                              status_reason=None,
+                              updated_at=None)
 
     def test_delete_software_deployment(self):
         deployment_id = '86729f02-4648-44d8-af44-d0ec65b6abc9'
@@ -297,3 +335,6 @@ class EngineRpcAPITestCase(testtools.TestCase):
         self._test_engine_api('delete_snapshot', 'call',
                               stack_identity=self.identity,
                               snapshot_id=snapshot_id)
+
+    def test_list_services(self):
+        self._test_engine_api('list_services', 'call', version='1.4')
