@@ -14,35 +14,11 @@
 import six
 
 from heat.common import exception
-from heat.common import template_format
 from heat.engine.cfn import functions as cfn_funcs
 from heat.engine.hot import functions as hot_funcs
 from heat.engine import properties
 from heat.engine import rsrc_defn
 from heat.tests import common
-from heat.tests import utils
-
-TEMPLATE_WITH_EX_REF_IMPLICIT_DEPEND = '''
-heat_template_version: 2016-10-14
-resources:
-  test1:
-    type: OS::Heat::TestResource
-    external_id: foobar
-    properties:
-        value: {get_resource: test2}
-  test2:
-    type: OS::Heat::TestResource
-'''
-
-TEMPLATE_WITH_INVALID_EXPLICIT_DEPEND = '''
-heat_template_version: 2016-10-14
-resources:
-  test1:
-    type: OS::Heat::TestResource
-  test3:
-    type: OS::Heat::TestResource
-    depends_on: test2
-'''
 
 
 class ResourceDefinitionTest(common.HeatTestCase):
@@ -99,24 +75,9 @@ class ResourceDefinitionTest(common.HeatTestCase):
         stack = {'foo': 'FOO', 'bar': 'BAR'}
         self.assertEqual(['FOO'], list(rd.dependencies(stack)))
 
-    def test_dependencies_explicit_ext(self):
-        rd = rsrc_defn.ResourceDefinition('rsrc', 'SomeType', depends=['foo'],
-                                          external_id='abc')
-        stack = {'foo': 'FOO', 'bar': 'BAR'}
-        self.assertRaises(
-            exception.InvalidExternalResourceDependency,
-            rd.dependencies, stack)
-
-    def test_dependencies_implicit_ext(self):
-        t = template_format.parse(TEMPLATE_WITH_EX_REF_IMPLICIT_DEPEND)
-        stack = utils.parse_stack(t)
-        rsrc = stack['test1']
-        self.assertEqual([], list(rsrc.t.dependencies(stack)))
-
     def test_dependencies_explicit_invalid(self):
-        t = template_format.parse(TEMPLATE_WITH_INVALID_EXPLICIT_DEPEND)
-        stack = utils.parse_stack(t)
-        rd = stack.t.resource_definitions(stack)['test3']
+        rd = rsrc_defn.ResourceDefinition('rsrc', 'SomeType', depends=['baz'])
+        stack = {'foo': 'FOO', 'bar': 'BAR'}
         self.assertRaises(exception.InvalidTemplateReference,
                           lambda: list(rd.dependencies(stack)))
 
@@ -224,71 +185,32 @@ class ResourceDefinitionTest(common.HeatTestCase):
         self.assertNotEqual(hash(rd1), hash(rd2))
 
 
-class ResourceDefinitionDiffTest(common.HeatTestCase):
-    def test_properties_diff(self):
-        before = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
-                                              properties={'Foo': 'blarg'},
-                                              update_policy={'baz': 'quux'},
-                                              metadata={'baz': 'quux'})
-        after = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
-                                             properties={'Foo': 'wibble'},
-                                             update_policy={'baz': 'quux'},
-                                             metadata={'baz': 'quux'})
+class ResourceDefinitionSnippetTest(common.HeatTestCase):
+    def test_type(self):
+        rd = rsrc_defn.ResourceDefinition('rsrc', 'SomeType')
+        self.assertEqual({'Type': 'SomeType'}, rd)
 
-        diff = after - before
-        self.assertTrue(diff.properties_changed())
-        self.assertFalse(diff.update_policy_changed())
-        self.assertFalse(diff.metadata_changed())
-        self.assertTrue(diff)
+    def test_properties(self):
+        rd = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
+                                          properties={'Foo': 'bar'})
+        self.assertEqual({'Type': 'SomeType',
+                          'Properties': {'Foo': 'bar'}}, rd)
 
-    def test_update_policy_diff(self):
-        before = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
-                                              properties={'baz': 'quux'},
-                                              update_policy={'Foo': 'blarg'},
-                                              metadata={'baz': 'quux'})
-        after = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
-                                             properties={'baz': 'quux'},
-                                             update_policy={'Foo': 'wibble'},
-                                             metadata={'baz': 'quux'})
+    def test_metadata(self):
+        rd = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
+                                          metadata={'Foo': 'bar'})
+        self.assertEqual({'Type': 'SomeType',
+                          'Metadata': {'Foo': 'bar'}}, rd)
 
-        diff = after - before
-        self.assertFalse(diff.properties_changed())
-        self.assertTrue(diff.update_policy_changed())
-        self.assertFalse(diff.metadata_changed())
-        self.assertTrue(diff)
+    def test_deletion_policy(self):
+        rd = rsrc_defn.ResourceDefinition(
+            'rsrc', 'SomeType',
+            deletion_policy=rsrc_defn.ResourceDefinition.RETAIN)
+        self.assertEqual({'Type': 'SomeType',
+                          'DeletionPolicy': 'Retain'}, rd)
 
-    def test_metadata_diff(self):
-        before = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
-                                              properties={'baz': 'quux'},
-                                              update_policy={'baz': 'quux'},
-                                              metadata={'Foo': 'blarg'})
-        after = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
-                                             properties={'baz': 'quux'},
-                                             update_policy={'baz': 'quux'},
-                                             metadata={'Foo': 'wibble'})
-
-        diff = after - before
-        self.assertFalse(diff.properties_changed())
-        self.assertFalse(diff.update_policy_changed())
-        self.assertTrue(diff.metadata_changed())
-        self.assertTrue(diff)
-
-    def test_no_diff(self):
-        before = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
-                                              properties={'Foo': 'blarg'},
-                                              update_policy={'bar': 'quux'},
-                                              metadata={'baz': 'wibble'},
-                                              depends=['other_resource'],
-                                              deletion_policy='Delete')
-        after = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
-                                             properties={'Foo': 'blarg'},
-                                             update_policy={'bar': 'quux'},
-                                             metadata={'baz': 'wibble'},
-                                             depends=['other_other_resource'],
-                                             deletion_policy='Retain')
-
-        diff = after - before
-        self.assertFalse(diff.properties_changed())
-        self.assertFalse(diff.update_policy_changed())
-        self.assertFalse(diff.metadata_changed())
-        self.assertFalse(diff)
+    def test_update_policy(self):
+        rd = rsrc_defn.ResourceDefinition('rsrc', 'SomeType',
+                                          update_policy={'Foo': 'bar'})
+        self.assertEqual({'Type': 'SomeType',
+                          'UpdatePolicy': {'Foo': 'bar'}}, rd)
