@@ -17,7 +17,7 @@ import eventlet
 
 from heat.engine import dependencies
 from heat.engine import scheduler
-from heat.tests.common import HeatTestCase
+from heat.tests import common
 
 
 class DummyTask(object):
@@ -33,7 +33,7 @@ class DummyTask(object):
         pass
 
 
-class PollingTaskGroupTest(HeatTestCase):
+class PollingTaskGroupTest(common.HeatTestCase):
 
     def setUp(self):
         super(PollingTaskGroupTest, self).setUp()
@@ -45,7 +45,7 @@ class PollingTaskGroupTest(HeatTestCase):
             self.m.StubOutWithMock(t, 'do_step')
 
         self.m.StubOutWithMock(scheduler.TaskRunner, '_sleep')
-        scheduler.TaskRunner._sleep(1).AndReturn(None)
+        scheduler.TaskRunner._sleep(0).AndReturn(None)
 
         for t in tasks:
             t.do_step(1).AndReturn(None)
@@ -161,7 +161,7 @@ class PollingTaskGroupTest(HeatTestCase):
                 dummy.do_step(1, i, i * i)
 
 
-class ExceptionGroupTest(HeatTestCase):
+class ExceptionGroupTest(common.HeatTestCase):
 
     def test_contains_exceptions(self):
         exception_group = scheduler.ExceptionGroup()
@@ -190,7 +190,7 @@ class ExceptionGroupTest(HeatTestCase):
         self.assertEqual("['ex 1', 'ex 2']", str(exception_group))
 
 
-class DependencyTaskGroupTest(HeatTestCase):
+class DependencyTaskGroupTest(common.HeatTestCase):
     def setUp(self):
         super(DependencyTaskGroupTest, self).setUp()
         self.addCleanup(self.m.VerifyAll)
@@ -220,8 +220,7 @@ class DependencyTaskGroupTest(HeatTestCase):
         self.steps = 0
         self.m.StubOutWithMock(scheduler.TaskRunner, '_sleep')
         with self._dep_test(('second', 'first')):
-            scheduler.TaskRunner._sleep(None).AndReturn(None)
-            scheduler.TaskRunner._sleep(None).AndReturn(None)
+            pass
 
     def test_single_node(self):
         with self._dep_test(('only', None)) as dummy:
@@ -414,7 +413,7 @@ class DependencyTaskGroupTest(HeatTestCase):
                 dummy.do_step(2, 'B').InAnyOrder('2')
                 dummy.do_step(3, 'B')
 
-        exc = self.assertRaises(Exception, run_tasks_with_exceptions)
+        exc = self.assertRaises(type(e1), run_tasks_with_exceptions)
         self.assertEqual(e1, exc)
 
     def test_exception_grace_period_expired(self):
@@ -436,11 +435,11 @@ class DependencyTaskGroupTest(HeatTestCase):
                 dummy.do_step(3, 'B')
                 dummy.do_step(4, 'B').WithSideEffects(sleep)
 
-        exc = self.assertRaises(Exception, run_tasks_with_exceptions)
+        exc = self.assertRaises(type(e1), run_tasks_with_exceptions)
         self.assertEqual(e1, exc)
 
 
-class TaskTest(HeatTestCase):
+class TaskTest(common.HeatTestCase):
 
     def setUp(self):
         super(TaskTest, self).setUp()
@@ -453,7 +452,7 @@ class TaskTest(HeatTestCase):
         self.m.StubOutWithMock(scheduler.TaskRunner, '_sleep')
 
         task.do_step(1).AndReturn(None)
-        scheduler.TaskRunner._sleep(1).AndReturn(None)
+        scheduler.TaskRunner._sleep(0).AndReturn(None)
         task.do_step(2).AndReturn(None)
         scheduler.TaskRunner._sleep(1).AndReturn(None)
         task.do_step(3).AndReturn(None)
@@ -469,7 +468,7 @@ class TaskTest(HeatTestCase):
         self.m.StubOutWithMock(scheduler.TaskRunner, '_sleep')
 
         task.do_step(1).AndReturn(None)
-        scheduler.TaskRunner._sleep(42).AndReturn(None)
+        scheduler.TaskRunner._sleep(0).AndReturn(None)
         task.do_step(2).AndReturn(None)
         scheduler.TaskRunner._sleep(42).AndReturn(None)
         task.do_step(3).AndReturn(None)
@@ -516,6 +515,7 @@ class TaskTest(HeatTestCase):
     def test_sleep(self):
         sleep_time = 42
         self.m.StubOutWithMock(eventlet, 'sleep')
+        eventlet.sleep(0).AndReturn(None)
         eventlet.sleep(sleep_time).MultipleTimes().AndReturn(None)
 
         self.m.ReplayAll()
@@ -892,7 +892,7 @@ class TaskTest(HeatTestCase):
         self.assertTrue(runner.done())
 
 
-class TimeoutTest(HeatTestCase):
+class TimeoutTest(common.HeatTestCase):
     def test_compare(self):
         task = scheduler.TaskRunner(DummyTask())
 
@@ -906,7 +906,7 @@ class TimeoutTest(HeatTestCase):
         self.assertNotEqual(earlier, later)
 
 
-class DescriptionTest(HeatTestCase):
+class DescriptionTest(common.HeatTestCase):
 
     def setUp(self):
         super(DescriptionTest, self).setUp()
@@ -950,7 +950,7 @@ class DescriptionTest(HeatTestCase):
         self.assertEqual('o', scheduler.task_description(C()))
 
 
-class WrapperTaskTest(HeatTestCase):
+class WrapperTaskTest(common.HeatTestCase):
 
     def setUp(self):
         super(WrapperTaskTest, self).setUp()
@@ -970,7 +970,7 @@ class WrapperTaskTest(HeatTestCase):
             self.m.StubOutWithMock(child_task, 'do_step')
         self.m.StubOutWithMock(scheduler.TaskRunner, '_sleep')
 
-        scheduler.TaskRunner._sleep(1).AndReturn(None)
+        scheduler.TaskRunner._sleep(0).AndReturn(None)
         for child_task in child_tasks:
             child_task.do_step(1).AndReturn(None)
             scheduler.TaskRunner._sleep(1).AndReturn(None)
