@@ -14,17 +14,16 @@
 import mock
 import six
 
-from heat.common import exception
+from heat.common import exception as exc
 from heat.common import template_format
-from heat.engine.resources.software_config import software_component as sc
+from heat.engine.resources.openstack.heat import software_component as sc
 from heat.engine import stack
 from heat.engine import template
-from heat.tests.common import HeatTestCase
+from heat.tests import common
 from heat.tests import utils
-from heatclient.exc import HTTPNotFound
 
 
-class SoftwareComponentTest(HeatTestCase):
+class SoftwareComponentTest(common.HeatTestCase):
 
     def setUp(self):
         super(SoftwareComponentTest, self).setUp()
@@ -58,11 +57,8 @@ class SoftwareComponentTest(HeatTestCase):
             self.ctx, 'software_component_test_stack',
             template.Template(self.template))
         self.component = self.stack['mysql_component']
-        heat = mock.MagicMock()
-        self.heatclient = mock.MagicMock()
-        self.component.heat = heat
-        heat.return_value = self.heatclient
-        self.software_configs = self.heatclient.software_configs
+        self.rpc_client = mock.MagicMock()
+        self.component._rpc_client = self.rpc_client
 
     def test_resource_mapping(self):
         mapping = sc.resource_mapping()
@@ -72,11 +68,19 @@ class SoftwareComponentTest(HeatTestCase):
         self.assertIsInstance(self.component, sc.SoftwareComponent)
 
     def test_handle_create(self):
-        value = mock.MagicMock()
         config_id = 'c8a19429-7fde-47ea-a42f-40045488226c'
-        value.id = config_id
-        self.software_configs.create.return_value = value
+        value = {'id': config_id}
+        self.rpc_client.create_software_config.return_value = value
+        props = dict(self.component.properties)
         self.component.handle_create()
+        self.rpc_client.create_software_config.assert_called_with(
+            self.ctx,
+            group='component',
+            name=None,
+            inputs=props['inputs'],
+            outputs=props['outputs'],
+            config={'configs': props['configs']},
+            options=None)
         self.assertEqual(config_id, self.component.resource_id)
 
     def test_handle_delete(self):
@@ -84,9 +88,9 @@ class SoftwareComponentTest(HeatTestCase):
         self.assertIsNone(self.component.handle_delete())
         config_id = 'c8a19429-7fde-47ea-a42f-40045488226c'
         self.component.resource_id = config_id
-        self.software_configs.delete.return_value = None
+        self.rpc_client.delete_software_config.return_value = None
         self.assertIsNone(self.component.handle_delete())
-        self.software_configs.delete.side_effect = HTTPNotFound()
+        self.rpc_client.delete_software_config.side_effect = exc.NotFound
         self.assertIsNone(self.component.handle_delete())
 
     def test_resolve_attribute(self):
@@ -94,18 +98,17 @@ class SoftwareComponentTest(HeatTestCase):
         self.component.resource_id = None
         self.assertIsNone(self.component._resolve_attribute('configs'))
         self.component.resource_id = 'c8a19429-7fde-47ea-a42f-40045488226c'
-        value = mock.MagicMock()
-        configs = self.\
-            template['resources']['mysql_component']['properties']['configs']
+        configs = self.template['resources']['mysql_component'
+                                             ]['properties']['configs']
         # configs list is stored in 'config' property of SoftwareConfig
-        value.config = {'configs': configs}
-        self.software_configs.get.return_value = value
+        value = {'config': {'configs': configs}}
+        self.rpc_client.show_software_config.return_value = value
         self.assertEqual(configs, self.component._resolve_attribute('configs'))
-        self.software_configs.get.side_effect = HTTPNotFound()
+        self.rpc_client.show_software_config.side_effect = exc.NotFound
         self.assertIsNone(self.component._resolve_attribute('configs'))
 
 
-class SoftwareComponentValidationTest(HeatTestCase):
+class SoftwareComponentValidationTest(common.HeatTestCase):
 
     scenarios = [
         (
@@ -160,7 +163,7 @@ class SoftwareComponentValidationTest(HeatTestCase):
                            echo CREATE $foo
                          tool: script
                  ''',
-                 err=exception.StackValidationFailed,
+                 err=exc.StackValidationFailed,
                  err_msg='Unknown Property config')
         ),
         (
@@ -172,22 +175,22 @@ class SoftwareComponentValidationTest(HeatTestCase):
                      inputs:
                        - name: foo
                  ''',
-                 err=exception.StackValidationFailed,
+                 err=exc.StackValidationFailed,
                  err_msg='Property configs not assigned')
         ),
         # do not test until bug #1350840
-#         (
-#             'empty_configs',
-#             dict(snippet='''
-#                  component:
-#                    type: OS::Heat::SoftwareComponent
-#                    properties:
-#                      configs:
-#                  ''',
-#                  err=exception.StackValidationFailed,
-#                  err_msg='configs length (0) is out of range '
-#                                     '(min: 1, max: None)')
-#         ),
+        # (
+        #     'empty_configs',
+        #     dict(snippet='''
+        #          component:
+        #            type: OS::Heat::SoftwareComponent
+        #            properties:
+        #              configs:
+        #          ''',
+        #          err=exception.StackValidationFailed,
+        #          err_msg='configs length (0) is out of range '
+        #                  '(min: 1, max: None)')
+        # ),
         (
             'invalid_configs',
             dict(snippet='''
@@ -199,7 +202,7 @@ class SoftwareComponentValidationTest(HeatTestCase):
                        config: #!/bin/bash
                        tool: script
                  ''',
-                 err=exception.StackValidationFailed,
+                 err=exc.StackValidationFailed,
                  err_msg='is not a list')
         ),
         (
@@ -213,9 +216,9 @@ class SoftwareComponentValidationTest(HeatTestCase):
                          config: #!/bin/bash
                          tool: script
                  ''',
-                 err=exception.StackValidationFailed,
-                 err_msg='actions length (0) is out of range '
-                         '(min: 1, max: None)')
+                 err=exc.StackValidationFailed,
+                 err_msg='component.properties.configs[0].actions: '
+                         'length (0) is out of range (min: 1, max: None)')
         ),
         (
             'multiple_configs_per_action_single',
@@ -231,7 +234,7 @@ class SoftwareComponentValidationTest(HeatTestCase):
                          config: #!/bin/bash
                          tool: script
                  ''',
-                 err=exception.StackValidationFailed,
+                 err=exc.StackValidationFailed,
                  err_msg='Defining more than one configuration for the same '
                          'action in SoftwareComponent "component" is not '
                          'allowed.')
@@ -250,7 +253,7 @@ class SoftwareComponentValidationTest(HeatTestCase):
                          config: #!/bin/bash
                          tool: script
                  ''',
-                 err=exception.StackValidationFailed,
+                 err=exc.StackValidationFailed,
                  err_msg='Defining more than one configuration for the same '
                          'action in SoftwareComponent "component" is not '
                          'allowed.')
@@ -272,11 +275,7 @@ class SoftwareComponentValidationTest(HeatTestCase):
             self.ctx, 'software_component_test_stack',
             template.Template(self.template))
         self.component = self.stack['component']
-        heat = mock.MagicMock()
-        self.heatclient = mock.MagicMock()
-        self.component.heat = heat
-        heat.return_value = self.heatclient
-        self.software_configs = self.heatclient.software_configs
+        self.component._rpc_client = mock.MagicMock()
 
     def test_properties_schema(self):
         if self.err:
