@@ -1864,3 +1864,59 @@ class StackKwargsForCloningTest(common.HeatTestCase):
             # just make sure that the kwargs are valid
             # (no exception should be raised)
             stack.Stack(ctx, utils.random_name(), tmpl, **res)
+
+
+class ResetStateOnErrorTest(common.HeatTestCase):
+    class DummyStack(object):
+
+        (COMPLETE, IN_PROGRESS, FAILED) = range(3)
+        action = 'something'
+        status = COMPLETE
+
+        def __init__(self):
+            self.state_set = mock.MagicMock()
+
+        @stack.reset_state_on_error
+        def raise_exception(self):
+            self.status = self.IN_PROGRESS
+            raise ValueError('oops')
+
+        @stack.reset_state_on_error
+        def raise_exit_exception(self):
+            self.status = self.IN_PROGRESS
+            raise BaseException('bye')
+
+        @stack.reset_state_on_error
+        def succeed(self):
+            return 'Hello world'
+
+        @stack.reset_state_on_error
+        def fail(self):
+            self.status = self.FAILED
+            return 'Hello world'
+
+    def test_success(self):
+        dummy = self.DummyStack()
+
+        self.assertEqual('Hello world', dummy.succeed())
+        self.assertFalse(dummy.state_set.called)
+
+    def test_failure(self):
+        dummy = self.DummyStack()
+
+        self.assertEqual('Hello world', dummy.fail())
+        self.assertFalse(dummy.state_set.called)
+
+    def test_reset_state_exception(self):
+        dummy = self.DummyStack()
+
+        exc = self.assertRaises(ValueError, dummy.raise_exception)
+        self.assertIn('oops', str(exc))
+        self.assertTrue(dummy.state_set.called)
+
+    def test_reset_state_exit_exception(self):
+        dummy = self.DummyStack()
+
+        exc = self.assertRaises(BaseException, dummy.raise_exit_exception)
+        self.assertIn('bye', str(exc))
+        self.assertTrue(dummy.state_set.called)
