@@ -14,17 +14,14 @@
 import copy
 import time
 
-import fixtures
-from keystoneauth1 import exceptions as kc_exceptions
+from keystoneclient import exceptions as kc_exceptions
 import mock
-from oslo_log import log as logging
 
 from heat.common import exception
+from heat.common import heat_keystoneclient as hkc
 from heat.common import template_format
-from heat.common import timeutils
 from heat.engine.clients.os import keystone
-from heat.engine.clients.os.keystone import fake_keystoneclient as fake_ks
-from heat.engine.clients.os.keystone import heat_keystoneclient as hkc
+from heat.engine import resource
 from heat.engine import scheduler
 from heat.engine import stack
 from heat.engine import template
@@ -32,6 +29,7 @@ from heat.objects import snapshot as snapshot_object
 from heat.objects import stack as stack_object
 from heat.objects import user_creds as ucreds_object
 from heat.tests import common
+from heat.tests import fakes
 from heat.tests import generic_resource as generic_rsrc
 from heat.tests import utils
 
@@ -46,6 +44,8 @@ class StackTest(common.HeatTestCase):
 
         self.tmpl = template.Template(copy.deepcopy(empty_template))
         self.ctx = utils.dummy_context()
+        resource._register_class('GenericResourceType',
+                                 generic_rsrc.GenericResource)
 
     def test_delete(self):
         self.stack = stack.Stack(self.ctx, 'delete_test', self.tmpl)
@@ -84,46 +84,6 @@ class StackTest(common.HeatTestCase):
         self.assertEqual([], snapshot_object.Snapshot.get_all(
             self.ctx, stack_id))
 
-    def test_delete_with_snapshot_after_stack_add_resource(self):
-        tpl = {'heat_template_version': 'queens',
-               'resources':
-                   {'A': {'type': 'ResourceWithRestoreType'}}}
-        self.stack = stack.Stack(self.ctx, 'stack_delete_with_snapshot',
-                                 template.Template(tpl))
-        stack_id = self.stack.store()
-        self.stack.create()
-
-        data = copy.deepcopy(self.stack.prepare_abandon())
-        data['resources']['A']['resource_data']['a_string'] = 'foo'
-        snapshot_fake = {
-            'tenant': self.ctx.tenant_id,
-            'name': 'Snapshot',
-            'stack_id': stack_id,
-            'status': 'COMPLETE',
-            'data': data
-        }
-        snapshot_object.Snapshot.create(self.ctx, snapshot_fake)
-
-        self.assertIsNotNone(snapshot_object.Snapshot.get_all(
-            self.ctx, stack_id))
-
-        new_tmpl = {'heat_template_version': 'queens',
-                    'resources':
-                        {'A': {'type': 'ResourceWithRestoreType'},
-                         'B': {'type': 'ResourceWithRestoreType'}}}
-        updated_stack = stack.Stack(self.ctx, 'update_stack_add_res',
-                                    template.Template(new_tmpl))
-        self.stack.update(updated_stack)
-        self.assertEqual(2, len(self.stack.resources))
-
-        self.stack.delete()
-        db_s = stack_object.Stack.get_by_id(self.ctx, stack_id)
-        self.assertIsNone(db_s)
-        self.assertEqual((stack.Stack.DELETE, stack.Stack.COMPLETE),
-                         self.stack.state)
-        self.assertEqual([], snapshot_object.Snapshot.get_all(
-            self.ctx, stack_id))
-
     def test_delete_user_creds(self):
         self.stack = stack.Stack(self.ctx, 'delete_test', self.tmpl)
         stack_id = self.stack.store()
@@ -132,16 +92,14 @@ class StackTest(common.HeatTestCase):
         self.assertIsNotNone(db_s)
         self.assertIsNotNone(db_s.user_creds_id)
         user_creds_id = db_s.user_creds_id
-        db_creds = ucreds_object.UserCreds.get_by_id(
-            self.ctx, db_s.user_creds_id)
+        db_creds = ucreds_object.UserCreds.get_by_id(db_s.user_creds_id)
         self.assertIsNotNone(db_creds)
 
         self.stack.delete()
 
         db_s = stack_object.Stack.get_by_id(self.ctx, stack_id)
         self.assertIsNone(db_s)
-        db_creds = ucreds_object.UserCreds.get_by_id(
-            self.ctx, user_creds_id)
+        db_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
         self.assertIsNone(db_creds)
         del_db_s = stack_object.Stack.get_by_id(self.ctx,
                                                 stack_id,
@@ -164,8 +122,7 @@ class StackTest(common.HeatTestCase):
         self.assertIsNotNone(db_s)
         self.assertIsNotNone(db_s.user_creds_id)
         user_creds_id = db_s.user_creds_id
-        db_creds = ucreds_object.UserCreds.get_by_id(
-            self.ctx, db_s.user_creds_id)
+        db_creds = ucreds_object.UserCreds.get_by_id(db_s.user_creds_id)
         self.assertIsNotNone(db_creds)
 
         ucreds_object.UserCreds.delete(self.ctx, user_creds_id)
@@ -174,8 +131,7 @@ class StackTest(common.HeatTestCase):
 
         db_s = stack_object.Stack.get_by_id(self.ctx, stack_id)
         self.assertIsNone(db_s)
-        db_creds = ucreds_object.UserCreds.get_by_id(
-            self.ctx, user_creds_id)
+        db_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
         self.assertIsNone(db_creds)
         del_db_s = stack_object.Stack.get_by_id(self.ctx,
                                                 stack_id,
@@ -236,8 +192,7 @@ class StackTest(common.HeatTestCase):
 
         user_creds_id = db_s.user_creds_id
         self.assertIsNotNone(user_creds_id)
-        user_creds = ucreds_object.UserCreds.get_by_id(
-            self.ctx, user_creds_id)
+        user_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
         self.assertEqual('thetrustor', user_creds.get('trustor_user_id'))
 
         self.stack.delete()
@@ -268,11 +223,10 @@ class StackTest(common.HeatTestCase):
 
         user_creds_id = db_s.user_creds_id
         self.assertIsNotNone(user_creds_id)
-        user_creds = ucreds_object.UserCreds.get_by_id(
-            self.ctx, user_creds_id)
+        user_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
         self.assertEqual('thetrustor', user_creds.get('trustor_user_id'))
 
-        mock_kc.return_value = fake_ks.FakeKeystoneClient(user_id='nottrustor')
+        mock_kc.return_value = fakes.FakeKeystoneClient(user_id='nottrustor')
 
         loaded_stack = stack.Stack.load(other_ctx, self.stack.id)
         loaded_stack.delete()
@@ -284,7 +238,7 @@ class StackTest(common.HeatTestCase):
                          loaded_stack.state)
 
     def test_delete_trust_backup(self):
-        class FakeKeystoneClientFail(fake_ks.FakeKeystoneClient):
+        class FakeKeystoneClientFail(fakes.FakeKeystoneClient):
             def delete_trust(self, trust_id):
                 raise Exception("Shouldn't delete")
 
@@ -306,7 +260,7 @@ class StackTest(common.HeatTestCase):
         mock_kcp.assert_called_once_with()
 
     def test_delete_trust_nested(self):
-        class FakeKeystoneClientFail(fake_ks.FakeKeystoneClient):
+        class FakeKeystoneClientFail(fakes.FakeKeystoneClient):
             def delete_trust(self, trust_id):
                 raise Exception("Shouldn't delete")
 
@@ -320,22 +274,20 @@ class StackTest(common.HeatTestCase):
         self.assertIsNotNone(db_s)
         user_creds_id = db_s.user_creds_id
         self.assertIsNotNone(user_creds_id)
-        user_creds = ucreds_object.UserCreds.get_by_id(
-            self.ctx, user_creds_id)
+        user_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
         self.assertIsNotNone(user_creds)
 
         self.stack.delete()
 
         db_s = stack_object.Stack.get_by_id(self.ctx, stack_id)
         self.assertIsNone(db_s)
-        user_creds = ucreds_object.UserCreds.get_by_id(
-            self.ctx, user_creds_id)
+        user_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
         self.assertIsNotNone(user_creds)
         self.assertEqual((stack.Stack.DELETE, stack.Stack.COMPLETE),
                          self.stack.state)
 
     def test_delete_trust_fail(self):
-        class FakeKeystoneClientFail(fake_ks.FakeKeystoneClient):
+        class FakeKeystoneClientFail(fakes.FakeKeystoneClient):
             def delete_trust(self, trust_id):
                 raise kc_exceptions.Forbidden("Denied!")
 
@@ -360,7 +312,7 @@ class StackTest(common.HeatTestCase):
         self.assertIn('Error deleting trust', self.stack.status_reason)
 
     def test_delete_deletes_project(self):
-        fkc = fake_ks.FakeKeystoneClient()
+        fkc = fakes.FakeKeystoneClient()
         fkc.delete_stack_domain_project = mock.Mock()
 
         mock_kcp = self.patchobject(keystone.KeystoneClientPlugin, '_create',
@@ -428,7 +380,7 @@ class StackTest(common.HeatTestCase):
         start_time = time.time()
         mock_tg = self.patchobject(scheduler.DependencyTaskGroup, '__call__',
                                    return_value=dummy_task())
-        mock_wallclock = self.patchobject(timeutils, 'wallclock')
+        mock_wallclock = self.patchobject(scheduler, 'wallclock')
         mock_wallclock.side_effect = [
             start_time,
             start_time + 1,
@@ -470,26 +422,9 @@ class StackTest(common.HeatTestCase):
                          'resources.AResource: foo',
                          self.stack.status_reason)
 
-    def test_delete_stack_with_resource_log_is_clear(self):
-        debug_logger = self.useFixture(
-            fixtures.FakeLogger(level=logging.DEBUG,
-                                format="%(levelname)8s [%(name)s] "
-                                       "%(message)s"))
-        tmpl = {'HeatTemplateFormatVersion': '2012-12-12',
-                'Resources': {'AResource': {'Type': 'GenericResourceType'}}}
-        self.stack = stack.Stack(self.ctx, 'delete_log_test',
-                                 template.Template(tmpl))
-        self.stack.store()
-        self.stack.create()
-        self.assertEqual((self.stack.CREATE, self.stack.COMPLETE),
-                         self.stack.state)
-        self.stack.delete()
-        self.assertNotIn("destroy from None running",
-                         debug_logger.output)
-
     def test_stack_user_project_id_delete_fail(self):
 
-        class FakeKeystoneClientFail(fake_ks.FakeKeystoneClient):
+        class FakeKeystoneClientFail(fakes.FakeKeystoneClient):
             def delete_stack_domain_project(self, project_id):
                 raise kc_exceptions.Forbidden("Denied!")
 
