@@ -12,14 +12,16 @@
 #    under the License.
 
 
+import mock
 import mox
+import six
 import swiftclient.client as sc
 
 from heat.common import exception
 from heat.common import template_format
-from heat.engine.resources import swift
+from heat.engine.resources.openstack.swift import swift
 from heat.engine import scheduler
-from heat.tests.common import HeatTestCase
+from heat.tests import common
 from heat.tests import utils
 
 
@@ -64,16 +66,18 @@ swift_template = '''
 '''
 
 
-class swiftTest(HeatTestCase):
+class swiftTest(common.HeatTestCase):
     def setUp(self):
         super(swiftTest, self).setUp()
         self.m.CreateMock(sc.Connection)
         self.m.StubOutWithMock(sc.Connection, 'post_account')
         self.m.StubOutWithMock(sc.Connection, 'put_container')
+        self.m.StubOutWithMock(sc.Connection, 'get_container')
         self.m.StubOutWithMock(sc.Connection, 'delete_container')
+        self.m.StubOutWithMock(sc.Connection, 'delete_object')
         self.m.StubOutWithMock(sc.Connection, 'head_container')
         self.m.StubOutWithMock(sc.Connection, 'get_auth')
-        self.stub_keystoneclient()
+        self.stub_auth()
 
     def create_resource(self, t, stack, resource_name):
         resource_defns = stack.t.resource_definitions(stack)
@@ -85,6 +89,11 @@ class swiftTest(HeatTestCase):
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
         return rsrc
 
+    def stub_delete_empty(self, res_id):
+        sc.Connection.get_container(res_id).AndReturn(
+            ({'name': res_id}, []))
+        sc.Connection.delete_container(res_id).AndReturn(None)
+
     def test_create_container_name(self):
         self.m.ReplayAll()
         t = template_format.parse(swift_template)
@@ -131,7 +140,7 @@ class swiftTest(HeatTestCase):
             container_name, {}).AndReturn(None)
         sc.Connection.head_container(
             mox.IgnoreArg()).MultipleTimes().AndReturn(headers)
-        sc.Connection.delete_container(container_name).AndReturn(None)
+        self.stub_delete_empty(container_name)
 
         self.m.ReplayAll()
         t = template_format.parse(swift_template)
@@ -160,7 +169,7 @@ class swiftTest(HeatTestCase):
         sc.Connection.put_container(
             container_name,
             {'X-Container-Read': '.r:*'}).AndReturn(None)
-        sc.Connection.delete_container(container_name).AndReturn(None)
+        self.stub_delete_empty(container_name)
 
         self.m.ReplayAll()
         t = template_format.parse(swift_template)
@@ -177,7 +186,7 @@ class swiftTest(HeatTestCase):
             container_name,
             {'X-Container-Write': '.r:*',
              'X-Container-Read': '.r:*'}).AndReturn(None)
-        sc.Connection.delete_container(container_name).AndReturn(None)
+        self.stub_delete_empty(container_name)
 
         self.m.ReplayAll()
         t = template_format.parse(swift_template)
@@ -196,7 +205,7 @@ class swiftTest(HeatTestCase):
             {'X-Container-Meta-Web-Error': 'error.html',
              'X-Container-Meta-Web-Index': 'index.html',
              'X-Container-Read': '.r:*'}).AndReturn(None)
-        sc.Connection.delete_container(container_name).AndReturn(None)
+        self.stub_delete_empty(container_name)
 
         self.m.ReplayAll()
         t = template_format.parse(swift_template)
@@ -210,7 +219,7 @@ class swiftTest(HeatTestCase):
         sc.Connection.put_container(container_name, {})
         sc.Connection.post_account(
             {'X-Account-Meta-Temp-Url-Key': 'secret'}).AndReturn(None)
-        sc.Connection.delete_container(container_name).AndReturn(None)
+        self.stub_delete_empty(container_name)
 
         self.m.ReplayAll()
         t = template_format.parse(swift_template)
@@ -224,6 +233,9 @@ class swiftTest(HeatTestCase):
         sc.Connection.put_container(
             container_name,
             {}).AndReturn(None)
+        sc.Connection.get_container(
+            container_name).AndReturn(({'name': container_name},
+                                       []))
         sc.Connection.delete_container(container_name).AndRaise(
             sc.ClientException('Test delete failure'))
 
@@ -241,6 +253,9 @@ class swiftTest(HeatTestCase):
         sc.Connection.put_container(
             container_name,
             {}).AndReturn(None)
+        sc.Connection.get_container(
+            container_name).AndReturn(({'name': container_name},
+                                       []))
         sc.Connection.delete_container(container_name).AndRaise(
             sc.ClientException('Its gone',
                                http_status=404))
@@ -253,6 +268,120 @@ class swiftTest(HeatTestCase):
 
         self.m.VerifyAll()
 
+    def test_delete_non_empty_not_allowed(self):
+        container_name = utils.PhysName('test_stack', 'test_resource')
+        sc.Connection.put_container(
+            container_name,
+            {}).AndReturn(None)
+        sc.Connection.get_container(
+            container_name).AndReturn(({'name': container_name},
+                                       [{'name': 'test_object'}]))
+
+        self.m.ReplayAll()
+        t = template_format.parse(swift_template)
+        stack = utils.parse_stack(t)
+        rsrc = self.create_resource(t, stack, 'SwiftContainer')
+        deleter = scheduler.TaskRunner(rsrc.delete)
+        ex = self.assertRaises(exception.ResourceFailure, deleter)
+        self.assertIn('ResourceActionNotSupported: resources.test_resource: '
+                      'Deleting non-empty container',
+                      six.text_type(ex))
+
+        self.m.VerifyAll()
+
+    def test_delete_non_empty_allowed(self):
+        container_name = utils.PhysName('test_stack', 'test_resource')
+        sc.Connection.put_container(
+            container_name,
+            {}).AndReturn(None)
+        sc.Connection.get_container(
+            container_name).AndReturn(({'name': container_name},
+                                       [{'name': 'test_object1'},
+                                        {'name': 'test_object2'}]))
+        sc.Connection.delete_object(container_name, 'test_object2'
+                                    ).AndReturn(None)
+        sc.Connection.get_container(
+            container_name).AndReturn(({'name': container_name},
+                                       [{'name': 'test_object1'}]))
+        sc.Connection.delete_object(container_name, 'test_object1'
+                                    ).AndReturn(None)
+        sc.Connection.delete_container(container_name).AndReturn(None)
+
+        self.m.ReplayAll()
+        t = template_format.parse(swift_template)
+        t['Resources']['SwiftContainer']['Properties']['PurgeOnDelete'] = True
+        stack = utils.parse_stack(t)
+        rsrc = self.create_resource(t, stack, 'SwiftContainer')
+        scheduler.TaskRunner(rsrc.delete)()
+        self.assertEqual((rsrc.DELETE, rsrc.COMPLETE), rsrc.state)
+        self.m.VerifyAll()
+
+    def test_delete_non_empty_allowed_ignores_not_found(self):
+        container_name = utils.PhysName('test_stack', 'test_resource')
+        sc.Connection.put_container(
+            container_name,
+            {}).AndReturn(None)
+        sc.Connection.get_container(
+            container_name).AndReturn(({'name': container_name},
+                                       [{'name': 'test_object'}]))
+        sc.Connection.delete_object(
+            container_name, 'test_object').AndRaise(
+                sc.ClientException('Object is gone', http_status=404))
+        sc.Connection.delete_container(
+            container_name).AndRaise(
+                sc.ClientException('Container is gone', http_status=404))
+
+        self.m.ReplayAll()
+        t = template_format.parse(swift_template)
+        t['Resources']['SwiftContainer']['Properties']['PurgeOnDelete'] = True
+        stack = utils.parse_stack(t)
+        rsrc = self.create_resource(t, stack, 'SwiftContainer')
+        scheduler.TaskRunner(rsrc.delete)()
+        self.assertEqual((rsrc.DELETE, rsrc.COMPLETE), rsrc.state)
+        self.m.VerifyAll()
+
+    def test_delete_non_empty_fails_delete_object(self):
+        container_name = utils.PhysName('test_stack', 'test_resource')
+        sc.Connection.put_container(
+            container_name,
+            {}).AndReturn(None)
+        sc.Connection.get_container(
+            container_name).AndReturn(({'name': container_name},
+                                       [{'name': 'test_object'}]))
+        sc.Connection.delete_object(
+            container_name, 'test_object').AndRaise(
+                sc.ClientException('Test object delete failure'))
+
+        self.m.ReplayAll()
+        t = template_format.parse(swift_template)
+        t['Resources']['SwiftContainer']['Properties']['PurgeOnDelete'] = True
+        stack = utils.parse_stack(t)
+        rsrc = self.create_resource(t, stack, 'SwiftContainer')
+        self.assertRaises(exception.ResourceFailure,
+                          scheduler.TaskRunner(rsrc.delete))
+        self.m.VerifyAll()
+
+    def _get_check_resource(self):
+        t = template_format.parse(swift_template)
+        self.stack = utils.parse_stack(t)
+        res = self.create_resource(t, self.stack, 'SwiftContainer')
+        res.swift = mock.Mock()
+        return res
+
+    def test_check(self):
+        res = self._get_check_resource()
+        scheduler.TaskRunner(res.check)()
+        self.assertEqual((res.CHECK, res.COMPLETE), res.state)
+
+    def test_check_fail(self):
+        res = self._get_check_resource()
+        res.swift().get_container.side_effect = Exception('boom')
+
+        exc = self.assertRaises(exception.ResourceFailure,
+                                scheduler.TaskRunner(res.check))
+        self.assertIn('boom', six.text_type(exc))
+        self.assertEqual((res.CHECK, res.FAILED), res.state)
+
     def test_delete_retain(self):
         # first run, with retain policy
         sc.Connection.put_container(
@@ -279,7 +408,7 @@ class swiftTest(HeatTestCase):
         container_name = utils.PhysName('test_stack', 'test_resource')
         sc.Connection.put_container(
             container_name, {}).AndReturn(None)
-        sc.Connection.delete_container(container_name).AndReturn(None)
+        self.stub_delete_empty(container_name)
 
         self.m.ReplayAll()
         t = template_format.parse(swift_template)
