@@ -15,17 +15,18 @@ from glanceclient import exc as glance_exceptions
 import six
 
 from heat.common import exception
+from heat.common.i18n import _
 from heat.common import template_format
 from heat.engine.clients.os import glance
 from heat.engine.clients.os import nova
 from heat.engine import environment
-from heat.engine.hot.template import HOTemplate20130523
+from heat.engine.hot import template as tmpl
 from heat.engine import parser
 from heat.engine import resources
 from heat.engine import service
-from heat.tests.common import HeatTestCase
+from heat.tests import common
+from heat.tests.nova import fakes as fakes_nova
 from heat.tests import utils
-from heat.tests.v1_1 import fakes
 
 test_template_volumeattach = '''
 {
@@ -67,83 +68,77 @@ test_template_ref = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Resources" : {
-        "WikiDatabase": {
-          "Type": "AWS::EC2::Instance",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" }
-          }
-        },
-        "DataVolume" : {
-          "Type" : "AWS::EC2::Volume",
-          "Properties" : {
-            "Size" : "6",
-            "AvailabilityZone" : "nova"
-          }
-        },
-        "MountPoint" : {
-          "Type" : "AWS::EC2::VolumeAttachment",
-          "Properties" : {
-            "InstanceId" : { "Ref" : "%s" },
-            "VolumeId"  : { "Ref" : "DataVolume" },
-            "Device" : "/dev/vdb"
-          }
-        }
+  "Resources" : {
+    "WikiDatabase": {
+      "Type": "AWS::EC2::Instance",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" }
+      }
+    },
+    "DataVolume" : {
+      "Type" : "AWS::EC2::Volume",
+      "Properties" : {
+        "Size" : "6",
+        "AvailabilityZone" : "nova"
+      }
+    },
+    "MountPoint" : {
+      "Type" : "AWS::EC2::VolumeAttachment",
+      "Properties" : {
+        "InstanceId" : { "Ref" : "%s" },
+        "VolumeId"  : { "Ref" : "DataVolume" },
+        "Device" : "/dev/vdb"
       }
     }
-    '''
+  }
+}
+'''
 test_template_findinmap_valid = '''
 {
   "AWSTemplateFormatVersion" : "2010-09-09",
   "Description" : "test.",
   "Parameters" : {
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2 KeyPair to' + \
-    'enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Resources" : {
-        "WikiDatabase": {
-          "Type": "AWS::EC2::Instance",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" }
-          }
-        },
-        "DataVolume" : {
-          "Type" : "AWS::EC2::Volume",
-          "Properties" : {
-            "Size" : "6",
-            "AvailabilityZone" : "nova"
-          }
-        },
+  "Resources" : {
+    "WikiDatabase": {
+      "Type": "AWS::EC2::Instance",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" }
+      }
+    },
+    "DataVolume" : {
+      "Type" : "AWS::EC2::Volume",
+      "Properties" : {
+        "Size" : "6",
+        "AvailabilityZone" : "nova"
+      }
+    },
 
-        "MountPoint" : {
-          "Type" : "AWS::EC2::VolumeAttachment",
-          "Properties" : {
-            "InstanceId" : { "Ref" : "WikiDatabase" },
-            "VolumeId"  : { "Ref" : "DataVolume" },
-            "Device" : "/dev/vdb"
-          }
-        }
+    "MountPoint" : {
+      "Type" : "AWS::EC2::VolumeAttachment",
+      "Properties" : {
+        "InstanceId" : { "Ref" : "WikiDatabase" },
+        "VolumeId"  : { "Ref" : "DataVolume" },
+        "Device" : "/dev/vdb"
       }
     }
-    '''
+  }
+}
+'''
 test_template_findinmap_invalid = '''
 {
   "AWSTemplateFormatVersion" : "2010-09-09",
@@ -151,40 +146,39 @@ test_template_findinmap_invalid = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2 KeyPair to enable SSH ' + \
-    'access to the instances",' + \
-    '''      "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Mappings" : {
-        "AWSInstanceType2Arch" : {
-          "t1.micro"    : { "Arch" : "64" },
-          "m1.small"    : { "Arch" : "64" },
-          "m1.medium"   : { "Arch" : "64" },
-          "m1.large"    : { "Arch" : "64" },
-          "m1.xlarge"   : { "Arch" : "64" },
-          "m2.xlarge"   : { "Arch" : "64" },
-          "m2.2xlarge"  : { "Arch" : "64" },
-          "m2.4xlarge"  : { "Arch" : "64" },
-          "c1.medium"   : { "Arch" : "64" },
-          "c1.xlarge"   : { "Arch" : "64" },
-          "cc1.4xlarge" : { "Arch" : "64HVM" },
-          "cc2.8xlarge" : { "Arch" : "64HVM" },
-          "cg1.4xlarge" : { "Arch" : "64HVM" }
-        }
-      },
-      "Resources" : {
-        "WikiDatabase": {
-          "Type": "AWS::EC2::Instance",
-          "Properties": {
-    ''' + \
-    '"ImageId" : { "Fn::FindInMap" : [ "DistroArch2AMI", { "Ref" : ' + \
-    '"LinuxDistribution" },' + \
-    '{ "Fn::FindInMap" : [ "AWSInstanceType2Arch", { "Ref" : ' + \
-    '"InstanceType" }, "Arch" ] } ] },' + \
-    '''
+  "Mappings" : {
+    "AWSInstanceType2Arch" : {
+      "t1.micro"    : { "Arch" : "64" },
+      "m1.small"    : { "Arch" : "64" },
+      "m1.medium"   : { "Arch" : "64" },
+      "m1.large"    : { "Arch" : "64" },
+      "m1.xlarge"   : { "Arch" : "64" },
+      "m2.xlarge"   : { "Arch" : "64" },
+      "m2.2xlarge"  : { "Arch" : "64" },
+      "m2.4xlarge"  : { "Arch" : "64" },
+      "c1.medium"   : { "Arch" : "64" },
+      "c1.xlarge"   : { "Arch" : "64" },
+      "cc1.4xlarge" : { "Arch" : "64HVM" },
+      "cc2.8xlarge" : { "Arch" : "64HVM" },
+      "cg1.4xlarge" : { "Arch" : "64HVM" }
+    }
+  },
+  "Resources" : {
+    "WikiDatabase": {
+      "Type": "AWS::EC2::Instance",
+      "Properties": {
+        "ImageId" : {
+          "Fn::FindInMap" : [
+            "DistroArch2AMI", { "Ref" : "LinuxDistribution" },
+              { "Fn::FindInMap" : [
+              "AWSInstanceType2Arch",
+                { "Ref" : "InstanceType" }, "Arch" ] } ]
+        },
         "InstanceType": "m1.large",
         "KeyName": { "Ref" : "KeyName"}
       }
@@ -241,13 +235,10 @@ test_template_invalid_property = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2 KeyPai",
+      "Type" : "String"
+    }
+  },
 
       "Resources" : {
         "WikiDatabase": {
@@ -270,27 +261,24 @@ test_template_unimplemented_property = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Resources" : {
-        "WikiDatabase": {
-          "Type": "AWS::EC2::Instance",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" },
-            "SourceDestCheck": "false"
-          }
-        }
+  "Resources" : {
+    "WikiDatabase": {
+      "Type": "AWS::EC2::Instance",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" },
+        "SourceDestCheck": "false"
       }
     }
-    '''
+  }
+}
+'''
 
 test_template_invalid_deletion_policy = '''
 {
@@ -299,27 +287,24 @@ test_template_invalid_deletion_policy = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Resources" : {
-        "WikiDatabase": {
-          "Type": "AWS::EC2::Instance",
-          "DeletionPolicy": "Destroy",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" }
-          }
-        }
+  "Resources" : {
+    "WikiDatabase": {
+      "Type": "AWS::EC2::Instance",
+      "DeletionPolicy": "Destroy",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" }
       }
     }
-    '''
+  }
+}
+'''
 
 test_template_snapshot_deletion_policy = '''
 {
@@ -328,27 +313,24 @@ test_template_snapshot_deletion_policy = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Resources" : {
-        "WikiDatabase": {
-          "Type": "AWS::EC2::Instance",
-          "DeletionPolicy": "Snapshot",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" }
-          }
-        }
+  "Resources" : {
+    "WikiDatabase": {
+      "Type": "AWS::EC2::Instance",
+      "DeletionPolicy": "Snapshot",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" }
       }
     }
-    '''
+  }
+}
+'''
 
 test_template_volume_snapshot = '''
 {
@@ -374,26 +356,23 @@ test_unregistered_key = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Resources" : {
-        "Instance": {
-          "Type": "AWS::EC2::Instance",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" }
-          }
-        }
+  "Resources" : {
+    "Instance": {
+      "Type": "AWS::EC2::Instance",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" }
       }
     }
-    '''
+  }
+}
+'''
 
 test_template_image = '''
 {
@@ -402,26 +381,23 @@ test_template_image = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Resources" : {
-        "Instance": {
-          "Type": "AWS::EC2::Instance",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" }
-          }
-        }
+  "Resources" : {
+    "Instance": {
+      "Type": "AWS::EC2::Instance",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" }
       }
     }
-    '''
+  }
+}
+'''
 
 test_template_invalid_secgroups = '''
 {
@@ -430,28 +406,25 @@ test_template_invalid_secgroups = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Resources" : {
-        "Instance": {
-          "Type": "AWS::EC2::Instance",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" },
-            "SecurityGroups": [ "default" ],
-            "NetworkInterfaces": [ "mgmt", "data" ]
-          }
-        }
+  "Resources" : {
+    "Instance": {
+      "Type": "AWS::EC2::Instance",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" },
+        "SecurityGroups": [ "default" ],
+        "NetworkInterfaces": [ "mgmt", "data" ]
       }
     }
-    '''
+  }
+}
+'''
 
 test_template_invalid_secgroupids = '''
 {
@@ -460,28 +433,25 @@ test_template_invalid_secgroupids = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    }
+  },
 
-      "Resources" : {
-        "Instance": {
-          "Type": "AWS::EC2::Instance",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" },
-            "SecurityGroupIds": [ "default" ],
-            "NetworkInterfaces": [ "mgmt", "data" ]
-          }
-        }
+  "Resources" : {
+    "Instance": {
+      "Type": "AWS::EC2::Instance",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" },
+        "SecurityGroupIds": [ "default" ],
+        "NetworkInterfaces": [ "mgmt", "data" ]
       }
     }
-    '''
+  }
+}
+'''
 
 test_template_glance_client_exception = '''
 {
@@ -507,34 +477,28 @@ test_template_unique_logical_name = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String"
+    },
     "AName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String"
-        }
-      },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String",
+    }
+  },
 
-      "Resources" : {
-        "AName": {
-          "Type": "AWS::EC2::Instance",
-          "Properties": {
-            "ImageId": "image_name",
-            "InstanceType": "m1.large",
-            "KeyName": { "Ref" : "KeyName" },
-            "NetworkInterfaces": [ "mgmt", "data" ]
-          }
-        }
+  "Resources" : {
+    "AName": {
+      "Type": "AWS::EC2::Instance",
+      "Properties": {
+        "ImageId": "image_name",
+        "InstanceType": "m1.large",
+        "KeyName": { "Ref" : "KeyName" },
+        "NetworkInterfaces": [ "mgmt", "data" ]
       }
     }
-    '''
+  }
+}
+'''
 
 test_template_cfn_parameter_label = '''
 {
@@ -543,13 +507,10 @@ test_template_cfn_parameter_label = '''
   "Parameters" : {
 
     "KeyName" : {
-''' + \
-    '"Description" : "Name of an existing EC2' + \
-    'KeyPair to enable SSH access to the instances",' + \
-    '''
-          "Type" : "String",
-          "Label" : "Nova KeyPair Name"
-        },
+      "Description" : "Name of an existing EC2KeyPair",
+      "Type" : "String",
+      "Label" : "Nova KeyPair Name"
+    }
   },
 
   "Resources" : {
@@ -837,13 +798,25 @@ resources:
       name: { get_param: net_name }
 '''
 
+test_template_invalid_outputs = '''
+heat_template_version: 2013-05-23
 
-class validateTest(HeatTestCase):
+resources:
+  random_str:
+    type: OS::Heat::RandomString
+
+outputs:
+  string:
+    value: {get_attr: [[random_str, value]]}
+'''
+
+
+class validateTest(common.HeatTestCase):
     def setUp(self):
         super(validateTest, self).setUp()
         resources.initialise()
-        self.fc = fakes.FakeClient()
-        self.gc = fakes.FakeClient()
+        self.fc = fakes_nova.FakeClient()
+        self.gc = fakes_nova.FakeClient()
         resources.initialise()
         self.ctx = utils.dummy_context()
         self.patch('heat.engine.service.warnings')
@@ -929,8 +902,7 @@ class validateTest(HeatTestCase):
         # API layer in heat.engine.api.format_validate_parameter.
         expected = {'KeyName': {
             'Type': 'String',
-            'Description': 'Name of an existing EC2KeyPair to enable SSH '
-                           'access to the instances',
+            'Description': 'Name of an existing EC2KeyPair',
             'NoEcho': 'false',
             'Label': 'KeyName'}}
         self.assertEqual(expected, res['Parameters'])
@@ -1001,8 +973,7 @@ class validateTest(HeatTestCase):
 
         expected = {'KeyName': {
             'Type': 'String',
-            'Description': 'Name of an existing EC2KeyPair to enable SSH '
-                           'access to the instances',
+            'Description': 'Name of an existing EC2KeyPair',
             'NoEcho': 'false',
             'Label': 'Nova KeyPair Name'}}
         self.assertEqual(expected, parameters)
@@ -1063,14 +1034,15 @@ class validateTest(HeatTestCase):
         t = template_format.parse(test_template_invalid_property)
         engine = service.EngineService('a', 't')
         res = dict(engine.validate_template(None, t, {}))
-        self.assertEqual({'Error': 'Unknown Property UnknownProperty'}, res)
+        self.assertEqual({'Error': 'Property error: WikiDatabase.Properties: '
+                                   'Unknown Property UnknownProperty'}, res)
 
     def test_invalid_resources(self):
         t = template_format.parse(test_template_invalid_resources)
         engine = service.EngineService('a', 't')
         res = dict(engine.validate_template(None, t, {}))
         self.assertEqual({'Error': 'Resources must contain Resource. '
-                          'Found a [string] instead'},
+                          'Found a [%s] instead' % six.text_type},
                          res)
 
     def test_invalid_section_cfn(self):
@@ -1112,7 +1084,8 @@ class validateTest(HeatTestCase):
         engine = service.EngineService('a', 't')
         res = dict(engine.validate_template(None, t, {}))
         self.assertEqual(
-            {'Error': 'Property SourceDestCheck not implemented yet'},
+            {'Error': 'Property error: WikiDatabase.Properties: '
+                      'Property SourceDestCheck not implemented yet'},
             res)
 
     def test_invalid_deletion_policy(self):
@@ -1228,7 +1201,7 @@ class validateTest(HeatTestCase):
         self.assertEqual({'Error': 'u\'"DependsOn" is not a valid keyword '
                                    'inside a resource definition\''}, res)
 
-    def test_validate_template_with_invalid_resource_deletion_polciy(self):
+    def test_validate_template_with_invalid_resource_deletion_policy(self):
         hot_tpl = template_format.parse('''
         heat_template_version: 2013-05-23
         resources:
@@ -1274,10 +1247,9 @@ class validateTest(HeatTestCase):
 
     def test_unregistered_key(self):
         t = template_format.parse(test_unregistered_key)
-        template = parser.Template(t)
         params = {'KeyName': 'not_registered'}
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment(params))
+        template = parser.Template(t, env=environment.Environment(params))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
 
         self._mock_get_image_id_success('image_name', 'image_id')
         self.m.ReplayAll()
@@ -1288,10 +1260,11 @@ class validateTest(HeatTestCase):
 
     def test_unregistered_image(self):
         t = template_format.parse(test_template_image)
-        template = parser.Template(t)
+        template = parser.Template(t,
+                                   env=environment.Environment(
+                                       {'KeyName': 'test'}))
 
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'KeyName': 'test'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
 
         self._mock_get_image_id_fail('image_name',
                                      exception.ImageNotFound(
@@ -1305,10 +1278,11 @@ class validateTest(HeatTestCase):
 
     def test_duplicated_image(self):
         t = template_format.parse(test_template_image)
-        template = parser.Template(t)
+        template = parser.Template(t,
+                                   env=environment.Environment(
+                                       {'KeyName': 'test'}))
 
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'KeyName': 'test'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
 
         self._mock_get_image_id_fail('image_name',
                                      exception.PhysicalResourceNameAmbiguity(
@@ -1324,9 +1298,10 @@ class validateTest(HeatTestCase):
 
     def test_invalid_security_groups_with_nics(self):
         t = template_format.parse(test_template_invalid_secgroups)
-        template = parser.Template(t)
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'KeyName': 'test'}))
+        template = parser.Template(t,
+                                   env=environment.Environment(
+                                       {'KeyName': 'test'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
 
         self._mock_get_image_id_success('image_name', 'image_id')
 
@@ -1341,9 +1316,9 @@ class validateTest(HeatTestCase):
 
     def test_invalid_security_group_ids_with_nics(self):
         t = template_format.parse(test_template_invalid_secgroupids)
-        template = parser.Template(t)
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'KeyName': 'test'}))
+        template = parser.Template(
+            t, env=environment.Environment({'KeyName': 'test'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
 
         self._mock_get_image_id_success('image_name', 'image_id')
 
@@ -1373,97 +1348,97 @@ class validateTest(HeatTestCase):
 
     def test_validate_unique_logical_name(self):
         t = template_format.parse(test_template_unique_logical_name)
-        template = parser.Template(t)
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'AName': 'test',
-                                                      'KeyName': 'test'}))
+        template = parser.Template(
+            t, env=environment.Environment(
+                {'AName': 'test', 'KeyName': 'test'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
 
         self.assertRaises(exception.StackValidationFailed, stack.validate)
 
     def test_validate_duplicate_parameters_in_group(self):
         t = template_format.parse(test_template_duplicate_parameters)
-        template = HOTemplate20130523(t)
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({
-                                 'KeyName': 'test',
-                                 'ImageId': 'sometestid',
-                                 'db_password': 'Pass123'
-                             }))
+        template = tmpl.HOTemplate20130523(
+            t, env=environment.Environment({
+                'KeyName': 'test',
+                'ImageId': 'sometestid',
+                'db_password': 'Pass123'
+            }))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
         exc = self.assertRaises(exception.StackValidationFailed,
                                 stack.validate)
 
         self.assertEqual(_('The InstanceType parameter must be assigned to '
-                         'one Parameter Group only.'), six.text_type(exc))
+                           'one Parameter Group only.'),
+                         six.text_type(exc))
 
     def test_validate_invalid_parameter_in_group(self):
         t = template_format.parse(test_template_invalid_parameter_name)
-        template = HOTemplate20130523(t)
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({
-                                 'KeyName': 'test',
-                                 'ImageId': 'sometestid',
-                                 'db_password': 'Pass123'}))
+        template = tmpl.HOTemplate20130523(t,
+                                           env=environment.Environment({
+                                               'KeyName': 'test',
+                                               'ImageId': 'sometestid',
+                                               'db_password': 'Pass123'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
 
         exc = self.assertRaises(exception.StackValidationFailed,
                                 stack.validate)
 
         self.assertEqual(_('The Parameter name (SomethingNotHere) does not '
-                         'reference an existing parameter.'),
+                           'reference an existing parameter.'),
                          six.text_type(exc))
 
     def test_validate_no_parameters_in_group(self):
         t = template_format.parse(test_template_no_parameters)
-        template = HOTemplate20130523(t)
+        template = tmpl.HOTemplate20130523(t)
         stack = parser.Stack(self.ctx, 'test_stack', template)
         exc = self.assertRaises(exception.StackValidationFailed,
                                 stack.validate)
 
-        self.assertEqual(_('Parameters must be provided for each Parameter '
-                         'Group.'), six.text_type(exc))
+        self.assertEqual(_('Parameters must be provided for each '
+                           'Parameter Group.'), six.text_type(exc))
 
     def test_validate_allowed_values_integer(self):
         t = template_format.parse(test_template_allowed_integers)
-        template = parser.Template(t)
+        template = parser.Template(t,
+                                   env=environment.Environment({'size': '4'}))
 
         # test with size parameter provided as string
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'size': '4'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
         self.assertIsNone(stack.validate())
 
         # test with size parameter provided as number
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'size': 4}))
+        template.env = environment.Environment({'size': 4})
+        stack = parser.Stack(self.ctx, 'test_stack', template)
         self.assertIsNone(stack.validate())
 
     def test_validate_allowed_values_integer_str(self):
         t = template_format.parse(test_template_allowed_integers_str)
-        template = parser.Template(t)
+        template = parser.Template(t,
+                                   env=environment.Environment({'size': '4'}))
 
         # test with size parameter provided as string
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'size': '4'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
         self.assertIsNone(stack.validate())
-
         # test with size parameter provided as number
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'size': 4}))
+        template.env = environment.Environment({'size': 4})
+        stack = parser.Stack(self.ctx, 'test_stack', template)
         self.assertIsNone(stack.validate())
 
     def test_validate_not_allowed_values_integer(self):
         t = template_format.parse(test_template_allowed_integers)
-        template = parser.Template(t)
+        template = parser.Template(t,
+                                   env=environment.Environment({'size': '3'}))
 
         # test with size parameter provided as string
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'size': '3'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
         err = self.assertRaises(exception.StackValidationFailed,
                                 stack.validate)
         self.assertIn('"3" is not an allowed value [1, 4, 8]',
                       six.text_type(err))
 
         # test with size parameter provided as number
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'size': 3}))
+        template.env = environment.Environment({'size': 3})
+        stack = parser.Stack(self.ctx, 'test_stack', template)
         err = self.assertRaises(exception.StackValidationFailed,
                                 stack.validate)
         self.assertIn('"3" is not an allowed value [1, 4, 8]',
@@ -1471,20 +1446,54 @@ class validateTest(HeatTestCase):
 
     def test_validate_not_allowed_values_integer_str(self):
         t = template_format.parse(test_template_allowed_integers_str)
-        template = parser.Template(t)
+        template = parser.Template(t,
+                                   env=environment.Environment({'size': '3'}))
 
         # test with size parameter provided as string
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'size': '3'}))
+        stack = parser.Stack(self.ctx, 'test_stack', template)
         err = self.assertRaises(exception.StackValidationFailed,
                                 stack.validate)
         self.assertIn('"3" is not an allowed value [1, 4, 8]',
                       six.text_type(err))
 
         # test with size parameter provided as number
-        stack = parser.Stack(self.ctx, 'test_stack', template,
-                             environment.Environment({'size': 3}))
+        template.env = environment.Environment({'size': 3})
+        stack = parser.Stack(self.ctx, 'test_stack', template)
         err = self.assertRaises(exception.StackValidationFailed,
                                 stack.validate)
         self.assertIn('"3" is not an allowed value [1, 4, 8]',
                       six.text_type(err))
+
+    def test_validate_invalid_outputs(self):
+        t = template_format.parse(test_template_invalid_outputs)
+        template = parser.Template(t)
+        err = self.assertRaises(exception.StackValidationFailed,
+                                parser.Stack, self.ctx, 'test_stack', template)
+        error_message = ('Arguments to "get_attr" must be of the form '
+                         '[resource_name, attribute, (path), ...]')
+        self.assertEqual(error_message, six.text_type(err))
+
+    def test_validate_resource_attr_invalid_type(self):
+        t = template_format.parse("""
+        heat_template_version: 2013-05-23
+        resources:
+          resource:
+              type: 123
+        """)
+        template = parser.Template(t)
+        stack = parser.Stack(self.ctx, 'test_stack', template)
+        ex = self.assertRaises(exception.StackValidationFailed, stack.validate)
+        self.assertEqual('Resource resource type type must be string',
+                         six.text_type(ex))
+
+    def test_validate_resource_attr_invalid_type_cfn(self):
+        t = template_format.parse("""
+        HeatTemplateFormatVersion: '2012-12-12'
+        Resources:
+          Resource:
+            Type: [Wrong, Type]
+        """)
+        stack = parser.Stack(self.ctx, 'test_stack', parser.Template(t))
+        ex = self.assertRaises(exception.StackValidationFailed, stack.validate)
+        self.assertEqual('Resource Resource Type type must be string',
+                         six.text_type(ex))
