@@ -16,20 +16,20 @@ import uuid
 from heat.common import exception
 from heat.common import template_format
 from heat.engine import parser
-from heat.engine.resources import subnet as sn
+from heat.engine.resources.aws.ec2 import subnet as sn
 from heat.engine import scheduler
 from heat.engine import template
-from heat.tests.common import HeatTestCase
+from heat.tests import common
 from heat.tests import utils
 
 try:
-    from neutronclient.common.exceptions import NeutronClientException
+    from neutronclient.common import exceptions as neutron_exc
     from neutronclient.v2_0 import client as neutronclient
 except ImportError:
     neutronclient = None
 
 
-class VPCTestBase(HeatTestCase):
+class VPCTestBase(common.HeatTestCase):
 
     def setUp(self):
         super(VPCTestBase, self).setUp()
@@ -59,7 +59,6 @@ class VPCTestBase(HeatTestCase):
             neutronclient.Client, 'create_security_group_rule')
         self.m.StubOutWithMock(
             neutronclient.Client, 'delete_security_group_rule')
-        self.stub_keystoneclient()
 
     def create_stack(self, templ):
         t = template_format.parse(templ)
@@ -190,9 +189,9 @@ class VPCTestBase(HeatTestCase):
                 'direction': 'ingress',
                 'remote_group_id': None,
                 'remote_ip_prefix': '0.0.0.0/0',
-                'port_range_min': '22',
+                'port_range_min': 22,
                 'ethertype': 'IPv4',
-                'port_range_max': '22',
+                'port_range_max': 22,
                 'protocol': 'tcp',
                 'security_group_id': '0389f747-7785-4757-b7bb-2ab07e4b09c3'
             }
@@ -201,9 +200,9 @@ class VPCTestBase(HeatTestCase):
                 'direction': 'ingress',
                 'remote_group_id': None,
                 'remote_ip_prefix': '0.0.0.0/0',
-                'port_range_min': '22',
+                'port_range_min': 22,
                 'ethertype': 'IPv4',
-                'port_range_max': '22',
+                'port_range_max': 22,
                 'protocol': 'tcp',
                 'security_group_id': '0389f747-7785-4757-b7bb-2ab07e4b09c3',
                 'id': 'bbbb'
@@ -222,7 +221,7 @@ class VPCTestBase(HeatTestCase):
                     'security_group_rules': [{
                         'direction': 'ingress',
                         'protocol': 'tcp',
-                        'port_range_max': '22',
+                        'port_range_max': 22,
                         'id': 'bbbb',
                         'ethertype': 'IPv4',
                         'security_group_id': ('0389f747-7785-4757-b7bb-'
@@ -230,16 +229,16 @@ class VPCTestBase(HeatTestCase):
                         'remote_group_id': None,
                         'remote_ip_prefix': '0.0.0.0/0',
                         'tenant_id': 'c1210485b2424d48804aad5d39c61b8f',
-                        'port_range_min': '22'
+                        'port_range_min': 22
                     }],
                     'id': '0389f747-7785-4757-b7bb-2ab07e4b09c3'}})
         elif group == 'INVALID-NO-REF':
             neutronclient.Client.show_security_group(group).AndRaise(
-                NeutronClientException(status_code=404))
+                neutron_exc.NeutronClientException(status_code=404))
         elif group == 'RaiseException':
             neutronclient.Client.show_security_group(
                 '0389f747-7785-4757-b7bb-2ab07e4b09c3').AndRaise(
-                    NeutronClientException(status_code=403))
+                    neutron_exc.NeutronClientException(status_code=403))
 
     def mock_delete_security_group(self):
         self.mock_show_security_group()
@@ -354,7 +353,7 @@ Resources:
         neutronclient.Client.create_network(
             {
                 'network': {'name': self.vpc_name}
-            }).AndRaise(NeutronClientException())
+            }).AndRaise(neutron_exc.NeutronClientException())
 
     def test_vpc(self):
         self.mock_create_network()
@@ -375,7 +374,7 @@ Resources:
         t = template_format.parse(self.test_template)
         stack = self.parse_stack(t)
         scheduler.TaskRunner(stack.create)()
-        self.assertEqual(stack.state, (stack.CREATE, stack.FAILED))
+        self.assertEqual((stack.CREATE, stack.FAILED), stack.state)
         scheduler.TaskRunner(stack.delete)()
 
         self.m.VerifyAll()
@@ -408,9 +407,9 @@ Resources:
         neutronclient.Client.remove_interface_router(
             u'bbbb',
             {'subnet_id': 'cccc'}).AndRaise(
-                NeutronClientException(status_code=404))
+                neutron_exc.NeutronClientException(status_code=404))
         neutronclient.Client.delete_subnet('cccc').AndRaise(
-            NeutronClientException(status_code=404))
+            neutron_exc.NeutronClientException(status_code=404))
 
         self.m.ReplayAll()
         stack = self.create_stack(self.test_template)
@@ -446,9 +445,8 @@ Resources:
                         'tenant_id': 'c1210485b2424d48804aad5d39c61b8f',
                         'id': 'cccc'}})
 
-        neutronclient.Client.show_network(
-            'aaaa'
-        ).MultipleTimes().AndRaise(NeutronClientException(status_code=404))
+        neutronclient.Client.show_network('aaaa').MultipleTimes().AndRaise(
+            neutron_exc.NeutronClientException(status_code=404))
 
     def test_create_failed_delete_success(self):
         self._mock_create_subnet_failed()
@@ -644,6 +642,7 @@ Resources:
         self.mock_create_network()
         self.mock_create_subnet()
         self.mock_show_subnet()
+        self.stub_SubnetConstraint_validate()
         self.mock_create_network_interface()
         self.mock_show_network_interface()
         self.mock_delete_network_interface()
@@ -671,6 +670,7 @@ Resources:
         self.mock_create_network()
         self.mock_create_subnet()
         self.mock_show_subnet()
+        self.stub_SubnetConstraint_validate()
         self.mock_create_network_interface()
         self.mock_delete_network_interface()
         self.mock_delete_subnet()
@@ -693,6 +693,7 @@ Resources:
         self.mock_create_network()
         self.mock_create_subnet()
         self.mock_show_subnet()
+        self.stub_SubnetConstraint_validate()
         self.mock_create_network_interface(security_groups=None)
         self.mock_delete_network_interface()
         self.mock_delete_subnet()
@@ -771,6 +772,7 @@ Resources:
         self.mock_create_network()
         self.mock_create_subnet()
         self.mock_create_route_table()
+        self.stub_SubnetConstraint_validate()
         self.mock_create_association()
         self.mock_create_gateway_attachment()
         self.mock_delete_gateway_attachment()
@@ -790,7 +792,7 @@ Resources:
         self.assertResourceState(attachment, 'the_attachment')
 
         route_table = stack['the_route_table']
-        self.assertEqual(list(attachment._vpc_route_tables()), [route_table])
+        self.assertEqual([route_table], list(attachment._vpc_route_tables()))
 
         stack.delete()
         self.m.VerifyAll()
@@ -826,6 +828,7 @@ Resources:
         self.mock_create_network()
         self.mock_create_subnet()
         self.mock_create_route_table()
+        self.stub_SubnetConstraint_validate()
         self.mock_create_association()
         self.mock_delete_association()
         self.mock_delete_route_table()
