@@ -1,4 +1,4 @@
-
+#
 # Copyright 2010-2011 OpenStack Foundation
 # All Rights Reserved.
 #
@@ -15,18 +15,20 @@
 #    under the License.
 
 
-import datetime
 import json
-from oslo.config import cfg
+
+from oslo_config import cfg
+import six
 import stubout
 import webob
 
+from heat.api.aws import exception as aws_exception
 from heat.common import exception
 from heat.common import wsgi
-from heat.tests.common import HeatTestCase
+from heat.tests import common
 
 
-class RequestTest(HeatTestCase):
+class RequestTest(common.HeatTestCase):
 
     def setUp(self):
         self.stubs = stubout.StubOutForTesting()
@@ -102,7 +104,7 @@ class RequestTest(HeatTestCase):
         self.assertIsNone(request.best_match_language())
 
 
-class ResourceTest(HeatTestCase):
+class ResourceTest(common.HeatTestCase):
 
     def setUp(self):
         self.stubs = stubout.StubOutForTesting()
@@ -221,15 +223,18 @@ class ResourceTest(HeatTestCase):
 
         e = self.assertRaises(exception.HTTPExceptionDisguise,
                               resource, request)
-        self.assertEqual(message_es, str(e.exc))
+        self.assertEqual(message_es, six.text_type(e.exc))
         self.m.VerifyAll()
 
 
-class ResourceExceptionHandlingTest(HeatTestCase):
+class ResourceExceptionHandlingTest(common.HeatTestCase):
     scenarios = [
         ('client_exceptions', dict(
             exception=exception.StackResourceLimitExceeded,
             exception_catch=exception.StackResourceLimitExceeded)),
+        ('aws_exception', dict(
+            exception=aws_exception.HeatAccessDeniedError,
+            exception_catch=aws_exception.HeatAccessDeniedError)),
         ('webob_bad_request', dict(
             exception=webob.exc.HTTPBadRequest,
             exception_catch=exception.HTTPExceptionDisguise)),
@@ -255,42 +260,10 @@ class ResourceExceptionHandlingTest(HeatTestCase):
                                  None)
         e = self.assertRaises(self.exception_catch, resource, request)
         e = e.exc if hasattr(e, 'exc') else e
-        self.assertNotIn(str(e), self.logger.output)
+        self.assertNotIn(six.text_type(e), self.LOG.output)
 
 
-class JSONResponseSerializerTest(HeatTestCase):
-
-    def test_to_json(self):
-        fixture = {"key": "value"}
-        expected = '{"key": "value"}'
-        actual = wsgi.JSONResponseSerializer().to_json(fixture)
-        self.assertEqual(expected, actual)
-
-    def test_to_json_with_date_format_value(self):
-        fixture = {"date": datetime.datetime(1, 3, 8, 2)}
-        expected = '{"date": "0001-03-08T02:00:00"}'
-        actual = wsgi.JSONResponseSerializer().to_json(fixture)
-        self.assertEqual(expected, actual)
-
-    def test_to_json_with_more_deep_format(self):
-        fixture = {"is_public": True, "name": [{"name1": "test"}]}
-        expected = '{"is_public": true, "name": [{"name1": "test"}]}'
-        actual = wsgi.JSONResponseSerializer().to_json(fixture)
-        self.assertEqual(expected, actual)
-
-    def test_default(self):
-        fixture = {"key": "value"}
-        response = webob.Response()
-        wsgi.JSONResponseSerializer().default(response, fixture)
-        self.assertEqual(200, response.status_int)
-        content_types = filter(lambda h: h[0] == 'Content-Type',
-                               response.headerlist)
-        self.assertEqual(1, len(content_types))
-        self.assertEqual('application/json', response.content_type)
-        self.assertEqual('{"key": "value"}', response.body)
-
-
-class JSONRequestDeserializerTest(HeatTestCase):
+class JSONRequestDeserializerTest(common.HeatTestCase):
 
     def test_has_body_no_content_length(self):
         request = wsgi.Request.blank('/')
@@ -421,7 +394,7 @@ class JSONRequestDeserializerTest(HeatTestCase):
         error = self.assertRaises(exception.RequestLimitExceeded,
                                   wsgi.JSONRequestDeserializer().from_json,
                                   body)
-        msg = 'Request limit exceeded: JSON body size ' + \
-              '(%s bytes) exceeds maximum allowed size (%s bytes).' % \
-              (len(body), cfg.CONF.max_json_body_size)
-        self.assertEqual(msg, str(error))
+        msg = ('Request limit exceeded: JSON body size '
+               '(%s bytes) exceeds maximum allowed size (%s bytes).' % (
+                   len(body), cfg.CONF.max_json_body_size))
+        self.assertEqual(msg, six.text_type(error))
