@@ -14,16 +14,17 @@ import logging
 
 import yaml
 
-from heat_integrationtests.functional import functional_base
+from heat_integrationtests.common import test
 
 
 LOG = logging.getLogger(__name__)
 
 
-class HooksTest(functional_base.FunctionalTestsBase):
+class HooksTest(test.HeatIntegrationTest):
 
     def setUp(self):
         super(HooksTest, self).setUp()
+        self.client = self.orchestration_client
         self.template = {'heat_template_version': '2014-10-16',
                          'resources': {
                              'foo_step1': {'type': 'OS::Heat::RandomString'},
