@@ -15,10 +15,10 @@ import json
 
 from testtools import matchers
 
-from heat_integrationtests.functional import functional_base
+from heat_integrationtests.common import test
 
 
-class InstanceGroupTest(functional_base.FunctionalTestsBase):
+class InstanceGroupTest(test.HeatIntegrationTest):
 
     template = '''
 {
@@ -105,6 +105,7 @@ outputs:
 
     def setUp(self):
         super(InstanceGroupTest, self).setUp()
+        self.client = self.orchestration_client
         if not self.conf.image_ref:
             raise self.skipException("No image configured to test")
         if not self.conf.minimal_image_ref:
@@ -131,7 +132,6 @@ class InstanceGroupBasicTest(InstanceGroupTest):
 
     def test_basic_create_works(self):
         """Make sure the working case is good.
-
         Note this combines test_override_aws_ec2_instance into this test as
         well, which is:
         If AWS::EC2::Instance is overridden, InstanceGroup will automatically
@@ -174,14 +174,13 @@ class InstanceGroupBasicTest(InstanceGroupTest):
                                'flavor': self.conf.instance_type}}
         self.update_stack(stack_identifier, self.template,
                           environment=env2, files=files)
+        self._wait_for_stack_status(stack_identifier, 'UPDATE_COMPLETE')
         stack = self.client.stacks.get(stack_identifier)
         self.assert_instance_count(stack, 5)
 
     def test_update_group_replace(self):
-        """Test case for ensuring non-updatable props case a replacement.
-
-        Make sure that during a group update the non-updatable properties cause
-        a replacement.
+        """Make sure that during a group update the non updatable
+        properties cause a replacement.
         """
         files = {'provider.yaml': self.instance_template}
         env = {'resource_registry':
@@ -210,9 +209,7 @@ class InstanceGroupBasicTest(InstanceGroupTest):
         self.assertNotEqual(orig_asg_id, rsrc.physical_resource_id)
 
     def test_create_instance_error_causes_group_error(self):
-        """Test create failing a resource in the instance group.
-
-        If a resource in an instance group fails to be created, the instance
+        """If a resource in an instance group fails to be created, the instance
         group itself will fail and the broken inner resource will remain.
         """
         stack_name = self._stack_rand_name()
@@ -230,7 +227,7 @@ class InstanceGroupBasicTest(InstanceGroupTest):
             parameters={},
             environment=env
         )
-        self.addCleanup(self._stack_delete, stack_name)
+        self.addCleanup(self.client.stacks.delete, stack_name)
         stack = self.client.stacks.get(stack_name)
         stack_identifier = '%s/%s' % (stack_name, stack.id)
         self._wait_for_stack_status(stack_identifier, 'CREATE_FAILED')
@@ -245,9 +242,7 @@ class InstanceGroupBasicTest(InstanceGroupTest):
         self._assert_instance_state(nested_ident, 0, 2)
 
     def test_update_instance_error_causes_group_error(self):
-        """Test update failing a resource in the instance group.
-
-        If a resource in an instance group fails to be created during an
+        """If a resource in an instance group fails to be created during an
         update, the instance group itself will fail and the broken inner
         resource will remain.
         """
@@ -350,6 +345,7 @@ class InstanceGroupUpdatePolicyTest(InstanceGroupTest):
         # test stack update
         self.update_stack(stack_identifier, updt_template,
                           environment=env, files=files)
+        self._wait_for_stack_status(stack_identifier, 'UPDATE_COMPLETE')
         updt_stack = self.client.stacks.get(stack_identifier)
 
         # test that the launch configuration is replaced
@@ -383,8 +379,7 @@ class InstanceGroupUpdatePolicyTest(InstanceGroupTest):
             self.assertNotIn(deletes_expected, updt_names)
 
     def test_instance_group_update_replace(self):
-        """Test simple update replace with no conflict.
-
+        """
         Test simple update replace with no conflict in batch size and
         minimum instances in service.
         """
@@ -403,8 +398,7 @@ class InstanceGroupUpdatePolicyTest(InstanceGroupTest):
                                    update_replace=True)
 
     def test_instance_group_update_replace_with_adjusted_capacity(self):
-        """Test update replace with capacity adjustment.
-
+        """
         Test update replace with capacity adjustment due to conflict in
         batch size and minimum instances in service.
         """
@@ -423,7 +417,9 @@ class InstanceGroupUpdatePolicyTest(InstanceGroupTest):
                                    update_replace=True)
 
     def test_instance_group_update_replace_huge_batch_size(self):
-        """Test update replace with a huge batch size."""
+        """
+        Test update replace with a huge batch size.
+        """
         updt_template = self.ig_tmpl_with_updt_policy()
         group = updt_template['Resources']['JobServerGroup']
         policy = group['UpdatePolicy']['RollingUpdate']
@@ -439,7 +435,9 @@ class InstanceGroupUpdatePolicyTest(InstanceGroupTest):
                                    update_replace=True)
 
     def test_instance_group_update_replace_huge_min_in_service(self):
-        """Update replace with huge number of minimum instances in service."""
+        """
+        Test update replace with a huge number of minimum instances in service.
+        """
         updt_template = self.ig_tmpl_with_updt_policy()
         group = updt_template['Resources']['JobServerGroup']
         policy = group['UpdatePolicy']['RollingUpdate']
@@ -456,8 +454,7 @@ class InstanceGroupUpdatePolicyTest(InstanceGroupTest):
                                    update_replace=True)
 
     def test_instance_group_update_no_replace(self):
-        """Test simple update only and no replace with no conflict.
-
+        """
         Test simple update only and no replace (i.e. updated instance flavor
         in Launch Configuration) with no conflict in batch size and
         minimum instances in service.
@@ -478,8 +475,7 @@ class InstanceGroupUpdatePolicyTest(InstanceGroupTest):
                                    update_replace=False)
 
     def test_instance_group_update_no_replace_with_adjusted_capacity(self):
-        """Test update only and no replace with capacity adjustment.
-
+        """
         Test update only and no replace (i.e. updated instance flavor in
         Launch Configuration) with capacity adjustment due to conflict in
         batch size and minimum instances in service.
