@@ -13,6 +13,7 @@
 from heatclient.common import template_utils
 import six
 
+from heat_integrationtests.common import exceptions
 from heat_integrationtests.scenario import scenario_base
 
 CFG1_SH = '''#!/bin/sh
@@ -36,18 +37,17 @@ file {'output_result':
   mode    => 0644,
   content => "The file /tmp/$::bar contains $::foo for server \
 $::deploy_server_id during $::deploy_action",
-}
-'''
+}'''
 
 
 class SoftwareConfigIntegrationTest(scenario_base.ScenarioTestsBase):
 
     def setUp(self):
         super(SoftwareConfigIntegrationTest, self).setUp()
-        if not self.conf.image_ref:
-            raise self.skipException("No image configured to test")
-        if not self.conf.instance_type:
-            raise self.skipException("No flavor configured to test")
+        if self.conf.skip_software_config_tests:
+            self.skipTest('Testing software config disabled in conf, '
+                          'skipping')
+        self.stack_name = self._stack_rand_name()
 
     def check_stack(self):
         sid = self.stack_identifier
@@ -75,12 +75,18 @@ class SoftwareConfigIntegrationTest(scenario_base.ScenarioTestsBase):
             for res in ('dep2a', 'dep2b', 'dep1', 'dep3'):
                 self._wait_for_resource_status(
                     sid, res, 'CREATE_COMPLETE')
+        except (exceptions.StackResourceBuildErrorException,
+                exceptions.TimeoutException) as e:
+            raise e
         finally:
             # attempt to log the server console regardless of deployments
             # going to complete. This allows successful and failed boot
             # logs to be compared
             self._log_console_output(servers=[server])
 
+        # Check that stack was fully created
+        self._wait_for_stack_status(sid, 'CREATE_COMPLETE')
+
         complete_server_metadata = self.client.resources.metadata(
             sid, 'server')
 
@@ -100,7 +106,7 @@ class SoftwareConfigIntegrationTest(scenario_base.ScenarioTestsBase):
             res1['result'])
         self.assertEqual(0, res1['status_code'])
         self.assertEqual('Output to stderr\n', res1['stderr'])
-        self.assertGreater(len(res1['stdout']), 0)
+        self.assertTrue(len(res1['stdout']) > 0)
 
         res2 = self._stack_output(stack, 'res2')
         self.assertEqual(
@@ -118,7 +124,7 @@ class SoftwareConfigIntegrationTest(scenario_base.ScenarioTestsBase):
             res3['result'])
         self.assertEqual(0, res3['status_code'])
         self.assertEqual('', res3['stderr'])
-        self.assertGreater(len(res1['stdout']), 0)
+        self.assertTrue(len(res1['stdout']) > 0)
 
         dep1_resource = self.client.resources.get(sid, 'dep1')
         dep1_id = dep1_resource.physical_resource_id
@@ -133,7 +139,8 @@ class SoftwareConfigIntegrationTest(scenario_base.ScenarioTestsBase):
                 dep1_dep.creation_time)
 
     def test_server_software_config(self):
-        """Check that passed files with scripts are executed on created server.
+        """
+        Check that passed files with scripts are executed on created server.
 
         The alternative scenario is the following:
             1. Create a stack and pass files with scripts.
@@ -160,6 +167,7 @@ class SoftwareConfigIntegrationTest(scenario_base.ScenarioTestsBase):
 
         # Launch stack
         self.stack_identifier = self.launch_stack(
+            stack_name=self.stack_name,
             template_name='test_server_software_config.yaml',
             parameters=parameters,
             files=dict(list(files.items()) + list(env_files.items())),
