@@ -14,6 +14,7 @@
 from cinderclient import exceptions as cinder_exceptions
 from oslo_log import log as logging
 import six
+from testtools import testcase
 
 from heat_integrationtests.common import exceptions
 from heat_integrationtests.scenario import scenario_base
@@ -22,7 +23,9 @@ LOG = logging.getLogger(__name__)
 
 
 class VolumeBackupRestoreIntegrationTest(scenario_base.ScenarioTestsBase):
-    """Class is responsible for testing of volume backup."""
+    """
+    Class is responsible for testing of volume backup.
+    """
 
     def setUp(self):
         super(VolumeBackupRestoreIntegrationTest, self).setUp()
@@ -46,7 +49,7 @@ class VolumeBackupRestoreIntegrationTest(scenario_base.ScenarioTestsBase):
         self.assertEqual(self.volume_description,
                          self._stack_output(stack, 'display_description'))
 
-    def check_stack(self, stack_id, parameters):
+    def check_stack(self, stack_id):
         stack = self.client.stacks.get(stack_id)
 
         # Verify with cinder that the volume exists, with matching details
@@ -58,7 +61,8 @@ class VolumeBackupRestoreIntegrationTest(scenario_base.ScenarioTestsBase):
 
         # Delete the stack and ensure a backup is created for volume_id
         # but the volume itself is gone
-        self._stack_delete(stack_id)
+        self.client.stacks.delete(stack_id)
+        self._wait_for_stack_status(stack_id, 'DELETE_COMPLETE')
         self.assertRaises(cinder_exceptions.NotFound,
                           self.volume_client.volumes.get,
                           volume_id)
@@ -75,11 +79,11 @@ class VolumeBackupRestoreIntegrationTest(scenario_base.ScenarioTestsBase):
         try:
             stack_identifier2 = self.launch_stack(
                 template_name='test_volumes_create_from_backup.yaml',
-                parameters=parameters,
                 add_parameters={'backup_id': backup.id})
             stack2 = self.client.stacks.get(stack_identifier2)
-        except exceptions.StackBuildErrorException:
-            LOG.exception("Halting test due to bug: #1382300")
+        except exceptions.StackBuildErrorException as e:
+            LOG.error("Halting test due to bug: #1382300")
+            LOG.exception(e)
             return
 
         # Verify with cinder that the volume exists, with matching details
@@ -93,13 +97,17 @@ class VolumeBackupRestoreIntegrationTest(scenario_base.ScenarioTestsBase):
                          testfile_data)
 
         # Delete the stack and ensure the volume is gone
-        self._stack_delete(stack_identifier2)
+        self.client.stacks.delete(stack_identifier2)
+        self._wait_for_stack_status(stack_identifier2, 'DELETE_COMPLETE')
         self.assertRaises(cinder_exceptions.NotFound,
                           self.volume_client.volumes.get,
                           volume_id2)
 
+    @testcase.skip('Skipped until failure rate '
+                   'can be reduced ref bug #1382300')
     def test_cinder_volume_create_backup_restore(self):
-        """Ensure the 'Snapshot' deletion policy works.
+        """
+        Ensure the 'Snapshot' deletion policy works.
 
         This requires a more complex test, but it tests several aspects
         of the heat cinder resources:
@@ -126,4 +134,4 @@ class VolumeBackupRestoreIntegrationTest(scenario_base.ScenarioTestsBase):
         )
 
         # Check stack
-        self.check_stack(stack_id, parameters)
+        self.check_stack(stack_id)
