@@ -83,11 +83,11 @@ basic_configuration() {
         if detect_rabbit
         then
             echo "rabbitmq detected, configuring $conf_path for rabbit" >&2
-            iniset $conf_path DEFAULT rpc_backend heat.openstack.common.rpc.impl_kombu
+            iniset $conf_path DEFAULT rpc_backend kombu
             iniset $conf_path DEFAULT rabbit_password guest
         else
             echo "qpid detected, configuring $conf_path for qpid" >&2
-            iniset $conf_path DEFAULT rpc_backend heat.openstack.common.rpc.impl_qpid
+            iniset $conf_path DEFAULT rpc_backend qpid
         fi
     fi
 }
